C
C     Maximum number of object that can be stored in memory
C     during fetch process.
C
      INTEGER               NOBMAX
      PARAMETER           ( NOBMAX = 1000000 )

C
C     Type 2 sky catalog type string that appears in the architecture/
C     type identifier stored in the first 8 bytes of the file.
C
      CHARACTER*(*)         ST2TYP
      PARAMETER           ( ST2TYP = 'ST2' )

C
C     NBMAX is maximal number of declination bands onto the celestial
C     sphere.
C
      INTEGER               NBMAX
      PARAMETER           ( NBMAX = 400 )

C
C     NZMAX is maximal number of elementary zones onto the celestial
C     sphere. It depends on the only argument: the number of declination
C     bands. Below there is a table that shows how the elementary zone
C     height DELDEC and the number of elementary zones NZONES depend on
C     the number of declination bands NBANDS:
C
C                      NBANDS         DELDEC       NZONES
C
C                        30              6           1144
C                        45              4           2576
C                        60              3           4584
C                        90              2          10312
C                       180              1          41252
C                       360            0.5         165016
C
C     Approximately NZONES can be expressed by  4 * NBANDS^2 / PI.
C
      INTEGER               NZMAX
      PARAMETER           ( NZMAX = 4 * NBMAX * NBMAX / 3 )

C
C     NNMAX is maximal number of elements in so-called "node sequence"
C     (see SPICE Catalog Design) to provide fast access to indexed
C     parameter of the catalog object.
C
      INTEGER               NNMAX
      PARAMETER           ( NNMAX = 50 )

C
C     NFLMAX is maximal number of fields in the catalog object record
C
      INTEGER               NFLMAX
      PARAMETER           ( NFLMAX = 300 )

C
C     NFAMAX is maximal number of fields in the auxilary part of
C     the catalog object record
C
      INTEGER               NFAMAX
      PARAMETER           ( NFAMAX = 31 )

C
C     Number of characters packed in one integer number. 
C
      INTEGER               NCHARI
      PARAMETER           ( NCHARI = 4 )

C
C     Maximum number of integers packed in one integer number. 
C
      INTEGER               NIIMAX
      PARAMETER           ( NIIMAX = 16 )

C
C     String lengths -- all must be divisible by NCHARI without
C     remainder:
C
C        CATNLN -- catalog name length
C
C        OBJTLN -- object type length
C
C        FRMNLN -- reference frame name length
C
C        FLDNLN -- field name length
C
C        FOVTLN -- FOV type length
C
C        DSCLSZ -- catalog/field description line size
C
C        DPHXSZ -- size of a string that encoded one DP number
C
      INTEGER               CATNLN
      PARAMETER           ( CATNLN = 80 )

      INTEGER               OBJTLN
      PARAMETER           ( OBJTLN = CATNLN )

      INTEGER               FRMNLN
      PARAMETER           ( FRMNLN = 32 )

      INTEGER               FLDNLN
      PARAMETER           ( FLDNLN = 24 )

      INTEGER               FLDCLN
      PARAMETER           ( FLDCLN = 24 )

      INTEGER               FOVTLN
      PARAMETER           ( FOVTLN = 40 )

      INTEGER               DSCLSZ
      PARAMETER           ( DSCLSZ = 80 )

      INTEGER               DPHXSZ
      PARAMETER           ( DPHXSZ = 24 )

C
C     Maximum text field value size.
C
      INTEGER               TFVMAX
      PARAMETER           ( TFVMAX = 128 )

C
C     Names of the position fields.
C
      CHARACTER*(*)         FNBAND
      PARAMETER           ( FNBAND = 'BAND_NO' )

      CHARACTER*(*)         FNZONE
      PARAMETER           ( FNZONE = 'ZONE_IN_BAND_NO' )

      CHARACTER*(*)         FNRA
      PARAMETER           ( FNRA   = 'RA' )

      CHARACTER*(*)         FNDEC
      PARAMETER           ( FNDEC  = 'DEC' )

C
C     Field classes.
C
      CHARACTER*(*)         FCID
      PARAMETER           ( FCID   = 'ID'   )

      CHARACTER*(*)         FCRA
      PARAMETER           ( FCRA   = 'RA'   )

      CHARACTER*(*)         FCDEC
      PARAMETER           ( FCDEC  = 'DEC'   )

      CHARACTER*(*)         FCRAZ
      PARAMETER           ( FCRAZ  = 'RA_ZONE' )

      CHARACTER*(*)         FCDECB
      PARAMETER           ( FCDECB = 'DEC_BAND'   )

      CHARACTER*(*)         FCRAS
      PARAMETER           ( FCRAS  = 'RA_SHIFT' )

      CHARACTER*(*)         FCDECS
      PARAMETER           ( FCDECS = 'DEC_SHIFT'   )

      CHARACTER*(*)         FCPMRA
      PARAMETER           ( FCPMRA = 'RA_PM' )

      CHARACTER*(*)         FCPMDC
      PARAMETER           ( FCPMDC = 'DEC_PM' )

      CHARACTER*(*)         FCPRLX
      PARAMETER           ( FCPRLX = 'PARALLAX' )

      CHARACTER*(*)         FCRVEL
      PARAMETER           ( FCRVEL = 'RADIAL_VELOCITY' )

      CHARACTER*(*)         FCINTE
      PARAMETER           ( FCINTE = 'INTENSITY' )

      CHARACTER*(*)         FCCLSS
      PARAMETER           ( FCCLSS = 'CLASS_INDEX' )

      CHARACTER*(*)         FCOTYP
      PARAMETER           ( FCOTYP = 'OBJECT_TYPE' )

C
C     Positional field names.
C
      CHARACTER*(*)         PFNBAN
      PARAMETER           ( PFNBAN =
     .                '  DEC band number.' )

      CHARACTER*(*)         PFNZON
      PARAMETER           ( PFNZON =
     .                '  Elementary zone number within the DEC band.' )

      CHARACTER*(*)         PFNRA
      PARAMETER           ( PFNRA  =
     .                '  RA offset from the zone center.' )

      CHARACTER*(*)         PFNDEC
      PARAMETER           ( PFNDEC =
     .                '  DEC offset from the zone center.' )

C
C     Thresholds that determine whether field goes to MAIN or
C     AUX (see STWMG2/STWSW2 for details for decision process.)
C
      DOUBLE PRECISION      AORMPR
      PARAMETER           ( AORMPR = 40 )

      DOUBLE PRECISION      AORMSZ
      PARAMETER           ( AORMSZ = 200 )

C
C     FOV type that we support.
C
      CHARACTER*(*)         FTCIRC
      PARAMETER           ( FTCIRC = 'CIRCLE' )

      CHARACTER*(*)         FTELLI
      PARAMETER           ( FTELLI = 'ELLIPSE' )

      CHARACTER*(*)         FTPOLY
      PARAMETER           ( FTPOLY = 'POLYGON' )

C
C     Maximum number of vertices if FOV type is "POLYGON"
C
      INTEGER               NVRMAX
      PARAMETER           ( NVRMAX = 50 )

C
C     Meta information array name length -- this number should never
C     change because this length is determined in metablock directory
C     structure.
C
      INTEGER               METNLN
      PARAMETER           ( METNLN = 16 )

C
C     Meta information data area start address (area of the file from 
C     the very beginning of the file to this address is the meta 
C     information directory. It has fixed size of BEGMET-1 integers.)
C
      INTEGER               BEGMET
      PARAMETER           ( BEGMET = 1001 )

C
C     Metainformation array names.
C
C     TBD -- need descrptions for each metainformation array:
C
C        MDCNAM --> 'CAT_NAME'
C        MDOTYP --> 'OBJECT_TYPE'
C        MDNOFO --> 'N_OF_OBJECTS'
C        MDFRAM --> 'FRAME'
C        MDEPOC --> 'EPOCH'
C        MDPMSC --> 'PM_SCALE'
C        MDMATR --> 'MATRIX'
C        MDNOFF --> 'N_OF_FIELDS'
C        MDNMAI --> 'NMAIN'
C        MDFNAM --> 'FIELD_NAME'
C        MDFCLA --> 'FIELD_CLASS'
C        MDFTYP --> 'FIELD_TYPE'
C        MDFIDX --> 'FIELD_INDX'
C        MDMINV --> 'MIN_VALUE'
C        MDACCU --> 'ACCUR'
C        MDMAXA --> 'MAXABS'
C        MDNPKT --> 'N_PCK_TXT'
C        MDNPKN --> 'N_PCK_NUM'
C        MDNMFL --> 'NUM_MAIN_FIELDS'
C        MDMRCL --> 'MAIN_RECL'
C        MDDENS --> 'DENSITY'
C        MDNTAU --> 'N_TXT_AUX'
C        MDNNAU --> 'N_NUM_AUX'
C        MDTAUF --> 'TXT_AUX_FIELDS'
C        MDNAUF --> 'NUM_AUX_FIELDS'
C        MDNODB --> 'N_OF_DEC_BANDS'
C        MDNOZO --> 'N_OF_ZONES'
C        MDNINB --> 'N_IN_BAND'
C        MDIPOS --> 'INIT_POS'
C        MDNSUM --> 'N_SUM'
C        MDBEGM --> 'BEG_MAIN'
C        MDBAUX --> 'BEG_AUX'
C        MDBIDX --> 'BEG_INDX'
C        MDNINP --> 'N_IN_POS'
C        MDNINI --> 'N_IN_INTENS'
C        MDNITB --> 'N_IND_TAB'
C        MDLSTT --> 'LIST_TAB'
C        MDNNOD --> 'N_NODES'
C        MDMISS --> 'MISS'
C        MDFDSC --> 'FIELD_DESC'
C        MDFDSN --> 'FIELD_DESC_N'
C
      CHARACTER*(*)         MDCNAM
      PARAMETER           ( MDCNAM = 'CAT_NAME' )

      CHARACTER*(*)         MDOTYP
      PARAMETER           ( MDOTYP = 'OBJECT_TYPE' )

      CHARACTER*(*)         MDNOFO
      PARAMETER           ( MDNOFO = 'N_OF_OBJECTS' )

      CHARACTER*(*)         MDFRAM
      PARAMETER           ( MDFRAM = 'FRAME' )

      CHARACTER*(*)         MDEPOC
      PARAMETER           ( MDEPOC = 'EPOCH' )

      CHARACTER*(*)         MDPMSC
      PARAMETER           ( MDPMSC = 'PM_SCALE' )

      CHARACTER*(*)         MDMATR
      PARAMETER           ( MDMATR = 'MATRIX' )

      CHARACTER*(*)         MDNOFF
      PARAMETER           ( MDNOFF = 'N_OF_FIELDS' )

      CHARACTER*(*)         MDNMAI
      PARAMETER           ( MDNMAI = 'NMAIN' )

      CHARACTER*(*)         MDFNAM
      PARAMETER           ( MDFNAM = 'FIELD_NAME' )

      CHARACTER*(*)         MDFCLA
      PARAMETER           ( MDFCLA = 'FIELD_CLASS' )

      CHARACTER*(*)         MDFTYP
      PARAMETER           ( MDFTYP = 'FIELD_TYPE' )

      CHARACTER*(*)         MDFIDX
      PARAMETER           ( MDFIDX = 'FIELD_INDX' )

      CHARACTER*(*)         MDMINV
      PARAMETER           ( MDMINV = 'MIN_VALUE' )

      CHARACTER*(*)         MDACCU
      PARAMETER           ( MDACCU = 'ACCUR' )

      CHARACTER*(*)         MDMAXA
      PARAMETER           ( MDMAXA = 'MAXABS' )

      CHARACTER*(*)         MDNPKT
      PARAMETER           ( MDNPKT = 'N_PCK_TXT' )

      CHARACTER*(*)         MDNPKN
      PARAMETER           ( MDNPKN = 'N_PCK_NUM' )

      CHARACTER*(*)         MDNMFL
      PARAMETER           ( MDNMFL = 'NUM_MAIN_FIELDS' )

      CHARACTER*(*)         MDMRCL
      PARAMETER           ( MDMRCL = 'MAIN_RECL' )

      CHARACTER*(*)         MDDENS
      PARAMETER           ( MDDENS = 'DENSITY' )

      CHARACTER*(*)         MDNTAU
      PARAMETER           ( MDNTAU = 'N_TXT_AUX' )

      CHARACTER*(*)         MDNNAU
      PARAMETER           ( MDNNAU = 'N_NUM_AUX' )

      CHARACTER*(*)         MDTAUF
      PARAMETER           ( MDTAUF = 'TXT_AUX_FIELDS' )

      CHARACTER*(*)         MDNAUF
      PARAMETER           ( MDNAUF = 'NUM_AUX_FIELDS' )

      CHARACTER*(*)         MDNODB
      PARAMETER           ( MDNODB = 'N_OF_DEC_BANDS' )

      CHARACTER*(*)         MDNOZO
      PARAMETER           ( MDNOZO = 'N_OF_ZONES' )

      CHARACTER*(*)         MDNINB
      PARAMETER           ( MDNINB = 'N_IN_BAND' )

      CHARACTER*(*)         MDIPOS
      PARAMETER           ( MDIPOS = 'INIT_POS' )

      CHARACTER*(*)         MDNSUM
      PARAMETER           ( MDNSUM = 'N_SUM' )

      CHARACTER*(*)         MDBMAI
      PARAMETER           ( MDBMAI = 'BEG_MAIN' )

      CHARACTER*(*)         MDBAUX
      PARAMETER           ( MDBAUX = 'BEG_AUX' )

      CHARACTER*(*)         MDBIDX
      PARAMETER           ( MDBIDX = 'BEG_INDX' )

      CHARACTER*(*)         MDNINP
      PARAMETER           ( MDNINP = 'N_IN_POS' )

      CHARACTER*(*)         MDNINI
      PARAMETER           ( MDNINI = 'N_IN_INTENS' )

      CHARACTER*(*)         MDNITB
      PARAMETER           ( MDNITB = 'N_IND_TAB' )

      CHARACTER*(*)         MDLSTT
      PARAMETER           ( MDLSTT = 'LIST_TAB' )

      CHARACTER*(*)         MDNNOD
      PARAMETER           ( MDNNOD = 'N_NODES' )

      CHARACTER*(*)         MDMISS
      PARAMETER           ( MDMISS = 'MISS' )

      CHARACTER*(*)         MDFDSC
      PARAMETER           ( MDFDSC = 'FIELD_DESC' )

      CHARACTER*(*)         MDFDSN
      PARAMETER           ( MDFDSN = 'FIELD_DESC_N' )

      CHARACTER*(*)         MDNCDS
      PARAMETER           ( MDNCDS = 'CAT_DESCR_N' )

      CHARACTER*(*)         MDCDSC
      PARAMETER           ( MDCDSC = 'CAT_DESCR' )

      CHARACTER*(*)         MDCPRF
      PARAMETER           ( MDCPRF = 'CHR_PREFIXES' )

      CHARACTER*(*)         MDCPOS
      PARAMETER           ( MDCPOS = 'CHR_START_POS' )

C
C     Number of "bins" (fractions) in the integer representation of
C     RA/DEC offset with respect to the center of an elementary zone
C     reduced by two.
C
      DOUBLE PRECISION      OFFSCL
      PARAMETER           ( OFFSCL = 4294967292.0D0 )

C
C     Position shifts encoding MINVAL and MAXABS (these are the
C     "safest" cross-platform values of INTMAX and INTMIN).
C
      INTEGER               RDMAXA
      PARAMETER           ( RDMAXA = 2147483647 )

      DOUBLE PRECISION      RDMINV
      PARAMETER           ( RDMINV = -2147483647.D0 )

C
C     Maxumum Number of "bins" (fractions) in the integer
C     representation of a numeric field: ( 2**30 - 1 ) * 2 - 1.
C
      INTEGER               RATMAX
      PARAMETER           ( RATMAX = ( 2**30 - 1 ) * 2 - 1 )
