
C$Procedure STDIG2 ( the number of digits after decimal point )

      INTEGER FUNCTION STDIG2 ( A )

C$ Abstract
C
C     Returns the number of digits after decimal point
C     in decimal presentation of double precision number.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None
C
C$ Keywords
C
C     TBD
C
C$ Declarations

      DOUBLE PRECISION  A

C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     A          I   Double precision value to be analyzed
C
C$ Detailed_Input
C
C     A              is double precision value to be examined to
C                    determine the number of decimal digits after
C                    decimal point
C
C$ Parameters
C
C      None.
C
C$ Files
C
C     None.
C
C$ Exceptions
C
C     Error free
C
C$ Particulars
C
C     The routine does not pretend to be an universal instrument
C     to cover extended range of input numbers. Nevertheless it
C     is an efficient instrument in the case when:
C
C     - the numbers are read from text file containing them
C       presented with 'F' edit descriptor;
C
C     - the numbers are generated by real measurements made
C       with certain accuracy.
C
C     The routine provide reliable results if input number
C     has less than 10 numbers after decimal point.
C
C$ Examples
C
C     Let we have double precision array A(5), where:
C
C         A(1) =         123.45678901D0
C         A(2) =  -123456789.000001D0
C         A(3) =          -0.0000012345D0
C         A(4) =      123456.789012345D0
C         A(5) =   123456789.D2
C
C      Then on executing the following cycle
C
C         DO I = 1, 5
C            PRINT*, I, STDIG2(A(I))
C         END DO
C
C      we obtain correspondingly:
C
C         1         8
C         2         6
C         3        10
C         4         9
C         5         0
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets   ( JPL )
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 1-DECEMBER-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     SPICELIB Functions
C
      INTEGER            FRSTNB

C
C     Local variables
C
      CHARACTER*30       S
      INTEGER            I

      WRITE ( S, '(F30.10)' ) DABS(A) + 1.0D-30

      I = MAX( FRSTNB(S) + 16, 21 )
      I = MIN( I, 30 )

      DO WHILE ( S(I:I) .EQ. '0' )
         I = I - 1
      END DO

      STDIG2 = I - 20

      RETURN

      END
		
