C$Procedure  STGFC2 ( get certain text data from certain record )

      SUBROUTINE STGFC2 ( RECNO, NAME, COUT, FOUND )

C$ Abstract
C
C     Extract pre-defined text data from pre-defined record
C
C$ Copyright
C
C     Copyright (1995), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations

      IMPLICIT NONE

      INTEGER               RECNO
      CHARACTER*(*)         NAME
      CHARACTER*(*)         COUT
      LOGICAL               FOUND

C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     RECNO      I   Record number of the catalog object to be accessed
C     NAME       I   Field ( parameter ) name to be accessed
C     COUT       O   Contents of character NAME field of RECNO record
C     FOUND      O   Data missing flag
C
C$ Detailed_Input
C
C     RECNO          is a record number of the catalog object to
C                    be accessed
C
C     NAME           is a field ( parameter ) name to be read from
C                    the RECNO record. The field is to be of
C                    CHARACTER type.
C
C$ Detailed_Output
C
C     COUT           is contents of the NAME character field to be
C                    fetched from the RECNO record
C
C     FOUND          is a flag whether the NAME field of the RECNO
C                    record contains data ( and then its value is
C                    .TRUE. ) or the data are missed ( then .FALSE. )
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     TBD
C
C$ Files
C
C     TBD 
C
C$ Particulars
C
C     TBD
C
C     Extract text field NAME from record with through number RECNO
C     and put it into output text string COUT. If the field contains
C     not only blanks, output flag FOUND is .TRUE., otherwise .FALSE.
C
C$ Example
C
C     TBD -- small partial example 
C
C$ Restrictions
C
C     TBD
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-JUL-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Local variables
C
      LOGICAL               OK

C
C     Check whether the catalog is really loaded
C
      CALL STCHL2 ( OK )
      IF ( .NOT. OK ) THEN
         CALL SETMSG ( 'No catalog is loaded so far' )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'   )
      END IF

C
C     Check whether the given name exists
C
      CALL STCHN2 ( NAME, FOUND )

      IF ( FOUND ) THEN

C
C        Fetch the given record
C
         CALL STREC2 ( RECNO )

C
C        Read the text field from the given record
C
         CALL STRFC2 ( COUT, FOUND )

      END IF

      RETURN
      END
		
