C$Procedure  STGRD2   ( get RA and DEC from certain record )

      SUBROUTINE STGRD2 ( RECNO, FRAME, RA, DEC )

C$ Abstract
C
C     Extract RA and DEC values from record with given number,
C     modify them by proper motion and transform to the given frame.
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TBD
C
C$ Declarations

      IMPLICIT NONE

      INTEGER               RECNO
      CHARACTER*(*)         FRAME
      DOUBLE PRECISION      RA
      DOUBLE PRECISION      DEC

C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     RECNO      I   SPICE catalog record number
C     FRAME      I   Frame defined for star positions
C     RA         O   Right ascension of the sky object
C     DEC        O   Declination of the sky object
C
C$ Detailed_Input
C
C     RECNO          is the SPICE catalog record number
C
C     FRAME          is a frame defined for star positions
C
C$ Detailed_Output
C
C     RA             is right ascension of the given object at the
C                    given frame for the predefined epoch
C
C     DEC            is declination of the given object at the
C                    given frame for the predefined epoch
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     TBD
C
C$ Files
C
C     TBD.
C
C$ Particulars
C
C     TBD
C
C     The routine fetches RA and DEC double precision values
C     (in radians) for the sky object with the pre-defined record
C     number. Next step is to check whether the position is to be
C     recalculated to another EPOCH. It depends on two parameters:
C     EP_FLAG that is a special flag presenting current status of
C     the epoch definition (equal to zero if neither ET_POS nor
C     ET_FOV was set, so we are interested just in catalog epoch)
C     and PM_SCALE that is a scale coefficient for proper motion
C     of the catalog objects. If PM_SCALE = 0d0, that means that
C     there is no proper motion. Otherwise we consider proper
C     motion units as (arc sec/year)*PM_SCALE.
C     After all the calculations are done, the routine checks
C     whether the position is to be recalculated to another frame
C     and performs it if necessary.
C
C$ Examples
C
C     TBD -- example below probably needs changes
C
C     Let we want to obtain star position for object with record
C     number N in frame 'B1950'. Then on calling
C
C        CALL STGRD2 ( N, 'B1950', RA, DEC )
C
C     we have output values RA and DEC that are the object
C     position for the frame required and epoch defined before
C     using entry SET_POS_EPOCH ( see above).
C
C$ Restrictions
C
C     TBD
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     ?????
C
C-&

C
C     Local variables
C
      LOGICAL               OK

C
C     Check whether the catalog is really loaded
C
      CALL STCHL2 ( OK )
      IF ( .NOT. OK ) THEN
         CALL SETMSG ( 'No catalog is loaded so far' )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'   )
      END IF

C
C     Set "fast" mode of reading (only MAIN part of the record)
C
      CALL STRF2

C
C     Fetch MAIN portion of the record
C
      CALL STREC2 ( RECNO  )

C
C     Fetch RA and DEC from the record and convert them to given
C     epoch (if there is proper motion) and frame
C
      CALL STCRD2 ( FRAME, RA, DEC )

      RETURN
      END
