C$Procedure  STRMG2  ( Type 2 Sky Catalog data access manager )

      SUBROUTINE STRMG2 ( RECNO, NAME, CONSTR, IFLD, NRET, LOGREL,
     .       VAL, IOUT, DOUT, COUT, RA,  DEC, FOUND, ETIME, FRAME,
     .       FOVTYP, BSIGHT, NSIDES, VERTIC, TABNO, OK, R, WITHIN,
     .       NRINDX, INDXED, FOVSET, NCNSTR, NOB,  IBAND,  IBAND1,
     .       IBAND2, IZONE, IZONE1, IZONE2, RECNO1, RECNO2, OBTYP,
     .       MATR, ROOM, FIRST, DESCR, NFLD, FLNAM, FLTYP,  FLCLS,
     .       FLIND, MINV, MAXV, NDIG,  MISSED, SIZE, NBAND,  HNDL,
     .       INBAND, INZONE,  ACTION, STATUS,  NZ, INDEX1, INDEX2 )

C$ Abstract
C
C     Manage data access operations on SPICE Sky Catalog files.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
      IMPLICIT              NONE

      INCLUDE               'starlib.inc'

      INTEGER               RECNO
      CHARACTER*(*)         NAME
      CHARACTER*(*)         CONSTR
      INTEGER               IFLD
      INTEGER               TABNO
      INTEGER               NRET
      CHARACTER*(*)         LOGREL
      DOUBLE PRECISION      VAL
      INTEGER               IOUT
      DOUBLE PRECISION      DOUT
      CHARACTER*(*)         COUT
      DOUBLE PRECISION      RA
      DOUBLE PRECISION      DEC
      DOUBLE PRECISION      ETIME
      CHARACTER*(*)         FRAME
      CHARACTER*(*)         FOVTYP
      DOUBLE PRECISION      BSIGHT (3)
      INTEGER               NSIDES
      DOUBLE PRECISION      VERTIC (3,*)
      LOGICAL               FOUND
      LOGICAL               OK
      DOUBLE PRECISION      R      (3)
      LOGICAL               WITHIN
      LOGICAL               FOVSET
      INTEGER               NRINDX
      INTEGER               INDXED (2,*)
      INTEGER               NCNSTR
      INTEGER               NOB
      INTEGER               IBAND
      INTEGER               IBAND1
      INTEGER               IBAND2
      INTEGER               IZONE
      INTEGER               IZONE1
      INTEGER               IZONE2
      INTEGER               RECNO1
      INTEGER               RECNO2
      INTEGER               INDEX1
      INTEGER               INDEX2

C
C     Summary agrument declarations
C

      CHARACTER*(*)         OBTYP
      DOUBLE PRECISION      MATR (3,3)
      INTEGER               ROOM
      INTEGER               FIRST
      CHARACTER*(*)         DESCR(*)
      INTEGER               NFLD
      CHARACTER*(*)         FLNAM (*)
      CHARACTER*(1)         FLTYP (*)
      CHARACTER*(*)         FLCLS (*)
      LOGICAL               FLIND (*)
      DOUBLE PRECISION      MINV
      DOUBLE PRECISION      MAXV
      INTEGER               NDIG
      INTEGER               MISSED
      INTEGER               SIZE
      INTEGER               NBAND
      INTEGER               NZ
      INTEGER               INBAND (*)
      INTEGER               INZONE (*)
      INTEGER               HNDL
      CHARACTER*(*)         ACTION
      LOGICAL               STATUS

C$ Brief_I/O
C
C     VARIABLE  I/O  ENTRY POINTS
C     --------  ---  --------------------------------------------------
C     RECNO      I   STREC2
C     NAME       I   STSCN2, STSCC2, STCHN2,
C                    STLD2
C     CONSTR     I   STSCC2
C     LOGREL     I   STSCN2, STSCC2
C     VAL        I   STSCN2
C     ETIME      I   STSF2, STSEP2
C     FRAME     I/O  STSF2, STCRD2, STINF2
C     FOVTYP     I   STSF2
C     BSIGHT     I   STSF2
C     NSIDES     I   STSF2
C     VERTIC     I   STSF2
C     R          I   STCHF2
C     IBAND      I   STGZ2
C     IZONES     I   STGR2
C     IFLD       I   STGL2
C     TABNO      I   STGL2
C     N_RET      O   STGL2
C     OK         O   STCHC2, STCHL2
C     WITHIN     O   STCHF2
C     IOUT       O   STRFI2
C     DOUT       O   STRFD2
C     COUT       O   STRFC2
C     FOUND      O   STRFI2, STRFC2, STRFD2, STCHN2
C     RA         O   STCRD2
C     DEC        O   STCRD2
C     NRINDX     O   STINF2
C     INDXED     O   STINF2
C     FOVSET     O   STINF2
C     NCNSTR     O   STINF2
C     NOB        O   STINF2
C     IBAND1     O   STGB2
C     IBAND2     O   STGB2
C     IZONE1     O   STGZ2
C     IZONE2     O   STGZ2
C     RECNO1     O   STGR2
C     RECNO2     O   STGR2
C     INDEX1     O   STGL2
C     INDEX2     O   STGL2
C     ACTION     I   STSSS2
C     STATUS    I/O  STSSS2
C
C$ Detailed_Input
C
C     See entry point headers.
C
C$ Detailed_Output
C
C     See entry point headers.
C
C$ Parameters
C
C     NZMAX          is maximal number of elementary zones onto the
C                    celestial sphere. It depends on the only argument:
C                    the number of declination bands. Below there is a
C                    table that shows how the elementary zone height
C                    DELDEC and the number of elementary zones
C                    NZONES depend on the number of declination
C                    bands NBANDS:
C
C                     NBANDS          DELDEC       NZONES
C
C                        30              6           1144
C                        45              4           2576
C                        60              3           4584
C                        90              2          10312
C                       180              1          41252
C                       360            0.5         165016
C
C     NNMAX          is maximal number of elements in so-called "node
C                    sequence" (see SPICE Catalog Design) to provide
C                    fast access to indexed parameter of the catalog
C                    object.
C
C$ Particulars
C
C     CATMGR is an umbrella routine for its entry points:  all
C     variables used by the entry points are declared here.
C
C     CATMGR supports loading and unloading SPICE Catalog files,
C     access data of different kind, setting and erasing constraints
C     for data filtering, setting FOV parameters, epochs etc.
C     The entry points and their functions are:
C
C        Catalog loading and unloading:
C
C           STLD2  ( load catalog   )
C           STULD2 ( unload catalog )
C
C        Data extraction:
C
C           STREC2 ( get certain record and unpack it            )
C           STRFC2 ( read certain text data from given record    )
C           STRFI2 ( read certain integer data from given record )
C           STRFD2 ( read certain DP data from given record      )
C           STCRD2 ( compute RA and DEC for given record         )
C
C        Setting parameters:
C
C           STSEP2 ( set epoch for star positions )
C           STSF2  ( set FOV parameters           )
C           STSCN2 ( set numerical constraints    )
C           STSCC2 ( set "character" constraints  )
C           STCLC2 ( clear all constraints        )
C           STRF2  ( set "fast mode" of reading   )
C           STSSS2 ( get/set search/fetch status  )
C
C        Utilities:
C
C           STGB2  ( compute DEC bands range for FOV       )
C           STGZ2  ( compute zones range for given band    )
C           STGR2  ( compute rec # range for given zone    )
C           STCHC2 ( check whether all constraints are met )
C           STCHF2 ( check whether an object is within FOV )
C           STBOX2 ( get RA-DEC box around FOV             )
C           STGL2  ( get objects met one field constraints )
C           STINF2 ( provide information to fetch data     )
C           STCHL2 ( check whether a catalog is loaded     )
C
C        Summary:
C
C           STGCD2 ( get the catalog description           )
C           STFIN2 ( get the fields information            )
C           STFLD2 ( get the field description             )
C           STNFA2 ( get attributes for numerical field    )
C           STCFA2 ( get attributes for text field         )
C           STZSZ2 ( get size of a zone in declination     )
C           STZAT2 ( get information about elem. zones     )
C
C$ Examples
C
C     Assume that we have generated DAS file with SPICE catalog and
C     the filename is ARIEL.CAT. Below is a piece of program calling
C     ACCESS entries.
C     ............................begin-piece-of-program........
C
C     CALL TOSTDO ( '................ DATA ACCESS test ..............' )
C     CALL STLOAD ( 'ARIEL.CAT' )
C
C     I = 6
C     CALL STGFC ( I, 'ARIEL_NAME', STRING, FOUND )
C     CALL REPMI ( 'Record number #','#', I, LINE )
C     CALL TOSTDO ( LINE )
C     IF ( FOUND ) THEN
C          CALL TOSTDO ( '   ARIEL_NAME: '//STRING )
C     ELSE
C          CALL TOSTDO ( '   The field is not found')
C     END IF
C
C     I = 2
C     CALL STGFC ( I, 'POS_CODE', STRING, FOUND )
C     CALL REPMI ( 'Record number #','#', I, LINE )
C     CALL TOSTDO ( LINE )
C     IF ( FOUND ) THEN
C          CALL TOSTDO ( '   POS_CODE: '//STRING )
C     ELSE
C          CALL TOSTDO ( '   The field is not found')
C     END IF
C
C     I=4
C     CALL STGFD ( I, 'AV_FLUX', A, FOUND )
C     CALL REPMI ( 'Record number #','#', I, LINE )
C     CALL TOSTDO ( LINE )
C     IF ( FOUND ) THEN
C          CALL REPMD ( '    AV_FLUX = #','#', A, 10, LINE )
C          CALL TOSTDO ( LINE )
C     ELSE
C          CALL TOSTDO ( '   The field is not found')
C     END IF
C
C     I=2
C     CALL STGRD ( I, 'B1950', RA, DEC )
C     CALL REPMI ( 'Record number #','#', I, LINE )
C     CALL TOSTDO ( LINE )
C     CALL REPMD ( '   RA, DEC:  #, #','#', RA/RPD(), 10, LINE )
C     CALL REPMD ( LINE,'#', DEC/RPD(), 10, LINE )
C     CALL TOSTDO ( LINE )
C
C     CALL STSCN ( 'MAX_FLUX', 'GE',  37.D0 )
C     CALL STSCN ( 'MAX_FLUX', 'LE', 145.D0 )
C
C     CALL TOSTDO ( ' ' )
C     CALL TOSTDO ( 'Now we have set constraints for MAX_FLUX' )
C     CALL TOSTDO ( 'FETCH results:' )
C
C     MAXIM = 1000
C     N = 1
C     DO WHILE ( N .GT. 0 )
C        CALL STFTCH ( MAXIM, N, LIST )
C        IF ( N .GT. 0 ) THEN
C           CALL REPMI ( 'Returned number #','#', N, LINE )
C           CALL TOSTDO ( LINE )
C           PRINT '(20I4)', ( LIST(I), I = 1, N )
C        END IF
C     END DO
C
C     CALL STSCN ( 'MIN_FLUX', 'GE',  20.D0 )
C     CALL STSCN ( 'MIN_FLUX', 'LE',  45.D0 )
C
C     CALL TOSTDO ( ' ' )
C     CALL TOSTDO ( 'Now we have set constraints for MIN_FLUX' )
C     CALL TOSTDO ( 'FETCH results:' )
C
C     MAXIM = 400
C     N = 1
C     DO WHILE ( N .GT. 0 )
C        CALL STFTCH ( MAXIM, N, LIST )
C        IF ( N .GT. 0 ) THEN
C           CALL REPMI ( 'Returned number #','#', N, LINE )
C           CALL TOSTDO ( LINE )
C           PRINT '(20I4)', ( LIST(I), I = 1, N )
C        END IF
C     END DO
C
C     ETIME = 0D0
C     FRAME = 'B1950'
C     FOVTYP = 'CIRCLE'
C     NSIDES = 1
C     CALL LATREC ( 1D0, 0D0, HALFPI(), BSIGHT )
C     CALL LATREC ( 1D0, 0D0, 0d0, VERTIC )
C     CALL STSFOV ( ETIME, FRAME, FOVTYP, BSIGHT, NSIDES, VERTIC )
C
C     CALL TOSTDO ( ' ' )
C     CALL TOSTDO ( 'Now we have set FOV parameters' )
C     CALL TOSTDO ( 'FETCH results:' )
C
C     N = 1
C     DO WHILE ( N .GT. 0 )
C        CALL STFTCH ( MAXIM, N, LIST )
C        IF ( N .GT. 0 ) THEN
C           CALL REPMI ( 'Returned number #','#', N, LINE )
C           CALL TOSTDO ( LINE )
C           PRINT '(20I4)', ( LIST(I), I = 1, N )
C        END IF
C     END DO
C
C     CALL TOSTDO ( 'Normal termination. Bye...' )
C     CALL STUNLD
C
C     ............................end-piece-of-program........
C
C     The results of the program running are as follows:
C__________________________________________________________________
C
C     ................ DATA ACCESS test ..............
C     Record number 6
C        ARIEL_NAME: 3A0241+622
C     Record number 2
C        POS_CODE: X-RAY
C     Record number 5
C        IDENT:    STAR?
C     Record number 10
C         MIN_FLUX_ER = 3.200000000E-01
C     Record number 10
C         MAX_FLUX_ER = 5.600000000E-01
C     Record number 4
C         AV_FLUX = 1.100000000E+00
C     Record number 2
C        RA, DEC:  5.600000024E+00, 6.388000001E+01
C
C     Now we have set constraints for MAX_FLUX
C     FETCH results:
C     Returned number 17
C      42 209 136 176 238 237 206 207  95 201 137  92 234 199 135 210  50
C
C     Now we have set constraints for MIN_FLUX
C     FETCH results:
C     Returned number 6
C     136 209 210  50 199 207
C
C     Now we have set FOV parameters
C     FETCH results:
C     Returned number 1
C      50
C     Normal termination. Bye...
C__________________________________________________________________
C
C$ Restrictions
C
C     TBD
C
C$ Literature_References
C
C     TBD
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB pre-release Version 1.0.1, 20-JAN-2000 (VNK)
C
C-&

C$ Index_Entries
C
C     Manage Catalog data access operations
C
C-&

C
C     SPICELIB functions
C
      INTEGER               ESRCHC
      INTEGER               RTRIM
      DOUBLE PRECISION      VTMV
      DOUBLE PRECISION      VDOT
      DOUBLE PRECISION      PI
      DOUBLE PRECISION      HALFPI
      DOUBLE PRECISION      TWOPI
      DOUBLE PRECISION      RPD
      DOUBLE PRECISION      JYEAR
      LOGICAL               RETURN
      LOGICAL               EQSTR

C
C     Local parameters
C
      INTEGER               LLINSZ
      PARAMETER           ( LLINSZ = 256 )

C
C     Local variables.
C
C     General information
C
      CHARACTER*(CATNLN)    CATNAM
      CHARACTER*(OBJTLN)    OBTYPE
      INTEGER               NOBJ
      CHARACTER*(FRMNLN)    CFRAME
      CHARACTER*(FRMNLN)    FRAM
      CHARACTER*(FRMNLN)    FRAMPR
      DOUBLE PRECISION      MATRIX (3,3)
      DOUBLE PRECISION      PMSCAL (2)
      DOUBLE PRECISION      ETFPR

C
C     Fields
C
      INTEGER               NFLDS
      INTEGER               NMAIN
      CHARACTER*(FLDNLN)    FLDNAM (NFLMAX)
      CHARACTER*(FLDCLN)    FLDCLS (NFLMAX)
      INTEGER               FLTYPE (NFLMAX)
      INTEGER               FLDIND (NFLMAX)
      DOUBLE PRECISION      MINVAL (NFLMAX)
      INTEGER               MAXABS (NFLMAX)
      INTEGER               ACCUR  (NFLMAX)
      INTEGER               TXTBEG (NFLMAX)
      INTEGER               NMFLDS (NFLMAX)
      INTEGER               TMFLDS (NFLMAX)
      INTEGER               DENS   (NFLMAX)
      CHARACTER*(TFVMAX)    FLDPRF (NFLMAX)
      INTEGER               FLDBPS (NFLMAX)
      INTEGER               NPKNUM
      INTEGER               NPKTXT
      INTEGER               NNUMM
      INTEGER               NTXTM
      INTEGER               MRECL
      INTEGER               MASK
      INTEGER               NNUMA
      INTEGER               NTXTA
      INTEGER               TAFLDS (NFAMAX)
      INTEGER               NAFLDS (NFAMAX)
      INTEGER               DENAUX (NFAMAX)
      INTEGER               NINPOS
      INTEGER               NININT

C
C     Geometry
C
      INTEGER               NBANDS
      INTEGER               NZONES
      INTEGER               INPOS  (NZMAX)
      INTEGER               NINBND (NBMAX)
      INTEGER               NSUM   (NBMAX)
      DOUBLE PRECISION      DELDEC

C
C     Indexing
C
      INTEGER               NINDX
      INTEGER               LSTTAB (NFLMAX)
      INTEGER               NNODES (NFLMAX)
      INTEGER               NODES  (NNMAX)
      INTEGER               ININDX (NNMAX)

C
C     Addresses
C
      INTEGER               HANDLE
      INTEGER               BEGMAI
      INTEGER               BEGAUX
      INTEGER               BEGIND

C
C     EPOCHes
C
      DOUBLE PRECISION      ETPOS
      DOUBLE PRECISION      ETFOV
      DOUBLE PRECISION      ETCAT
      INTEGER               EPFLAG

C
C     FOV
C
      DOUBLE PRECISION      BORE   (3)
      DOUBLE PRECISION      RA1
      DOUBLE PRECISION      RA2
      DOUBLE PRECISION      DEC1
      DOUBLE PRECISION      DEC2
      DOUBLE PRECISION      R1     (3)
      DOUBLE PRECISION      S      (3)
      DOUBLE PRECISION      T      (3)
      DOUBLE PRECISION      MAT    (3,3)
      DOUBLE PRECISION      M1     (3,3)
      DOUBLE PRECISION      M2     (3,3)
      DOUBLE PRECISION      M3     (3,3)
      DOUBLE PRECISION      VERT   (3,NVRMAX)
      DOUBLE PRECISION      NORM   (3,NVRMAX)
      DOUBLE PRECISION      D
      DOUBLE PRECISION      A
      DOUBLE PRECISION      B
      DOUBLE PRECISION      COSALP
      DOUBLE PRECISION      ALPHA
      DOUBLE PRECISION      M6X6   (6,6)
      INTEGER               NVERT
      CHARACTER*(FOVTLN)    FOV

C
C     CONSTRAINTS
C
      CHARACTER*(TFVMAX)    STRING
      INTEGER               FLDPAR (2,NFLMAX)
      INTEGER               A1
      INTEGER               A2
      INTEGER               NCONST
      INTEGER               CTRREL ( NFLMAX )
      CHARACTER*(TFVMAX)    CTRCVL ( NFLMAX )
      INTEGER               CTRNLB ( NFLMAX )
      INTEGER               CTRNUB ( NFLMAX )
      LOGICAL               CTRFLG ( NFLMAX )

C
C     Catalog features description
C
      INTEGER               MISS   (NFLMAX)

C
C     Accumulated common prefix and its size
C
      INTEGER                    PRFSIZ
      CHARACTER*(NFLMAX*TFVMAX)  PRFVAL

C
C     Miscellaneous
C
      INTEGER               RECLST
      INTEGER               Z      (NFLMAX*(TFVMAX/NCHARI+1))
      INTEGER               PACKED (NFLMAX)
      INTEGER               ARR    (NFLMAX)
      INTEGER               VALUE  (NFLMAX)
      CHARACTER*(TFVMAX)    NAM
      CHARACTER*(TFVMAX)    REL
      CHARACTER*(TFVMAX)    CNST

      CHARACTER*(NFLMAX*TFVMAX) TEXT
      CHARACTER*(NFAMAX*TFVMAX) TXTAUX

      INTEGER               I
      INTEGER               I1
      INTEGER               I2
      INTEGER               J
      INTEGER               K
      INTEGER               L
**    INTEGER               LL
      INTEGER               M
      INTEGER               N
      INTEGER               NTEXT
      INTEGER               NZON
      INTEGER               NNUM
      INTEGER               ISTART
      INTEGER               IFIELD
      INTEGER               IPACK
      INTEGER               IZ
      INTEGER               ITHRGH
      INTEGER               NREST

      DOUBLE PRECISION      DELRA
      DOUBLE PRECISION      DELTA
      DOUBLE PRECISION      RA0
      DOUBLE PRECISION      DEC0
      DOUBLE PRECISION      RAI
      DOUBLE PRECISION      DECI
      CHARACTER*(LLINSZ)    ERROR
      LOGICAL               FAILED
      LOGICAL               ISDONE
      LOGICAL               ONLYMA
      LOGICAL               LOADED
      LOGICAL               KNOWN
      LOGICAL               SRCHST
      LOGICAL               BOXSET
      LOGICAL               GOOD

C
C     Save ALL local variables
C
      SAVE

C
C     Initial values
C
      DATA                  EPFLAG     / 0 /,
     .                      NCONST     / 0 /,
     .                      RECLST     / 0 /,
     .                      NREST      / -1 /,
     .                      LOADED     / .FALSE. /,
     .                      ISDONE     / .FALSE. /,
     .                      ONLYMA     / .FALSE. /,
     .                      SRCHST     / .FALSE. /,
     .                      BOXSET     / .FALSE. /

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STRMG2' )
      END IF

C
C     Never come here.
C
      CALL SIGERR ( 'SPICE(BOGUSENTRY)' )
      CALL CHKOUT ( 'STRMG2' )

      RETURN


C$Procedure STSEP2 ( set epoch for sky object positions )

      ENTRY STSEP2 ( ETIME )

C$ Abstract
C
C     Set epoch for which sky object positions will be computed.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     DOUBLE PRECISION      ETIME
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     ETIME      I   Epoch, ET
C
C$ Detailed_Input
C
C     ETIME          is the ephemeris time (seconds past J2000) for
C                    which the sky object positions will be returned.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     TBD
C
C     We shall deal with three different epochs:
C
C     - epoch ETCAT corresponding to the catalog positions
C
C     - user defined epoch ETPOS corresponding to desired star
C       positions
C
C     - user defined epoch ETFOV to obtain the FOV attitude with
C       respect to the catalog frame.
C
C     Let us consider a special flag EPFLAG presenting current
C     status of the epoch definition:
C
C     EPFLAG = 0  -  neither ETPOS nor ETFOV was set -- catalog epoch
C                    is used for both time as default value.
C
C                       * search done for catalog epoch ETCAT;
C                       * PMs not applied;
C                       * RA/DEC returned for catalog epoch ETCAT;
C
C     EPFLAG = 1  -  ETPOS was NOT set and ETFOV was set -- ETFOV value
C                    is assigned to ETPOS.
C
C                       * search done for ETFOV;
C                       * PMs applied for ETPOS (ETPOS = ETFOV);
C                       * RA/DEC returned for ETFOV;
C
C     EPFLAG = 2  -  ETPOS was set and ETFOV was NOT set -- ETPOS value
C                    is assigned to ETFOV.
C
C                       * search done for ETFOV (ETFOV = ETPOS);
C                       * PMs applied for ETPOS;
C                       * RA/DEC returned for ETFOV (ETFOV = ETPOS);
C
C     EPFLAG = 3  -  both ETPOS and ETFOV was set -- epochs can be
C                    different.
C
C                       * search done for ETFOV;
C                       * PMs applied for ETPOS;
C                       * RA/DEC returned for ETFOV;
C
C$ Example
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-JUL-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STSEP2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'   )
         CALL CHKOUT ( 'STSEP2'                      )
         RETURN
      END IF

C
C     Modify EPFLAG and define ETPOS.
C
      IF ( EPFLAG .LT. 2 ) THEN
         EPFLAG = EPFLAG + 2
      END IF

      ETPOS = ETIME

C
C     If ETFOV was not defined (using STSF2) prior to calling this
C     entry, set ETFOV to ETPOS (see Particulars in the header.)
C
      IF ( EPFLAG .EQ. 2 ) THEN
         ETFOV = ETPOS
      END IF

C
C     Re-set search/fetch state flag.
C
      SRCHST = .FALSE.

      CALL CHKOUT ( 'STSEP2' )

      RETURN


C$Procedure STCLC2 ( Clear all constraints )

      ENTRY STCLC2

C$ Abstract
C
C     Clear all the constarints that were set before.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C     None.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     Clear all the constraints set earlier by calls to STSCN2 and
C     STSCC2 by resetting NCONST and re-initializing all constraint
C     buffers -- FLDPAR, CTRNLB, CTRNUB, CTRREL, CTRCVL, CTRFLG.
C
C$ Example
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-JUL-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STCLC2' )
      END IF

C
C     Check whether the catalog is really loaded.
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STCLC2'                                   )
         RETURN
      END IF

      NCONST = 0

      DO J = 1, 2
         DO I = 1, NFLDS
            FLDPAR(J,I) = 0
         END DO
      END DO

      CALL CLEARI ( NFLDS, CTRNLB )
      CALL CLEARI ( NFLDS, CTRNUB )
      CALL CLEARI ( NFLDS, CTRREL )
      CALL CLEARC ( NFLDS, CTRCVL )

      DO I = 1, NFLMAX
         CTRFLG(I) = .TRUE.
      END DO


C
C     Reset position and FOV epochs.
C
      EPFLAG = 0
      ETPOS = ETCAT
      ETFOV = ETCAT

C
C     Reset flag indicating that RA/DECs of the box circumscribing
C     FOV were computed.
C
      BOXSET = .FALSE.

C
C     Re-set search/fetch state flag.
C
      SRCHST = .FALSE.

      CALL CHKOUT ( 'STCLC2' )

      RETURN


C$Procedure STSCN2 ( set constraint for numerical field )

      ENTRY STSCN2 ( NAME, LOGREL, VAL )

C$ Abstract
C
C     Set search constraint for a Type 2 sky catalog numerical field.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     CHARACTER*(*)         NAME
C     CHARACTER*(*)         LOGREL
C     DOUBLE PRECISION      VAL
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NAME       I   name of numerical field
C     LOGREL     I   text string presenting logical relation
C     VAL        I   numerical value to be used in comparison
C
C$ Detailed_Input
C
C     NAME           is a field ( parameter ) name to be limited
C                    by the constraint. The field must to be of
C                    numerical type.
C
C     LOGREL         is a character string that presents a logical
C                    relation ('GE', 'GT', 'LE', 'LT', 'EQ', 'NE',
C                    'NOT NULL', 'IS NULL')
C
C     VAL            is numerical value of constraint to compare
C                    with ( to set as constraint )
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C     2) If a field with the specified name does not exist in the
C        loaded catalog, then the error 'SPICE(FIELDDOESNTEXIST)'
C        will be signalled.
C
C     3) If the constraint type does not match the field type, then
C        the error 'SPICE(TYPEMISMATCH)' will be signalled.
C
C     4) If specified logical relation is not recognized, then the
C        error 'SPICE(UNSUPPORTRELATION)' will be signalled.
C
C     5) If specified constraint contradicts the previous one, then
C        the error 'SPICE(UNCONSTRAINTSCONTRADICT)' will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     TBD -- currently this routine allows combining new constraint
C            with earlier specified one. This behavious maybe be
C            desirable ... but not described anywhere.
C
C     To define constraint for the field NAME, containing numerical
C     parameter, the constraint is presented by logical relation
C     string LOGREL -- 'GE', 'GT', 'LE', 'LT', 'EQ', 'NE', 'NOT NULL',
C     'IS NULL' -- and double precision argument VAL.
C
C     The constraints defined though this routine are stored in the
C     following way. Three integer arrays contain the constraints
C     information:
C
C     CTRNLB - k-th element of the array is lower boundary for
C              the field value being set by constraint # k
C              (integer presentation for the boundary value)
C
C     CTRNUB - k-th element of the array is upper boundary for
C              the field value being set by constraint # k
C              (integer presentation for the boundary value)
C
C     CTRFLG - k-th element of the array specifies whether
C              constraint # k is meaningful with respect to the
C              constrained field range (.TRUE.) or meaningless
C              and, thus, resulting in "no-match" search return
C              (.FALSE.)
C
C     The table below presents conventions about CTRNLB and CTRNUB
C     generation for certain user defined arguments: logical relation
C     and number VAL. The VAL argument is converted to integer IVAL
C     by the following equation:
C
C     IVAL = MINVAL(I) + DBLE(MAXABS(I) + VALUE(I)) / 10**ACCUR(I)
C
C     +--------------------------------------------------------+
C     |  Logical relation |     CTRNLB       |     CTRNUB      |
C     |-------------------|------------------|-----------------|
C     |       GE          |       IVAL       |    MAXABS - 1   |
C     |-------------------|------------------|-----------------|
C     |       GT          |     IVAL + 1     |    MAXABS - 1   |
C     |-------------------|------------------|-----------------|
C     |       LE          |    - MAXABS      |      IVAL       |
C     |-------------------|------------------|-----------------|
C     |       LT          |    - MAXABS      |    IVAL - 1     |
C     |-------------------|------------------|-----------------|
C     |       EQ          |       IVAL       |      IVAL       |
C     |-------------------|------------------|-----------------|
C     |       NE          |       IVAL       |    IVAL - 1     |
C     |-------------------|------------------|-----------------|
C     |     NOT NULL      |    - MAXABS      |    MAXABS - 1   |
C     |-------------------|------------------|-----------------|
C     |      IS NULL      |      MAXABS      |     MAXABS      |
C     +--------------------------------------------------------+
C
C     One can see that for all cases of logical relations but 'NE'
C     CTRNLB and CTRNUB are boundaries of the tolerant interval
C     for the parameter.
C
C$ Example
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-JUL-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     set numeric constraint for type_2 sky_catalog search
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STSCN2' )
      END IF

C
C     Re-set search/fetch state flag if this routine was called.
C
      SRCHST = .FALSE.

C
C     Check whether the catalog is really loaded.
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STSCN2'                                   )
         RETURN
      END IF

C
C     "Comb" NAME and LOGREL to allow equality comparisons later.
C
      CALL STCMB2 ( .TRUE., NAME,   NAM )
      CALL STCMB2 ( .TRUE., LOGREL, REL )

C
C     Find the NAME field number.
C
      IFIELD = ESRCHC ( NAM, NFLDS, FLDNAM )

C
C     Check whether the field really exists.
C
      IF ( IFIELD .EQ. 0 ) THEN
         CALL DASHFN ( HANDLE, STRING )
         CALL SETMSG ( 'The field with the name ''#'' does not '     //
     .                 'exist in the loaded Type 2 catalog ''#''.'   )
         CALL ERRCH  ( '#', NAM                                      )
         CALL ERRCH  ( '#', STRING                                   )
         CALL SIGERR ( 'SPICE(FIELDDOESNTEXIST)'                     )
         CALL CHKOUT ( 'STSCN2'                                      )
         RETURN
      END IF

C
C     Check whether the field is of numerical type.
C
      IF ( FLTYPE(IFIELD) .EQ. 0 ) THEN
         CALL SETMSG ( 'The constraint type does not match the '     //
     .                 'field type.'                                 )
         CALL SIGERR ( 'SPICE(TYPEMISMATCH)'                         )
         CALL CHKOUT ( 'STSCN2'                                      )
         RETURN
      END IF

C
C     Check whether the field is already "restricted".
C
      K = 0
      DO J = 1, NCONST
         IF ( FLDPAR(1,J) .EQ. IFIELD ) THEN
            K = J
         END IF
      END DO

C
C     Check whether the constraint is not TOO wide ... i.e. constrains
C     anything at all :-)
C
      A = ( VAL - MINVAL(IFIELD) ) * 10**ACCUR(IFIELD) - MAXABS(IFIELD)

      IF ( (   A .LT. -MAXABS(IFIELD)       .AND.
     .       ( REL .EQ. 'GE'  .OR.
     .         REL .EQ. 'GT'  .OR.
     .         REL .EQ. 'NE'           )    .AND.
     .         MISS(IFIELD) .NE. 0               ) .OR.
     .     (   A .GT.  MAXABS(IFIELD)       .AND.
     .       ( REL .EQ. 'LE'  .OR.
     .         REL .EQ. 'LT'  .OR.
     .         REL .EQ. 'NE'           )    .AND.
     .         MISS(IFIELD) .NE. 0               ) .OR.
     .     (   EQSTR ( REL, 'NOT NULL' )    .AND.
     .         MISS(IFIELD) .EQ. 0 )                   ) THEN

C
C        Let's see if the field was restricted before.
C
         IF ( K .NE. 0 ) THEN

C
C           It looks like this field was constrained before. We
C           clear that previous constraint.
C
            IF ( K .NE. NCONST ) THEN

C
C              If our constrain is not the last on the list, we need to
C              shift all constraints after it towards the beginning of
C              the list.
C
               DO J = K, NCONST - 1

                  FLDPAR ( 1, J ) = FLDPAR ( 1, J+1 )
                  FLDPAR ( 2, J ) = FLDPAR ( 2, J+1 )
                  CTRFLG (    J ) = CTRFLG (    J+1 )
                  CTRREL (    J ) = CTRREL (    J+1 )
                  CTRCVL (    J ) = CTRCVL (    J+1 )
                  CTRNLB (    J ) = CTRNLB (    J+1 )
                  CTRNUB (    J ) = CTRNUB (    J+1 )

               END DO

            END IF

C
C           With or without shift, decrement the number of constraints.
C
            NCONST = NCONST - 1

         END IF

C
C        Leave the routine.
C
         CALL CHKOUT ( 'STSCN2' )
         RETURN

      END IF


C
C     Now if the field has been "restricted" before, K is index
C     of the restriction in the constraint buffers. Otherwise K = 0.
C
      IF ( K .EQ. 0 ) THEN

C
C        Increment the number of constraints and save field number
C        and type to FLDPAR array.
C
         NCONST = NCONST + 1
         FLDPAR ( 1, NCONST ) = IFIELD
         FLDPAR ( 2, NCONST ) = FLTYPE(IFIELD)
         K  =  NCONST

C
C        Also, initialize constraint boundaries.
C
         A1 = -MAXABS(IFIELD)
         A2 =  MAXABS(IFIELD) - 1

      ELSE

C
C        Re-assign A1 and A2 to be the previously set constraint
C        boundaries .
C
         A1 = CTRNLB ( K )
         A2 = CTRNUB ( K )

C
C        ... and discard them if constraint was 'EQ', 'NE' or
C        'IS NULL' :-)
C
         IF ( A1 .GE. A2 ) THEN
            A1 = -MAXABS(IFIELD)
            A2 =  MAXABS(IFIELD) - 1
         END IF

      END IF

C
C     Check whether the constraint makes sense in context of our
C     field range and absense/presense of NULLs.
C
      IF ( (   A .LT. -MAXABS(IFIELD) .AND.
     .       ( REL .EQ. 'LE' .OR.
     .         REL .EQ. 'LT' .OR.
     .         REL .EQ. 'EQ'       )    ) .OR.
     .     (   A .GT.  MAXABS(IFIELD) .AND.
     .       ( REL .EQ. 'GE' .OR.
     .         REL .EQ. 'GT' .OR.
     .         REL .EQ. 'EQ'       )    ) .OR.
     .     (   MISS(IFIELD) .EQ. 0     .AND.
     .         EQSTR ( REL, 'IS NULL' ) )      ) THEN

C
C        There is contradiction between the constraint and common
C        sense. We do our best to hold indignation and set CTRFLG(K)
C        flag to .FALSE. (to indicate meaningless and resultless
C        constraint.) We also set field boundaries to default "match
C        all" values. The CTRFLG(K) will be checked later, when basic
C        information required for fetch will be returned via STINF2.
C
         CTRFLG ( K ) = .FALSE.
         CTRNLB ( K ) = -MAXABS(IFIELD)
         CTRNUB ( K ) =  MAXABS(IFIELD) - 1

         CALL CHKOUT ( 'STSCN2' )
         RETURN

      ELSE

C
C        Set flag to indicate meaningful and potentially resultful
C        constraint and proceed ahead.
C
         CTRFLG ( K ) = .TRUE.

      END IF

C
C     Define A1 and A2 in accordance to the table above.
C
      I1 = A + DSIGN ( .5D0, A )

      IF ( REL .EQ. 'LE' ) THEN

         A2 = I1

C
C        If the current constraint contradicts the one that was
C        set before, discard that previous constraint
C
         IF ( A1 .GT. A2 ) THEN
            A1 = -MAXABS(IFIELD)
         END IF

      ELSE IF ( REL .EQ. 'LT' ) THEN

         A2 = I1 - 1

C
C        If the current constraint contradicts the one that was
C        set before, discard that previous constraint
C
         IF ( A1 .GT. A2 ) THEN
            A1 = -MAXABS(IFIELD)
         END IF

      ELSE IF ( REL .EQ. 'GE' ) THEN

         A1 = I1

C
C        If the current constraint contradicts the one that was
C        set before, discard that previous constraint
C
         IF ( A1 .GT. A2 ) THEN
            A2 = MAXABS(IFIELD) - 1
         END IF

      ELSE IF ( REL .EQ. 'GT' ) THEN

         A1 = I1 + 1

C
C        If the current constraint contradicts the one that was
C        set before, discard that previous constraint
C
         IF ( A1 .GT. A2 ) THEN
            A2 = MAXABS(IFIELD) - 1
         END IF

      ELSE IF ( REL .EQ. 'EQ' ) THEN

         A1 = I1
         A2 = A1

      ELSE IF ( REL .EQ. 'NE' ) THEN

         A1 = I1
         A2 = A1 - 1

      ELSE IF ( EQSTR ( REL, 'IS NULL'  ) ) THEN

         A1 = MAXABS(IFIELD)
         A2 = MAXABS(IFIELD)

      ELSE IF ( EQSTR ( REL, 'NOT NULL' ) ) THEN

C
C        In this case we don't need to reassign A1/A2 -- they already
C        set to be boundaries of the filed range.
C

      ELSE

         CALL SETMSG ( 'Logical relation ''#'' is not supported for '//
     .                 'numeric fields.'                             )
         CALL ERRCH  ( '#', REL                                      )
         CALL SIGERR ( 'SPICE(UNSUPPORTRELATION)'                  )
         CALL CHKOUT ( 'STSCN2' )
         RETURN

      END IF

C
C     Save A1 and A2 to the constraint boundaries arrays.
C
      CTRNLB ( K ) = A1
      CTRNUB ( K ) = A2

      CALL CHKOUT ( 'STSCN2' )

      RETURN


C$Procedure STSCC2 ( set constraint for character field )

      ENTRY STSCC2 ( NAME, LOGREL, CONSTR )

C$ Abstract
C
C     Set search constraint for a loaded sky catalog character field.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     CHARACTER*(*)         NAME
C     CHARACTER*(*)         LOGREL
C     CHARACTER*(*)         CONSTR
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NAME       I   name of field containing numerical parameter
C     LOGREL     I   text string presenting logical relation
C     CONSTR     I   text string presenting constraint itself
C
C$ Detailed_Input
C
C     NAME           is a field name to be limited by the constraint.
C                    The field is to be of character type.
C
C     LOGREL         is a character string that presents a logical
C                    relation ('LIKE', 'EQ', 'NE', 'NOT NULL',
C                    'IS NULL')
C
C     CONSTR         is a character string that presents a type of
C                    limitation for certain field.
C
C                    This value is left-justified, stripped off
C                    non-printing characters and uppercased before it
C                    is buffered.
C
C                    For LOGREL='LIKE' if CONSTR contains '*', then
C                    only characters preceding it are matched to the
C                    beginning of the field values; if CONSTR doesn't
C                    contain '*' then the whole CONSTR is matched to
C                    the beginning of the field values.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C     2) If a field with the specified name does not exist in the
C        loaded catalog, then the error 'SPICE(FIELDDOESNTEXIST)'
C        will be signalled.
C
C     3) If the constraint type does not match the field type, then
C        the error 'SPICE(TYPEMISMATCH)' will be signalled.
C
C     4) If specified logical relation is not recognized, then the
C        error 'SPICE(UNSUPPORTRELATION)' will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     TBD -- this maybe OK, but needs careful review 
C
C     To define constraint for the field NAME, containing character
C     parameter, the constraint is presented by logical relation
C     string LOGREL ('LIKE', 'EQ', 'NE', 'NOT NULL', 'IS NULL') and
C     character string CONSTR.
C
C     The constraints defined are stored in two arrays CTRREL and
C     CTRCVL. The CTRFLG array contains flag specifying whether the
C     constraint is meaningful and fetch/search with this constraint can
C     potentially bring some results. The only case which
C     deterministically brings no result is searching for NULLs in field
C     which doesn't contain any of them. Then CTRFLG is set to .FALSE.
C
C     The CTRREL contains codes of the logical relation flags:
C
C     +----------------------------------------+
C     |  Logical relation |      CTRREL        |
C     |-------------------|--------------------|
C     |      LIKE         |         0          |
C     |-------------------|--------------------|
C     |      EQ           |         1          |
C     |-------------------|--------------------|
C     |      NE           |         2          |
C     |-------------------|--------------------|
C     |      NOT NULL     |         3          |
C     |-------------------|--------------------|
C     |      IS NULL      |         4          |
C     +----------------------------------------+
C
C     The array CTRCVL for relations 'LIKE', 'EQ', 'NE' contains
C     the value against which the character field will be checked.
C
C     In case of 'LIKE' the value of CTRCVL can be truncated and
C     terminated by the asterisk.
C
C     In case of 'NOT NULL' and 'NULL', the CTRCVL is not used.
C
C     CTRCVL values are left-justified, stripped off non-printing
C     characters and uppercased.
C  
C$ Example
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-JUL-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     set character constrain for type_2 sky_catalog search
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STSCC2' )
      END IF

C
C     Re-set search/fetch state flag if this routine was called.
C
      SRCHST = .FALSE.

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior '     //
     .                 'calling this routine.'                       )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                   )
         CALL CHKOUT ( 'STSCC2'                                      )
         RETURN
      END IF

C
C     "Comb" NAME, LOGREL and CONSTR to allow equality comparisons
C     later.
C
      CALL STCMB2 ( .TRUE., NAME,   NAM  )
      CALL STCMB2 ( .TRUE., LOGREL, REL  )
      CALL STCMB2 ( .TRUE., CONSTR, CNST )

C
C     Find the index of the field.
C
      IFIELD = ESRCHC ( NAM, NFLDS, FLDNAM )

C
C     Check whether the field exists in the loaded catalog.
C
      IF ( IFIELD .EQ. 0 ) THEN
         CALL DASHFN ( HANDLE, STRING )
         CALL SETMSG ( 'The field with the name ''#'' does not '     //
     .                 'exist in the loaded Type 2 catalog ''#''.'   )
         CALL ERRCH  ( '#', NAM                                      )
         CALL ERRCH  ( '#', STRING                                   )
         CALL SIGERR ( 'SPICE(FIELDDOESNTEXIST)'                     )
         CALL CHKOUT ( 'STSCC2'                                      )
         RETURN
      END IF

C
C     Check whether the field is of character type.
C
      IF ( FLTYPE(IFIELD) .NE. 0 ) THEN
         CALL SETMSG ( 'The constraint type does not match the '     //
     .                 'field type.'                                 )
         CALL SIGERR ( 'SPICE(TYPEMISMATCH)'                         )
         CALL CHKOUT ( 'STSCC2'                                      )
         RETURN
      END IF

C
C     Check whether the field is already "restricted".
C
      K = 0

      DO J = 1, NCONST
         IF ( FLDPAR(1,J) .EQ. IFIELD ) THEN
            K = J
         END IF
      END DO

C
C     Let I1 stands for meaningful size of CONSTR
C
      I1 = RTRIM ( CNST )
      J  = INDEX ( CNST, '*' )

C
C     If this field has common prefix, check how its size compares to
C     the size of the significant part of the constraint.
C
      IF ( ( FLDBPS( IFIELD ) .GT. 1 ) .AND.
     .     ( LOGREL .EQ. 'LIKE' )      .AND. 
     .     ( J .NE. 0 )                      ) THEN

         I1 = MAX0 ( J - 1, 1 )
         I2 = MIN0 ( FLDBPS(IFIELD) - 1, I1 )

      ELSE

         I2 = I1

      END IF

C
C     Check whether the constraint is TOO wide ... i.e. constrains
C     nothing at all :-) It can be too wide if it is:
C
C       'NOT NULL' for field that doesn't contain any NULLs;
C
C       'LIKE '*str'' for field that doesn't contain any NULLs;
C
C       'NE 'str'' for the field with common prefix not equal to 'str'
C       and no NULLs;
C
C       'LIKE 'str*'' for the field with common prefix equal to 'str'
C       and no NULLs;
C
      IF ( ( EQSTR ( REL, 'NOT NULL' )               .AND.
     .       MISS  ( IFIELD ) .EQ. 0                      ) .OR.
     .     ( INDEX ( CNST, '*' ) .EQ. 1              .AND.
     .       REL .EQ. 'LIKE'                         .AND.
     .       MISS  ( IFIELD ) .EQ. 0                      ) .OR.
     .     ( I1 .LT. FLDBPS(IFIELD)                  .AND.
     .       CNST(1:I2) .NE. FLDPRF(IFIELD)(1:I2)    .AND.
     .       REL .EQ. 'NE'                           .AND.
     .       MISS  ( IFIELD ) .EQ. 0                      ) .OR.
     .     ( I1 .LT. FLDBPS(IFIELD)                  .AND.
     .       CNST(1:I2) .EQ. FLDPRF(IFIELD)(1:I2)    .AND.
     .       REL .EQ. 'LIKE'                         .AND.
     .       MISS  ( IFIELD ) .EQ. 0                      )     ) THEN

C
C        Let's see if the field was restricted before.
C
         IF ( K .NE. 0 ) THEN

C
C           It looks like this field was constrained before. We
C           clear that previous constraint.
C
            IF ( K .NE. NCONST ) THEN

C
C              If our constrain is not the last on the list, we need to
C              shift all constraints after it towards the beginning of
C              the list.
C
               DO J = K, NCONST - 1

                  FLDPAR ( 1, J ) = FLDPAR ( 1, J+1 )
                  FLDPAR ( 2, J ) = FLDPAR ( 2, J+1 )
                  CTRFLG (    J ) = CTRFLG (    J+1 )
                  CTRREL (    J ) = CTRREL (    J+1 )
                  CTRCVL (    J ) = CTRCVL (    J+1 )
                  CTRNLB (    J ) = CTRNLB (    J+1 )
                  CTRNUB (    J ) = CTRNUB (    J+1 )

               END DO

            END IF

C
C           With or without shift, decrement the number of constraints.
C
            NCONST = NCONST - 1

         END IF

C
C        Leave the routine.
C
         CALL CHKOUT ( 'STSCC2' )
         RETURN

      END IF

C
C     Now when we know that constraint really constrains something, we
C     can check whether it's for a field that is already constrained.
C
      IF ( K .EQ. 0 ) THEN

C
C        Increment the number of constraints and save field number
C        and type in FLDPAR array.
C
         NCONST = NCONST + 1
         FLDPAR( 1, NCONST ) = IFIELD
         FLDPAR( 2, NCONST ) = FLTYPE(IFIELD)
         K = NCONST

      END IF

C
C     Now we can check whether search will bring any results or not.
C     It will not if constraint is:
C
C       'EQ' and common prefix is not equal to constraint value;
C
C       'LIKE' and common prefix is not equal to constraint value;
C
C       'IS NULL' and field doesn't have NULLs;
C
      IF ( ( FLDBPS(IFIELD) .GT. 1                  .AND.
     .       CNST(1:I2) .NE. FLDPRF(IFIELD)(1:I2)   .AND.
     .       REL .EQ. 'EQ'                               ) .OR.
     .     ( FLDBPS(IFIELD) .GT. 1                  .AND.
     .       CNST(1:I2) .NE. FLDPRF(IFIELD)(1:I2)   .AND.
     .       REL .EQ. 'LIKE'                             ) .OR.
     .     ( MISS ( IFIELD ) .EQ. 0                 .AND.
     .       EQSTR( REL, 'IS NULL' )                     )     ) THEN

C
C        No sense to do search when we know that it will return
C        nothing. Raise the flag and leave.
C
         CTRFLG ( K ) = .FALSE.
         CALL CHKOUT ( 'STSCC2' )
         RETURN

      END IF

C
C     Save contraint.
C
      CTRCVL ( K ) = ' '
      CTRFLG ( K ) = .TRUE.

      IF ( REL .EQ. 'LIKE' ) THEN

         CTRREL ( K ) = 0

C
C        The task is to select the first part of the CONSTR string up
C        to '*' symbol.
C
         J = INDEX ( CNST, '*' )

         IF      ( J .GT. 1 ) THEN

C
C           This is a normal case when CONTSR looked like this 'XXXX*'.
C           We chop off the '*' and mememorize 'XXXX' for value checks.
C
            CTRCVL ( K ) = CNST(1:J-1)

         ELSE IF ( J .EQ. 1 ) THEN

C
C           This is a very special case -- the '*' was the first
C           character (i.e. in our convention means 'matches all') but
C           the field contains NULLs ... and NULLs by definition don't
C           match any contraint. So all we need to do is to reset
C           contraint type to be 'NOT NULL'.
C
            CTRREL ( K ) = 3

         ELSE

C
C           This is another normal case but CONTSR looked like this
C           'XXXX' because "lazy" user forgot add '*'. So, we simply
C           mememorize 'XXXX' for value checks.
C
            CTRCVL ( K ) = CNST

         END IF

      ELSE IF ( REL .EQ. 'EQ' ) THEN

         CTRREL ( K ) = 1
         CTRCVL ( K ) = CNST

      ELSE IF ( REL .EQ. 'NE' ) THEN

         CTRREL ( K ) = 2
         CTRCVL ( K ) = CNST

      ELSE IF ( EQSTR( REL, 'NOT NULL' ) ) THEN

         CTRREL ( K ) = 3

      ELSE IF ( EQSTR( REL, 'IS NULL' ) ) THEN

         CTRREL ( K ) = 4

      ELSE

         CALL SETMSG ( 'Logical relation ''#'' is not supported for '//
     .                 'character fields.'                           )
         CALL ERRCH  ( '#', REL                                      )
         CALL SIGERR ( 'SPICE(UNSUPPORTRELATION)'                  )
         CALL CHKOUT ( 'STSCC2'                                      )
         RETURN

      END IF

      CALL CHKOUT ( 'STSCC2' )

      RETURN


C$Procedure STGL2 ( get range of indexes for certain constraint )

      ENTRY STGL2 ( IFLD, TABNO, INDEX1, INDEX2 )

C$ Abstract
C
C     Get range of INDEX TABLE indexes covering all sky objects
C     in the catalog that should be checked against constraint for
C     a given indexed field.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               IFLD
C     INTEGER               TABNO
C     INTEGER               INDEX1
C     INTEGER               INDEX2
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     IFLD       I   field number to be scanned
C     TABNO      I   Index Table number to be used for filtering
C     INDEX1     O   DAS address of the first element to be examined
C     INDEX2     O   DAS address of the last element to be examined
C
C$ Detailed_Input
C
C     IFLD           is field number to be scanned through all the
C                    catalog to make a list of objects that satisfy
C                    given constraints
C
C     TABNO          is Index Table number used to make a list of
C                    objects that satisfy given constraints
C
C$ Detailed_Output
C
C     INDEX1         is the DAS address of the tables's first element
C                    to be examined.
C
C     INDEX2         is the DAS address of the tables's last element to
C                    be examined.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C     2) If no contraints were set prior to calling this routine, then
C        the error 'SPICE(NOCONTSTRAINTSSET)' will be signalled.
C
C     3) If field was not constrained prior to calling this routine,
C        then the error 'SPICE(FIELDNOTCONSTRAINED)'  will be signalled.
C
C     4) If the index table number is greater than the total number of
C        index tables, then the error 'SPICE(BADINDEXTABLENUMBER)' will
C        be signalled.
C
C     5) The constraint set for the field was outside the field value
C        range, then the error 'SPICE(FIELDTOOCONSTRAINED)' will
C        be signalled.
C
C     6) The computed start address is greater than end address at the
C        return frm this routine, then the error 'SPICE(INDEXTABLEBUG)'
C        will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     TBD --   need some description of what this routine does becasue
C              it's quite complex.
C
C$ Example
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C     Specified field must be indexed field and it must be contrained
C     by calling STSCN2 or STSCC2 entry before calling this routine.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-JUL-1999 (VNK)
C
C-&
C$ Index_Entries
C
C     return index range for constrained type_2 sky_catalog field
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STGL2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STGL2'                                    )
         RETURN
      END IF

C
C     Check whether any constraints were set prior to calling this
C     routine.
C
      IF ( NCONST .EQ. 0 ) THEN
         CALL SETMSG ( 'No contraints were set prior to calling ' //
     .                 'this routine.'                            )
         CALL SIGERR ( 'SPICE(NOCONTSTRAINTSSET)'                 )
         CALL CHKOUT ( 'STGL2'                                    )
         RETURN
      END IF

C
C     Remind that FLDPAR array contains field # and field type for
C     each constraint.
C
      J = 1
      DO WHILE ( IFLD .NE. FLDPAR(1,J) .AND. J .LE. NCONST )
         J = J + 1
      END DO

C
C     Check whether our field was constrained.
C
      IF ( J .GT. NCONST ) THEN
         CALL SETMSG ( 'Field # was not constrained prior to '    //
     .                 'calling this routine.'                    )
         CALL ERRINT ( '#', IFLD                                  )
         CALL SIGERR ( 'SPICE(FIELDNOTCONSTRAIND)'                )
         CALL CHKOUT ( 'STGL2'                                    )
         RETURN
      END IF

C
C     Check whether our field was constrained in such a way that a
C     search wouldn't bring any results.
C
      IF ( .NOT. CTRFLG(J) ) THEN
         CALL SETMSG ( 'The constraint set for the field # was '  //
     .                 'outside the field value range. This '     //
     .                 'routine must not be called in such cases.')
         CALL ERRINT ( '#', IFLD                                  )
         CALL SIGERR ( 'SPICE(FIELDTOOCONSTRAIND)'                )
         CALL CHKOUT ( 'STGL2'                                    )
         RETURN
      END IF

C
C     Another sanity check before we proceed -- whether index table
C     number is not greater than total number of index tables.
C
      IF ( TABNO .GT. NINDX ) THEN
         CALL SETMSG ( 'The index table number # is greater than '//
     .                 'the total number of index tables #.'      )
         CALL ERRINT ( '#', TABNO                                 )
         CALL ERRINT ( '#', NINDX                                 )
         CALL SIGERR ( 'SPICE(BADINDEXTABNUMBER)'                 )
         CALL CHKOUT ( 'STGL2'                                    )
         RETURN
      END IF

C
C     Fetch Node Auxiliary (Initial positions) Index Table ININDX
C     and Node sequence NODES. First, skip over TABNO-1 index tables
C     located before our table in the file.
C
      I1 = BEGIND
      DO K = 1, TABNO-1
         I1 = I1 + NOBJ + NNODES(K) * 2
      END DO

C
C     Now we have got ISTART - the address of the integer immediately
C     preceding our INDEX TABLE in Catalog file.
C
      ISTART = I1 - 1

C
C     Skip over main portion of our index table and read the node
C     indexes part of the auxiliary index table.
C
      I1 = ISTART + 1 + NOBJ

      M = NNODES( TABNO )

      I2 = I1 + M - 1
      CALL DASRDI ( HANDLE, I1, I2, ININDX )

C
C     Now read the node values part of the auxiliary index table.
C
      I1 = I2 + 1
      I2 = I1 + M - 1
      CALL DASRDI ( HANDLE, I1, I2, NODES )

C
C     Let's handle all special cases when we know exactly what part of
C     index table we should return without playing any games with
C     numbers. Till now we have figured out three case like this:
C
C     -- if the logical relation is 'NE' for both numerical and
C        text fields -- in these cases we simply have to check
C        against all records;
C
C     -- 'NOT NULL' and 'IS NULL' constraints for character fields
C        that contain NULLs -- in these cases we know what to do
C        becasue all NULL values in a character field index table -- if
C        they are any -- are at the beginning of the the main index
C        table (i.e. in the main table index range 1 .. ININDX(1)-1)
C        Note that extereme cases -- 'NOT NULL' and 'IS NULL' for
C        fields that don't have NULLs -- were taken care of in STSCC2.
C
C     Remind that J is the index of the constraint for our field.
C
      IF ( ( FLDPAR(2,J) .NE. 0          .AND.
     .       CTRNLB(J)   .GT. CTRNUB(J)        ) .OR.
     .     ( FLDPAR(2,J) .EQ. 0          .AND.
     .       CTRREL(J)   .EQ. 2                )      ) THEN

C
C        'NE' case -- give the whole table out!
C
         I1 = 1
         I2 = NOBJ

      ELSE IF ( FLDPAR (2,J) .EQ. 0 .AND. CTRREL ( J ) .EQ. 3 ) THEN

C
C        We have logical relation 'NOT NULL' for char fieeld. In this
C        case we are to return all the records in the index table
C        starting from ININDX(1) through the end.
C
         I1 = ININDX(1)
         I2 = NOBJ

      ELSE IF ( FLDPAR (2,J) .EQ. 0 .AND. CTRREL ( J ) .EQ. 4 ) THEN

C
C        We have logical relation 'IS NULL' for char field. In the case
C        we are to return elements from the beginning through the
C        ININDX(1)-1.
C
         I1 = 1
         I2 = ININDX(1)-1

      ELSE

C
C        Well, it looks like we really need to determine what part
C        of the table we should return. First, let get the boundaries
C        of our constraint.
C
         IF ( FLDPAR (2,J) .NE. 0 ) THEN

C
C           We deal with numerical field. Let us get A1 and A2 that
C           are lower and upper boundaries.
C
            A1 = CTRNLB ( J )
            A2 = CTRNUB ( J )

         ELSE

C
C           We deal with text field. Using "key part of constraint
C           value" -- substring of CTRCVL(J) starting at FLDBPS(IFLD)
C           -- we generate integer boundaries corresponding to the
C           text. The length of the substring is computed EXACTLY the
C           same way as the lenght of the substrings that are stored in
C           the Node value table (see STWMG2, entry STWFW2.)
C
            TEXT = CTRCVL ( J ) ( FLDBPS(IFLD):    )
            K = MAX0 ( MIN0 (-MAXABS(IFLD)-FLDBPS(IFLD)+1, NCHARI),1)

C
C           Now we construct the integer boundaries corresponding to
C           our four-or-less char string TEXT. The lower boundary is
C           just integer coding of TEXT.
C
            CALL STT2I2 ( TEXT, K, A1, I )

C
C           The upper boundary is a result of integer coding of TEXT',
C           where TEXT' is generated from TEXT by changing the last
C           "considerable" byte by increasing its ASCII code by 1.
C
            I = ICHAR ( TEXT (K:K) )

            TEXT (K:K) = CHAR ( I + 1 )

            CALL STT2I2 ( TEXT, K, A2, I )

         END IF

C
C        Now we start our computations. Let us try to clarify our
C        task. Our key parameter X ( reduced to integer type ) is
C        to satisfy equation: A1 <= X <= A2. We need to find I1
C        and I2 values that provide:
C
C           NODES(I1-1) <  A1 <= NODES(I1)
C           NODES(I2-1) <= A2 <  NODES(I2)
C
C        Go ahead! Determine I1 - the lower boundary of the required
C        subset of corresponding INDEX_TAB array.
C
         K = 1

         IF      ( A1 .LE. NODES(1) ) THEN

C
C           Start with the very first record in the index table.
C
            I1 = 1

C
C           Except that for the text fields we may need to cut off
C           the very first bin because it contains NULLs.
C
            IF ( FLDPAR(2,J) .EQ. 0 .AND. MISS( IFLD ) .NE. 0 ) THEN
               I1 = ININDX(1)
            END IF

         ELSE IF ( A1 .GT. NODES(M) ) THEN

C
C           Look only at the last bin.
C
            I1 = ININDX(M)
            K  = M

         ELSE

C
C           Search for the right bin.
C
            DO WHILE ( A1 .GT. NODES(K) .AND. K .LE. M )
               K = K + 1
            END DO

C
C           We know that NODES(k) is exactly less than key parameter
C           for the first element in "k-th" interval (between NODES(k)
C           and NODES(k+1). Let we have NODES(k-1) < A1 <= NODES(k).
C           Then if A1 is less or equal to NODES(k), we need to start
C           with "k-1" interval:
C
            K = K - 1
            I1 = ININDX(K)

         END IF

C
C        Determine I2 - the upper boundary of the required subset of
C        corresponding INDEX_TAB array
C
         IF      ( A2 .GT. NODES(M) ) THEN

C
C           Look at the last bin.
C
            I2 = NOBJ

         ELSE IF ( A2 .LT. NODES(K+1) ) THEN

C
C           Look only in one bin -- ININDX(K) ... ININDX(K+1).
C
            I2 = ININDX(K+1)

         ELSE

C
C           Search for the right bin.
C
            DO WHILE ( A2 .GT. NODES(K) .AND. K .LE. M )
               K = K + 1
            END DO

            I2 = ININDX(K)

         END IF

      END IF

C
C     Form output values of boundary indexes INDEX1 and INDEX2.
C
      INDEX1 = ISTART + I1
      INDEX2 = ISTART + I2

C
C     Well, this sanity check is needed to catch major screw-up
C     right here, prior to leaving the routine.
C
      IF ( INDEX1 .GT. INDEX2 ) THEN
         CALL SETMSG ( 'Beginning address # of index table # '    //
     .                 'portion is greater than ending address '  //
     .                 '#. This may indicate bad index table in ' //
     .                 'the file or bug in the table processing ' //
     .                 'algorithm. Contact NAIF.'                 )
         CALL ERRINT ( '#', INDEX1                                )
         CALL ERRINT ( '#', TABNO                                 )
         CALL ERRINT ( '#', INDEX2                                )
         CALL SIGERR ( 'SPICE(INDEXTABLEBUG)'                     )
         CALL CHKOUT ( 'STGL2'                                    )
         RETURN
      END IF

      CALL CHKOUT ( 'STGL2' )

      RETURN


C$Procedure STCHC2 ( check whether all constraints are met )

      ENTRY STCHC2 ( OK )

C$ Abstract
C
C     Check whether all pre-defined constraints are met for the 
C     object buffered in the latest call to STREC2.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     LOGICAL               OK
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     OK         O   Flag indicating whether constrains are met or not
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     OK             is a flag indicating that all constrainst are 
C                    met for the object buffered by the latest call
C                    to STREC2.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     TBD -- need to augments this text with more details.
C
C     Upon entry this routine verifies whether we have any of the 
C     no-match constrains. 
C
C     If we do, output flag is set to FALSE and we return immediately. 
C
C     If we don't, we loop and check buffered values for each
C     contrained field against constraint for that field. If any of the
C     contraints is not met, we set flag to FALSE and get out.
C
C     Refer to the Particulars section of STSCC2 for the character
C     constraint boundary specififcation.
C
C     Refer to the Particulars section of STSCN2 for the numeric
C     constraint boundary specififcation.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     check constaints for buffered type_2 sky_catalog record
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STCHC2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STCHC2' )
         RETURN
      END IF

      OK = .TRUE.

C
C     Check whether any constraints were set at all. If not, the 
C     object is OK.
C
      IF ( NCONST .LT. 1 ) THEN
         CALL CHKOUT( 'STCHC2' )
         RETURN
      END IF

C
C     Check whether any of the constraints was of "no-result" kind.
C
      DO I = 1, NCONST
         IF ( .NOT. CTRFLG(I) ) THEN
            OK = .FALSE.
            CALL CHKOUT( 'STCHC2' )
            RETURN
         END IF
      END DO

C
C     Cycle for all the constraints that are set.
C
      K = 1

      DO I = 1, NCONST

C
C        Determine J that is field # for the constraint
C
         J = FLDPAR(1,I)

         IF ( FLDPAR(2,I) .EQ. 0 ) THEN

C
C           We deal with character parameter. Extract parameter value
C           from string buffer.
C
            I1 = TXTBEG(J)
            I2 = I1 - MAXABS(J) - 1
            STRING = TEXT(I1:I2)

C
C           Check for 'NOT NULL" and 'IS NULL' cases separately to save
C           on RTRIMs and UCASE.
C
            IF ( ( CTRREL(I) .EQ. 3 .AND. STRING .EQ. ' ' ) .OR.
     .           ( CTRREL(I) .EQ. 4 .AND. STRING .NE. ' ' )      )
     .      THEN
               OK = .FALSE.
               CALL CHKOUT( 'STCHC2' )
               RETURN
            END IF

C
C           Now process 'LIKE', EQ' and 'NE'. Get string sizes and
C           upppercase field value.
C
            I1 = RTRIM( CTRCVL(I) )
            I2 = MAX0( I1, RTRIM(STRING) )
            CALL UCASE( STRING(1:I2), STRING(1:I2) )

C
C           Start with LIKE case.
C
            IF ( ( STRING(1:I1) .NE. CTRCVL(I)(1:I1) .AND.
     .             CTRREL(I) .EQ. 0                        ) .OR.

C
C              Check EQ case.
C
     .           ( STRING(1:I2) .NE. CTRCVL(I)(1:I2) .AND.
     .             CTRREL(I) .EQ. 1                        ) .OR.
C
C              Check NE case.
C
     .           ( STRING(1:I2) .EQ. CTRCVL(I)(1:I2) .AND.
     .             CTRREL(I) .EQ. 2                        )      ) 

     .      THEN
               OK = .FALSE.
               CALL CHKOUT( 'STCHC2' )
               RETURN
            END IF

         ELSE

C
C           We deal with numerical parameter. Assign Boundary Values
C           A1, A2 and the parameter value K.
C
            A1 = CTRNLB(I)
            A2 = CTRNUB(I)
            K  = VALUE (J)

C
C           Check numeric contraints. Refer to the contraint 
C           specification detauls table in the Particulars section of 
C           STSCN2 header.
C
C           Start with GE, GT, LE, or LT cases. This also covers
C           NOT NULL case.
C
            IF ( ( ( A1 .LT. A2 )   .AND. 
     .             ( ( K  .LT. A1 ) .OR. ( K .GT. A2 ) ) )  .OR.

C
C              Check EQ and IS NULL cases
C
     .           ( ( A1 .EQ. A2 )   .AND. ( K .NE. A1 ) )   .OR.

C
C              Check NE case
C
     .           ( ( A2 .EQ. A1-1 ) .AND. ( K .EQ. A1 ) ) ) 

     .      THEN

               OK = .FALSE.
               CALL CHKOUT( 'STCHC2' )
               RETURN

            END IF

         END IF

      END DO

      CALL CHKOUT( 'STCHC2' )

      RETURN


C$Procedure STCRD2 ( compute RA and DEC of a given object )

      ENTRY STCRD2 ( FRAME, RA, DEC )

C$ Abstract
C
C     Compute RA and DEC values of the specified object, adjust them
C     for the proper motion and transform to the specified frame.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     CHARACTER*(*)         FRAME
C     DOUBLE PRECISION      RA
C     DOUBLE PRECISION      DEC
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     FRAME      I   Frame in which object position is returned
C     RA         O   Right ascension of the sky object, radians
C     DEC        O   Declination of the sky object, radians
C
C$ Detailed_Input
C
C     FRAME          is the name of the frame with respect to which
C                    the sky object position must be computed.
C
C$ Detailed_Output
C
C     RA             is the right ascension of the specified object in
C                    the specified frame.
C
C     DEC            is the declination of the specified object in the
C                    specified frame.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C     2) If object record data was not buffered prior to calling this
C        entry, then the error 'SPICE(RECORDNOTLOADED)' will be
C        signalled.
C
C     3) If orienation of the specifed frame cannot be computed, then
C        appropriate errors will be signalled by frame transformation
C        routines called by this entry.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     TBD -- may need more details in this section.
C
C     The routine computes the position -- RA and DEC in radians --
C     of a sky catalog object with respect the specified frame.
C
C     The position is adjusted for proper motion for the time ETPOS
C     if both EPFLAG and PMSCAL are not equal to zero.
C
C     The orientation of the specified frame is computed at the time
C     ETFOV.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C     Sky object record data must be loaded and buffered using
C     STREC2 entry of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     get type_2 sky_catalog object position
C
C-&

C
C     Check whether the catalog is really loaded.
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'to calling this routine.'                 )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         RETURN
      END IF

C
C     Compute declination band number I and zone number J within
C     the band
C
      I = MINVAL(2) + MAXABS(2) + VALUE(2)
      J = MINVAL(3) + MAXABS(3) + VALUE(3)

C
C     Compute the center of the zone coordinates
C
      DELDEC = PI() / NBANDS
      DELRA = 2 * PI() / NINBND(I)
      RA0 = DELRA * ( J - 0.5D0 )
      DEC0 = PI() / 2 - DELDEC * ( I - 0.5D0 )

C
C     Compute the object position at the catalog frame and epoch.
C
      RAI  = VALUE(4) * DELRA  / OFFSCL + RA0
      DECI = VALUE(5) * DELDEC / OFFSCL + DEC0

C
C     Check whether star position is to be recalculated to another
C     epoch. Remind that PMSCAL is a scale coefficient for proper
C     motion of the catalog objects. If PMSCAL = 0d0, that means that
C     there is no proper motion. Otherwise we consider proper motion
C     units as (arc sec/year)*PMSCAL.
C
C     PMs are applied at ETPOS which was set by STLD2, STSEP2 or STSF2.
C
      IF ( EPFLAG * ( PMSCAL(1)+PMSCAL(2) ) .NE. 0 ) THEN
         DELTA = (ETPOS-ETCAT) / JYEAR() / 3600D0 * RPD()
         RAI  = RAI  + ( MINVAL(6) + DBLE ( MAXABS(6) + VALUE(6) )
     .      / 10**ACCUR(6) ) * DELTA * PMSCAL(1)
         DECI = DECI + ( MINVAL(7) + DBLE ( MAXABS(7) + VALUE(7) )
     .      / 10**ACCUR(7) ) * DELTA * PMSCAL(2)
      END IF

C
C     Check whether star position is to be recalculated to
C     another frame
C
      CALL STCMB2 ( .TRUE., FRAME, FRAM )

C
C     Check whether requested frame is different from the catalog
C     frame, because if it's catalog frame we don't need to do
C     anything with RA/DEC that we have just computed.
C
      IF ( FRAM .NE. CFRAME ) THEN

C
C        Check whether requested frame or epoch at for which its
C        orientation was computed changed since the last call to this
C        entry.
C
         IF ( FRAM .NE. FRAMPR .OR. ETFOV .NE. ETFPR ) THEN

C
C           Either frame of epoch changed. We need to recalculate
C           matrix rotating vectors from CFRAME to FRAM.
C
C           The rotation matrix is computed at ETFOV which was set
C           by STLD2, STSEP2 or STSF2.
C
            IF ( KNOWN ) THEN

               CALL PXFORM ( CFRAME, FRAM, ETFOV, MAT )

            ELSE

               CALL PXFORM ( 'J2000', FRAM, ETFOV, MAT )

C
C              Multiply the matrix rotating vectors from
C              catalog frame to J2000 by MAT.
C
               CALL MXM( MAT, MATRIX, MAT )

            END IF

C
C           Reset "previous" flags.
C
            FRAMPR = FRAM
            ETFPR  = ETFOV

         END IF

C
C        Transform object direction from catalog frame to output
C        frame.
C
         CALL LATREC ( 1D0, RAI, DECI, R1 )
         CALL MXV    ( MAT, R1, R1        )
         CALL RECLAT ( R1, A, RAI, DECI   )

      END IF

      RA = RAI
      DEC = DECI

      RETURN


C$Procedure STREC2 ( buffer specified catalog record )

      ENTRY STREC2 ( RECNO )

C$ Abstract
C
C     Buffer SPICE catalog record with given number.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               RECNO
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     RECNO      I   SPICE catalog record number
C
C$ Detailed_Input
C
C     RECNO          is the number of the SPICE catalog record to be
C                    buffered.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     TBD -- need more details.
C
C     Read record of DATA segment with through number RECNO and
C     unpack it to integer array VALUE containing values of
C     numerical fields in elements with corresponding numbers
C     and text string TEXT containing all text fields pressed
C     (concatenated) with each other. Text field with number "i"
C     is located in the TEXT string beginning with position
C     TEST_BEG(i) and its length is equal to "-MAXABS(i)".
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     buffer specified type_2 sky_catalog record
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STREC2' )
      END IF

C
C     Check whether the catalog is really loaded.
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STREC2' )
         RETURN
      END IF

C
C     Check whether the record we are interested in is the one
C     currently buffered.
C
      IF ( ISDONE .AND. RECNO .EQ. RECLST ) THEN

C
C        It is. We have nothing to do before return.
C
         CALL CHKOUT ( 'STREC2' )
         RETURN

      ELSE IF ( RECLST .NE. RECNO ) THEN

C
C        Store the record # - "last record being read"
C
         RECLST = RECNO
         ISDONE = .FALSE.

C
C        Read MAIN part of the record of interest.
C
         I1 = BEGMAI + ( RECNO - 1 ) * MRECL
         I2 = I1 + MRECL - 1
         CALL DASRDI ( HANDLE, I1, I2, PACKED )

C
C        Perform necessary initialization. We will array value with
C        MAXABS values because they are defaults for NULLs.
C
         CALL MOVEI ( MAXABS, NFLDS, VALUE )

C
C        Unpack MAIN numerical fields. We can do it safely becasue
C        NPKNUM, DENS and NMFLDS values passed all sanity checks
C        during loading in STLD2.
C
         L = 0

         DO I = 1, NPKNUM

            CALL STI2F2 ( PACKED(I), DENS(I), Z )

            DO K = 1, DENS(I)
               L = L + 1
               VALUE(NMFLDS(L)) = Z(K)
            END DO

         END DO

C
C        Unpack MAIN character fields
C
         TEXT = ' '
         IF ( NPKTXT .GT. 0 ) THEN
            CALL STI2T2( PACKED( 1 + NPKNUM ), NPKTXT, TEXT, L )
         END IF

      END IF

C
C     If we are here, ISDONE is .FALSE., so it is necessary to check
C     whether we need deal with AUX part of the record
C
      IF ( ONLYMA ) THEN

         CALL CHKOUT ( 'STREC2' )
         RETURN

      END IF

C
C     Check whether there is AUX part
C
      I = PACKED( MRECL )

      IF ( I .GT. 0 ) THEN

C
C        Read the AUX part length and then the rest of the AUX part
C
         I = I + BEGAUX - 1
         CALL DASRDI ( HANDLE, I,   I,  L )
         IZ = L - 1

C
C        So, the AUX part itself is presented by IZ integers
C
         CALL DASRDI ( HANDLE, I+1, I + IZ, Z )

C
C        Get Mask, perform initialization
C
         MASK = Z(1)
         NTEXT = 0
         NNUM = 0
         L = MASK
         J = 1 + NMAIN

C
C        Process the Mask
C
         DO WHILE ( L .GT. 0 )

            K = L / 2
            IF ( L-2*K .EQ. 1 ) THEN

C
C              Field J is not empty
C
               IF ( FLTYPE(J) .EQ. 0 ) THEN

C
C                 Fill array of non-empty text fields numbers
C
                  NTEXT = NTEXT + 1
                  TAFLDS( NTEXT ) = J

               ELSE

C
C                Fill array of non-empty num. fields numbers
C
                 NNUM = NNUM + 1
                 NAFLDS( NNUM ) = J

               END IF

            END IF

            L = K
            J = J + 1

         END DO

C
C        Now we are through with the MASK analysis. We have NNUM
C        non-empty numerical fields which THROUGH numbers are
C        elements of the NAFLDS array and NTEXT non-empty text
C        fields which THROUGH numbers are elements of the TAFLDS
C        array.
C
C        Let us start with the numerical part - unpack it and
C        put the data into corresponding elements of the VALUE array.
C
C        At first determine the way the numerical data have been packed:
C
         N = 0

         IF ( NNUM .GT. 0 ) THEN

            DO J = 1, NNUM
               ARR(J) = MAXABS(NAFLDS(J))
            END DO

            CALL STPCK2 ( NAFLDS, ARR, NNUM, N, DENAUX )

C
C           So, for the record we have N integer packages. Each i-th
C           package contains DENAUX(i) packed values. The whole set
C           of corresponds to array of fields numbers RNKAUX.
C           Now it is hightime to unpack the numerical AUX fields.
C
            L = 0

            DO IPACK = 1, N

               CALL STI2F2 ( Z(IPACK+1), DENAUX(IPACK), ARR )

               DO K = 1, DENAUX(IPACK)
                  L = L + 1
                  VALUE(NAFLDS(L)) = ARR(K)
               END DO

            END DO

         END IF

C
C        Now unpack the text AUX fields.
C
         IF ( NTEXT .GT. 0 ) THEN

            CALL STI2T2 ( Z(N+2), IZ - N - 1, TXTAUX, K )

C
C           After call to STI2T2 the string TXTAUX contains NTEXT
C           concatenated AUX fields with through numbers TAFLDS(k),
C           k = 1, ..., NTEXT. After EACH field there is non-printable
C           byte CHAR(7). Let us fetch the fields and put them to
C           a proper place in TEXT string.
C
            J = 1

            DO K = 1, NTEXT

C
C              Look through all existing AUX text fields
C
               L = INDEX ( TXTAUX(J:), CHAR(7) )
               M = L - 2
               I1 = TXTBEG ( TAFLDS (K) )
               TEXT ( I1 : I1 + M ) = TXTAUX ( J : J + M )
               J = J + L

            END DO

         END IF

      END IF

C
C     Now the record has been processed completely and we can set
C     corresponding flag.
C
      ISDONE = .TRUE.

      ONLYMA = .FALSE.

      CALL CHKOUT ( 'STREC2' )

      RETURN


C$Procedure STSF2 ( set field-of-view parameters for search )

      ENTRY STSF2 ( ETIME, FRAME, FOVTYP, BSIGHT, NSIDES, VERTIC )

C$ Abstract
C
C     Specify the field-of-view parameters for catalog search.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     DOUBLE PRECISION      ETIME
C     CHARACTER*(*)         FRAME
C     CHARACTER*(*)         FOVTYP
C     DOUBLE PRECISION      BSIGHT(3)
C     INTEGER               NSIDES
C     DOUBLE PRECISION      VERTIC(3,*)
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     ETIME      I   Ephemeris time for FOV frame epoch
C     FRAME      I   Frame defined for FOV
C     FOVTYP     I   Character string that presents FOV type
C     BSIGHT     I   FOV boresight vector
C     NSIDES     I   The number of FOV vertices
C     VERTIC     I   Array containing FOV corners coordinates
C
C$ Detailed_Input
C
C     ETIME          is the epoch defining FOV FRAME orientation.
C
C     FRAME          is the name of the frame in which FOV vectors are
C                    defined.
C
C     FOVTYP         is a character string specifying FOV type; can have
C                    values 'POLYGON', 'CIRCLE' and 'ELLIPSE'.
C
C     BSIGHT         is the FOV boresight vector direction specified in
C                    FRAME.
C
C     NSIDES         is the number of FOV vertices; must be greater
C                    than 2 for 'POLYGON' FOVs, exactly 1 for 'CIRCLE'
C                    FOVs and exactly 2 for 'ELLIPSE' FOVs.
C
C     VERTIC         is an array that containing NSIDES 3d vectors
C                    specified with respect to FRAME, pointing to the
C                    "corners" of the FOV.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C     2) If specified FOV type is not recognized, then the error
C        'SPICE(BADFOVTYPE)' will be signalled.
C
C     3) If specified number of FOV vertices doesn't correspond to
C        specified FOV type, then the error
C        'SPICE(BADNUMBEROFVERTICES)' will be signalled.
C
C     4) If specified FOV type has more sides that can be stored in
C        the internal buffer, then the error 'SPICE(TOOMANYFOVSIDES)'
C        will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     The routine sets all the FOV parameters, namely:
C
C        -- epoch (ephemeris time) defining orientation of the FOV
C           frame;
C
C        -- frame in which FOV vectors are defined;
C
C        -- shape of the FOV (defined by string FOVTYP);
C
C        -- FOV boresight vector direction;
C
C        -- the number of the FOV corners and vectors pointing to the
C           the corners from the FOV center.
C
C     If the value of FOVTYP is 'POLYGON' the field of view of our
C     instrument is a pyramidal polyhedra. The vertex of the pyramid
C     is at the instrument and the rays along the edges of the pyramid
C     are parallel to the vectors defined in VERTIC.
C
C     If the value of FOVTYP is 'CIRCLE' the field of view of the
C     instrument is a circular cone about the boresight vector. A
C     single vector will be defined in VERTIC. This vector will be
C     parallel to a ray that lies in the cone that makes up the
C     boundary of the field of view.
C
C     If the value of FOVTYP is 'ELLIPSE' the field of view of the
C     instrument is a elliptical cone with the boresight vector as the
C     axis of the cone. In this case two vectors are defined in
C     VERTIC. One of the vectors points to the end of the semi-major
C     axis of a perpendicular cross section of the elliptic cone. The
C     other vector points to the end of the semi-minor axis of a
C     perpendicular cross section of the cone.
C
C     Also see discussion about ETPOS/ETFOV in the Particulars of the
C     STSEP2 entry header.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C     Input FOV type must be one of the supported by this routine.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STSF2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STSF2'                                    )
         RETURN
      END IF

C
C     Check whether we can recognize FOV frame
C
      CALL STCMB2 ( .TRUE., FRAME, FRAM )

      CALL NAMFRM ( FRAM, I )
      IF ( I .EQ. 0 ) THEN
         CALL SETMSG ( 'FRAME ''#'' is not supported. ' )
         CALL ERRCH  ( '#', FRAM                        )
         CALL SIGERR ( 'SPICE(FRAMENOTSUPPORTED)'       )
         CALL CHKOUT ( 'STSF2'                          )
         RETURN
      END IF

C
C     Check whether we can recognize FOV type.
C
      CALL STCMB2 ( .TRUE., FOVTYP, FOV )

      IF ( ( FOV .NE. FTCIRC ) .AND.
     .     ( FOV .NE. FTELLI ) .AND.
     .     ( FOV .NE. FTPOLY )       ) THEN
         CALL SETMSG ( 'FOV type ''#'' is not supported. ' )
         CALL ERRCH  ( '#', FOV                            )
         CALL SIGERR ( 'SPICE(BADFOVTYPE)'                 )
         CALL CHKOUT ( 'STSF2'                             )
         RETURN
      END IF

C
C     Check whether specified number of vertices corresponds to the
C     FOV type and whether we have enough space in the buffer to keep
C     all corner vectors.
C
      IF ( ( FOV .EQ. FTCIRC ) .AND. ( NSIDES .NE. 1 ) .OR.
     .     ( FOV .EQ. FTELLI ) .AND. ( NSIDES .NE. 2 ) .OR.
     .     ( FOV .EQ. FTPOLY ) .AND. ( NSIDES .LE. 2 )      ) THEN

         CALL SETMSG ( 'Number of vertices for FOV ''#'' was #.' )
         CALL ERRCH  ( '#', FTCIRC                               )
         CALL ERRINT ( '#', NSIDES                               )
         CALL SIGERR ( 'SPICE(BADNUMBEROFSIDES)'                 )
         CALL CHKOUT ( 'STSF2'                                   )
         RETURN

      ELSE IF ( NSIDES .GT. NVRMAX ) THEN

         CALL SETMSG ( 'Specified FOV has more sides than can be '   //
     .                 'stored in the buffer: # vs. #.'              )
         CALL ERRINT ( '#', NSIDES                                   )
         CALL ERRINT ( '#', NVRMAX                                   )
         CALL SIGERR ( 'SPICE(TOOMANYFOVSIDES)'                      )
         CALL CHKOUT ( 'STSF2'                                       )
         RETURN

      END IF

C
C     TBD -- needs a lot more checking/fixing for FOVs.
C
C     These are the FOV definition rules/requirements (they are pretty
C     in sync with we agreed upon in your contract or mayb even more
C     severe):
C
C        -- boresight vector is within FOV boundaries;
C
C        -- FOV is convex (the consiquence of this is that no FOV
C           can have angular separation between two farthest
C           verticies greater than 180 degrees);
C
C        -- FOV boundary vector can be "ordered about boresight"
C           clockwise or counterclockwise;
C
C        -- ellipse semi-major axis vertix can be
C
C     These are FOC checks/modifications that must be added to make
C     sure that STBOX2 and STCHF2 work correctly:
C
C        -- for boresight within FOV (I cannot say for sure that your
C           algorithms require this, but since it's general FOV
C           requirement it must checked);
C
C        -- for convexity and for order about boresight (this one I
C           know for sure -- the algorithm that check whether object
C           is within polygon FOV assumes convexity and clockwise(?)
C           order of vectors in VERTIC; if FOV is not convex we should
C           signal an error; if it's convex but order is CCW, we must
C           reverse the order);
C
C        -- for semi-major axis of elliple (this axis should be used
C           to compute ALPHA that is used STBOX2);
C
C

C
C     Define ETFOV and EPFLAG variables.
C
      ETFOV = ETIME

      IF ( EPFLAG .EQ. 0 .OR. EPFLAG .EQ. 2 ) THEN
         EPFLAG = EPFLAG + 1
      END IF

C
C     If ETPOS was not defined (using STSEP2) prior to calling this
C     entry, set ETPOS to ETFOV (see Particulars in STSEP2.)
C
      IF ( EPFLAG .EQ. 1 ) THEN
         ETPOS = ETFOV
      END IF

C
C     Generate Transfer matrix M1 from FOV frame
C     at ETFOV epoch to the catalog frame
C
      IF ( KNOWN ) THEN

         CALL PXFORM ( FRAME, CFRAME, ETFOV, M1 )

      ELSE

         CALL PXFORM ( FRAME, 'J2000', ETFOV, MAT )

C
C        Multiply the transposed matrix rotating vectors
C        from catalog frame to J2000 by MAT.
C
         CALL MTXM( MATRIX, MAT, M1 )

      END IF

C
C     Convert BSIGHT vector and VERTIC vectors into the catalog
C     frame and unitize all vectors.
C
      CALL MXV  ( M1, BSIGHT, BORE )
      CALL VHAT ( BORE, BORE )

      DO I = 1, NSIDES
         CALL MXV  ( M1, VERTIC(1,I), VERT(1,I) )
         CALL VHAT ( VERT(1,I), VERT(1,I) )
      END DO

C
C     Generate auxiliary variables using FOV parameters for each
C     FOV type.
C
      COSALP = VDOT ( BORE, VERT )
      ALPHA  = DACOS( COSALP )
      NVERT = NSIDES

      IF ( FOV .EQ. FTELLI ) THEN

C
C        Check whether the first semi-axis is really semi-major axis
C
         B = VDOT ( BORE, VERT(1,2) )
         IF ( B . LT. COSALP ) THEN

C
C           Replace the vertices
C
            DO I = 1, 3

               A = VERT(I,1)
               VERT(I,1) = VERT(I,2)
               VERT(I,2) = A

            END DO

            A = COSALP
            COSALP = B
            B = A

         END IF

C
C        Let us reformulate the task in the following way: it is
C        necessary to check whether the radius-vector of the star
C        object is within elliptical cone representing our FOV.
C
C        Let us put into consideration some special "Instrument"
C        frame XYZ where Z axis is along the boresight, XZ plane
C        contains VERT1 vector, whereas YZ plane contains VERT2
C        vector,
C                    +-         -+               +-         -+
C                    | VERT(1,1) |               | VERT(2,1) |
C           VERT1 =  | VERT(1,2) |,     VERT2 =  | VERT(2,2) |
C                    | VERT(1,3) |               | VERT(2,3) |
C                    +-         -+               +-         -+
C
C        It is evident that in this frame we have the following
C        equation for the cone surface:
C
C                2         2
C               x         y      2
C             -----  +  ----- - z  = 0
C                2         2
C               a         b
C
C                                       _  _T
C        That means that for any vector R, R = (x,y,z) in the frame
C        the condition of the vector being inside the cone can be
C        expressed as:
C
C        "quadratic form of the R vector with matrix M is negative",
C         i.e.
C                         _T  _
C                         R M R  < 0
C
C        Here matrix M is presented as follows
C
C                     +-         -+
C                     |  A  0  0  |        -2        -2
C                 M = |  0  B  0  |,  A = a  ,  B = b
C                     |  0  0 -1  |
C                     +-         -+
C
C        According to above mentioned definition,
C        a is tangent of angle between BORE and VERT1 vectors,
C        b is tangent of angle between BORE and VERT2 vectors.
C                             _
C        For arbitrary vector r in catalog frame the condition of
C        the vector being inside the cone is expressed as:
C
C                         _T T    _
C                         r G M G r  < 0
C
C        where G is transfer matrix from catalog frame to our
C        "Instrument" frame. Let us derive expression for this
C        transfer matrix. One can see that G rows contain unit
C        vectors of "Instrument" frame axes expressed in the
C        catalog frame. So, the first row of G matrix is unit
C        vector along cross product of BORE and VERT2 vectors,
C        the second row is unit vector along cross product of
C        BORE and VERT1 vectors, and the third row is BORE
C        vector.
C                                                         T
C        So, generate matrix of the quadratic form MAT = G M G.
C
C        At first generate matrix of the quadratic form in the
C        "Instrument" frame.
C
         A = COSALP*COSALP
         B = B*B
         M2(1,1) = A / ( 1D0 - A )
         M2(1,2) = 0D0
         M2(1,3) = 0D0
         M2(2,1) = 0D0
         M2(2,2) = B / ( 1D0 - B )
         M2(2,3) = 0D0
         M2(3,1) = 0D0
         M2(3,2) = 0D0
         M2(3,3) = -1D0

C
C        Now generate transfer matrix M1 from "Instrumental" to
C        catalog frame.
C
         CALL UCRSS ( VERT(2,1), BORE, M1(1,1) )
         CALL UCRSS ( BORE, VERT(1,1), M1(1,2) )
         DO I = 1, 3
            M1(I,3) = BORE(I)
         END DO

C
C        Complete computation matrix of quadratic form MAT in
C        catalog frame.
C
         CALL MXM  ( M1, M2, M3  )
         CALL MXMT ( M3, M1, MAT )

      ELSE IF ( FOV .EQ. FTPOLY ) THEN

C
C        Check whether parameters of polygon-like FOV are
C        presented correctly, namely that the FOV is convex,
C        that boresignt vector is within FOV and that the
C        sequence of vertices is presented counterclockwise.
C
         CALL POLYGON ( BORE, VERT, NVERT )

C
C        Generate set of unit vectors that are internal normals
C        (NORM) to the viewing pyramide faces (in the catalog frame)
C
         DO I = 1, NVERT

            J = I + 1
            IF ( I .EQ. NVERT ) THEN
               J = 1
            END IF

            CALL UCRSS ( VERT(1,I), VERT(1,J), NORM(1,I) )

         END DO

      END IF

C
C     Re-set search/fetch state flag.
C
      SRCHST = .FALSE.

C
C     Reset flag indicating that RA/DECs of the box circumscribing
C     FOV were computed.
C
      BOXSET = .FALSE.

      CALL CHKOUT ( 'STSF2' )

      RETURN


C$Procedure STCHF2 ( check whether an object is within FOV )

      ENTRY STCHF2 ( R, WITHIN )

C$ Abstract
C
C     Check whether the sky object is within FOV.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     DOUBLE PRECISION      R      ( 3 )
C     LOGICAL               WITHIN
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     R          I   Sky object direction in the catalog frame
C     WITHIN     O   Flag indicating whether object is within FOV
C
C$ Detailed_Input
C
C     R              is a sky object direction given as 3-d vector
C                    defined in the catalog frame.
C
C$ Detailed_Output
C
C     WITHIN         is the logical flag indicating whether the object
C                    is within FOV specified with earlier call to the
C                    STSF2 entry of this routine.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     As it is described in the SPICE Catalog System design, we
C     consider the object to be within given field-of-view if:
C
C        for circular FOV  - if angle between the object vector and
C                            vector and boresight is less then the
C                            FOV radius,
C
C        for elliptic FOV  - if the quadratic form of the object
C                            vector with matrix MAT is negative.
C
C        for polygonal FOV - if all "internal" normals provide
C                            positive scalar product with the
C                            object vector
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C     Input FOV parameters must be set by calling STSF2 entry before
C     calling this routine.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STCHF2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STCHF2'                                    )
         RETURN
      END IF

      WITHIN = .FALSE.

      IF      ( FOV .EQ. FTCIRC  ) THEN

C
C        The object is "within" circular FOV if angle
C        between the object vector and boresight is less
C        then the FOV radius
C
         IF ( VDOT ( BORE, R ) .GT. COSALP ) THEN
            WITHIN = .TRUE.
         END IF

      ELSE IF ( FOV .EQ. FTELLI ) THEN

C
C        The object is "within" elliptic FOV if the
C        quadratic form of the object vector with matrix MAT
C        is negative.
C
         IF ( VTMV( R, MAT, R ) .LT. 0 ) THEN
            WITHIN = .TRUE.
         END IF

      ELSE IF ( FOV .EQ. FTPOLY ) THEN

C
C        The object is "within" polygonal FOV if all
C        "internal" normals provide positive scalar product
C        with the object vector
C

         DO I = 1, NVERT
            IF ( VDOT( R, NORM(1,I) ) .LT. 0 ) THEN
               CALL CHKOUT ( 'STCHF2' )
               RETURN
            END IF
         END DO

         WITHIN = .TRUE.

      END IF

      CALL CHKOUT ( 'STCHF2' )

      RETURN


C$Procedure STLD2 ( load type 2 Sky Catalog )

      ENTRY STLD2 ( HNDL )

C$ Abstract
C
C     Read DAS file with the SPICE catalog with given handle
C     and load all necessary METAINFORMATION data.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               HANDLE
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     HANDLE     I   Handle of DAS file with the SPICE catalog
C
C$ Detailed_Input
C
C     HANDLE         is handle of DAS file with the SPICE catalog
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If another Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGALREADYLOADED)'
C        will be signalled.
C
C     2) If DAS file loader routine fails for any reason, it signals
C        appropriate error.
C
C     3) If conversion of the HEX-encoded epoch to DP number fails,
C        then the error 'SPICE(BADCATALOGEPOCH)' will be signalled.
C
C     4) If converison of the HEX-encoded PM scale to DP number fails,
C        then the error 'SPICE(BADPMSCALE)' will be signalled.
C
C     5) If converison of a HEX-encoded element of the frame rotation
C        matrix to DP number fails, then the error 'SPICE(BADMINVALUE)'
C        will be signalled.
C
C     6) If converison of a HEX-encoded element of the MIN values array
C        to DP number fails, then the error 'SPICE(BADMINVALUE)' will
C        be signalled.
C
C     7) ... (TBD) a lot more to be added here -- see SIGERRs in the
C        code of the entry point.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     TBD
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     load type_2 sky_catalog file
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STLD2' )
      END IF

C
C     Check whether the catalog is already loaded.
C
      IF ( LOADED ) THEN
         CALL SETMSG ( 'Cannot load catalog because another'         //
     .                 'catalog is already loaded. '                 )
         CALL SIGERR ( 'SPICE(CATALOGALREADYLOADED)'                 )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

      HANDLE = HNDL

C
C     Load all essential catalog metainformation from the catalog
C     metainformation area. Start with catalog name.
C
      CALL STGIT2 ( HANDLE, MDCNAM, I, J )
      IF ( ( J - I + 1 ) * NCHARI .GT. CATNLN ) THEN
         CALL SETMSG ( 'Encoded catalog name stored in the catalog ' //
     .                 'metainformation at DAS addresses #:# is '    //
     .                 'longer that can be accommodated in the '     //
     .                 'internal buffer intended for it. '           )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADCATALOGNAME)'                       )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, Z  )
      CALL STI2T2 ( Z, J - I + 1, CATNAM, J )

C
C     Read catalog object type.
C
      CALL STGIT2 ( HANDLE, MDOTYP, I, J )
      IF ( ( J - I + 1 ) * NCHARI .GT. OBJTLN ) THEN
         CALL SETMSG ( 'Encoded catalog object type stored in the '  //
     .                 'catalog metainformation at DAS addresses '   //
     .                 '#:# is longer that can be accommodated in '  //
     .                 'the internal buffer intended for it. '       )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADCATALOGOBJTYPE)'                    )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, Z  )
      CALL STI2T2 ( Z, J - I + 1, OBTYPE, J )

C
C     Read number of objects in the catalog.
C
      CALL STGIT2 ( HANDLE, MDNOFO, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The number of objects in the catalog stored '//
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADNUMBEROFOBJ)'                       )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NOBJ )

C
C     Read catalog reference frame.
C
      CALL STGIT2 ( HANDLE, MDFRAM, I, J  )
      IF ( ( J - I + 1 ) * NCHARI .GT. FRMNLN ) THEN
         CALL SETMSG ( 'Encoded catalog frame name stored in the '   //
     .                 'catalog metainformation at DAS addresses '   //
     .                 '#:# is longer that can be accommodated in '  //
     .                 'the internal buffer intended for it. '       )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADCATALOGFRAME)'                      )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, Z )
      CALL STI2T2 ( Z, J - I + 1, CFRAME, J )

C
C     Check whether the catalog frame name is recognized
C
      CALL NAMFRM ( CFRAME, I )
      IF ( I .EQ. 0 ) THEN
         KNOWN = .FALSE.
      ELSE
         KNOWN = .TRUE.
      END IF

C
C     Read and decode with epoch of star positions. First, find the
C     address of the parameter in the METAINFORMATION segment and fetch
C     corresponding package of integer numbers. Then, convert them to
C     character string. And at last convert the string to double
C     precision number.
C
      CALL STGIT2 ( HANDLE, MDEPOC, I, J )
      IF ( ( J - I + 1 ) * NCHARI .GT. TFVMAX ) THEN
         CALL SETMSG ( 'Encoded catalog epoch stored in the '        //
     .                 'catalog metainformation at DAS addresses '   //
     .                 '#:# is longer that can be accomodated in '   //
     .                 'the internal buffer intended for it. '       )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADCATALOGEPOCH)'                      )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, Z )

      STRING = ' '
      CALL STI2T2 ( Z, J - I + 1, STRING, J )

      CALL HX2DP  ( STRING, ETCAT, FAILED, ERROR )
      IF ( FAILED ) THEN
         CALL SETMSG ( 'Cannot convert catalog epoch ''#'' from '    //
     .                 'HEX to DP. Error was: ' // ERROR             )
         CALL ERRCH  ( '#', STRING                                   )
         CALL SIGERR ( 'SPICE(BADCATALOGEPOCH)'                      )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

C
C     Read PM scale factor -- same procedure as for EPOCH.
C
      CALL STGIT2 ( HANDLE, MDPMSC, I, J )
      IF ( ( J - I + 1 ) * NCHARI .GT. TFVMAX ) THEN
         CALL SETMSG ( 'Encoded catalog PM scale stored in the '     //
     .                 'catalog metainformation at DAS addresses '   //
     .                 '#:# is longer that can be accomodated in '   //
     .                 'the internal buffer intended for it. '       )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADCATALOGPMSCALE)'                    )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, Z )

      DO K = 1,2
         STRING = ' '
         CALL STI2T2 ( Z((K-1)*(DPHXSZ/NCHARI)+1), DPHXSZ/NCHARI, 
     .                                                 STRING, J )
         CALL HX2DP  ( STRING, PMSCAL(K), FAILED, ERROR )
         IF ( FAILED ) THEN
            CALL SETMSG ( 'Cannot convert proper motion scale ' //
     .                    'factor epoch ''#'' from HEX to DP. ' //
     .                    'Error was: ' // ERROR                )
            CALL ERRCH  ( '#', STRING                           )
            CALL SIGERR ( 'SPICE(BADPMSCALE)'                   )
            CALL CHKOUT ( 'STLD2'                               )
            RETURN
         END IF
      END DO

C
C     Fetch catalog frame to J2000 rotation matrix. The matrix must
C     be stored as a block of 9*(DPHXSZ/NCHARI) integer numbers.
C
      CALL STGIT2 ( HANDLE, MDMATR, I, J )
      IF ( ( J - I + 1 ) .NE. 9*(DPHXSZ/NCHARI) ) THEN
         CALL SETMSG ( 'The catalog frame transformation matrix '    //
     .                 'stored in the catalog metainformation at '   //
     .                 'DAS addresses #:# is not packed as '         //
     .                 'exactly # integer numbers. '                 )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', 9*(DPHXSZ/NCHARI)                        )
         CALL SIGERR ( 'SPICE(BADCATALOGMATRIX)'                     )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, Z )

      L = 1

      DO I = 1, 3

         DO J = 1, 3

            STRING = ' '
            CALL STI2T2 ( Z(L), DPHXSZ/NCHARI, STRING, K )

            CALL HX2DP  ( STRING, MATRIX(I,J), FAILED, ERROR )
            IF ( FAILED ) THEN
               CALL SETMSG ( 'Cannot convert ''#'' ((#,#) element '  //
     .                       'of the catalog frame transformation '  //
     .                       'matrix) from HEX to DP. Error was: '   //
     .                       ERROR                                   )
               CALL ERRCH  ( '#', STRING                             )
               CALL ERRINT ( '#', I                                  )
               CALL ERRINT ( '#', J                                  )
               CALL SIGERR ( 'SPICE(BADMATRIXELEMENT)'               )
               CALL CHKOUT ( 'STLD2'                                 )
               RETURN
            END IF

            L = L + DPHXSZ/NCHARI

         END DO

      END DO

C
C     TBD --   need check whether MATRIX is a rotation matrix (CALL
C              ISROT with some reasonable tolerance)
C

C
C     Read number of fields in the catalog records.
C
      CALL STGIT2 ( HANDLE, MDNOFF, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The number of fields in the catalog '        //
     .                 'records stored '                             //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADNUMBEROFFIELDS)'                    )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NFLDS )

      IF ( NFLDS .GT. NFLMAX ) THEN
         CALL SETMSG ( 'The number of fields in the catalog '        //
     .                 'records # stored in the catalog '            //
     .                 'metainformation is greater than allowed '    //
     .                 'maximum number.'                             )
         CALL ERRINT ( '#', NFLDS                                    )
         CALL SIGERR ( 'SPICE(BADNUMBEROFFIELDS2)'                   )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

C
C     TBD --   need sanity check for "at least so many" fields, given
C              that we have required fields (RA, DEC, etc.)
C

C
C     Read number of fields in the main part of the catalog records.
C
      CALL STGIT2 ( HANDLE, MDNMAI, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The number of fields in the main part of '   //
     .                 'the catalog records stored '                 //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADNUMBEROFMAINFLDS)'                  )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NMAIN )

      IF ( NMAIN .GT. NFLDS ) THEN
         CALL SETMSG ( 'The number of fields in the main part of '   //
     .                 'the catalog records # is greater than the '  //
     .                 'total number of fields in the record #.'     )
         CALL ERRINT ( '#', NMAIN                                    )
         CALL ERRINT ( '#', NFLDS                                    )
         CALL SIGERR ( 'SPICE(BADNUMBEROFMAINFLDS2)'                 )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

C
C     TBD -- need another check for "at least so many" main records.
C

C
C     Read catalog record field names.
C
      CALL STGIT2 ( HANDLE, MDFNAM, I, J )
      IF ( ( J - I + 1 ) * NCHARI .NE. NFLDS * FLDNLN ) THEN
         CALL SETMSG ( 'The catalog record field names stored in '   //
     .                 'the catalog metainformation at '             //
     .                 'DAS addresses #:# are not packed as '        //
     .                 'exactly # integer numbers. '                 )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NFLDS * FLDNLN                           )
         CALL SIGERR ( 'SPICE(BADCATALOGFLDNAMES)'                   )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

      DO K = 1, NFLDS
         J = I + ( K - 1 ) * ( FLDNLN / NCHARI )
         CALL DASRDI ( HANDLE, J, J + ( FLDNLN / NCHARI ) - 1, Z )
         CALL STI2T2 ( Z, FLDNLN / NCHARI, FLDNAM(K), L )
      END DO

C
C     Read field classes.
C
      CALL STGIT2 ( HANDLE, MDFCLA, I, J )
      IF ( ( J - I + 1 ) * NCHARI .NE. NFLDS * FLDCLN ) THEN
         CALL SETMSG ( 'The catalog record field classes stored in ' //
     .                 'the catalog metainformation at '             //
     .                 'DAS addresses #:# are not packed as '        //
     .                 'exactly # integer numbers. '                 )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NFLDS * FLDCLN                           )
         CALL SIGERR ( 'SPICE(BADCATALOGFLDCLASSES)'                 )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

      DO K = 1, NFLDS
         J = I + ( K - 1 ) * ( FLDCLN / NCHARI )
         CALL DASRDI ( HANDLE, J, J + ( FLDCLN / NCHARI ) - 1, Z )
         CALL STI2T2 ( Z, FLDCLN / NCHARI, FLDCLS(K), L )
      END DO

C
C     Read field types.
C
      CALL STGIT2 ( HANDLE, MDFTYP, I, J )
      IF ( ( J - I + 1 ) .NE. NFLDS ) THEN
         CALL SETMSG ( 'The number of catalog record field type ' //
     .                 'IDs stored in the catalog metainformation '  //
     .                 'at DAS addresses #:# is not equal to the '   //
     .                 'the number of fields in the catalog #. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NFLDS                                    )
         CALL SIGERR ( 'SPICE(BADCATALOGFLDCLASSES)'                 )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, FLTYPE )

C
C     Read field indexing flags.
C
      CALL STGIT2 ( HANDLE, MDFIDX, I, J )
      IF ( ( J - I + 1 ) .NE. NFLDS ) THEN
         CALL SETMSG ( 'The number of catalog record field indexing '//
     .                 'flags stored in the catalog metainformation '//
     .                 'at DAS addresses #:# is not equal to the '   //
     .                 'the number of fields in the catalog #. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NFLDS                                    )
         CALL SIGERR ( 'SPICE(BADCATALOGFLDIDXFLAGS)'                )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, FLDIND )

C
C     Read minimum values for the fields. They must be stored as a
C     block of NFLDS * (DPHXSZ/NCHARI) integer numbers.
C
      CALL STGIT2 ( HANDLE, MDMINV, I, J )
      IF ( ( J - I + 1 ) .NE. NFLDS * (DPHXSZ/NCHARI) ) THEN
         CALL SETMSG ( 'The catalog field minimum values '           //
     .                 'stored in the catalog metainformation at '   //
     .                 'DAS addresses #:# are not packed as '        //
     .                 'exactly # integer numbers. '                 )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NFLDS * (DPHXSZ/NCHARI)                  )    
         CALL SIGERR ( 'SPICE(BADCATALOGFLDMINVALUES)'               )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, Z )

      L = 1

      DO I = 1, NFLDS

         STRING = ' '
         CALL STI2T2 ( Z(L), DPHXSZ/NCHARI, STRING, K )

         CALL HX2DP  ( STRING, MINVAL(I), FAILED, ERROR )
         IF ( FAILED ) THEN
            CALL SETMSG ( 'Cannot convert ''#'' minimum value '      //
     .                    'of the #th field in the catalog '         //
     .                    'from HEX to DP. Error was: '              //
     .                    ERROR                                      )
            CALL ERRCH  ( '#', STRING                                )
            CALL ERRINT ( '#', I                                     )
            CALL SIGERR ( 'SPICE(BADMINVALUE)'                       )
            CALL CHKOUT ( 'STLD2'                                    )
            RETURN
         END IF

         L = L + DPHXSZ/NCHARI

      END DO

C
C     Read least significant bit values (accuracies) for catalog fields.
C
      CALL STGIT2 ( HANDLE, MDACCU, I, J )
      IF ( ( J - I + 1 ) .NE. NFLDS ) THEN
         CALL SETMSG ( 'The number of catalog record field accuracy '//
     .                 'values stored in the catalog '               //
     .                 'metainformation at DAS addresses #:# is not '//
     .                 'equal to the number of fields in the '       //
     .                 'catalog #. '                                 )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NFLDS                                    )
         CALL SIGERR ( 'SPICE(BADCATALOGFLDACCUR)'                   )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, ACCUR )

C
C     Read MAXABS values for catalog fields.
C
      CALL STGIT2 ( HANDLE, MDMAXA, I, J )
      IF ( ( J - I + 1 ) .NE. NFLDS ) THEN
         CALL SETMSG ( 'The number of catalog record field MAXABS '  //
     .                 'values stored in the catalog '               //
     .                 'metainformation at DAS addresses #:# is not '//
     .                 'equal to the number of fields in the '       //
     .                 'catalog #. '                                 )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NFLDS                                    )
         CALL SIGERR ( 'SPICE(BADCATALOGFLDMAXABS)'                  )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, MAXABS )

C
C     Read MISS values for catalog fields.
C
      CALL STGIT2 ( HANDLE, MDMISS, I, J )
      IF ( ( J - I + 1 ) .NE. NFLDS ) THEN
         CALL SETMSG ( 'The number of catalog record field MISS '    //
     .                 'values stored in the catalog '               //
     .                 'metainformation at DAS addresses #:# is not '//
     .                 'equal to the number of fields in the '       //
     .                 'catalog #. '                                 )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NFLDS                                    )
         CALL SIGERR ( 'SPICE(BADCATALOGFLDMAXABS)'                  )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, MISS )

C
C     Prepare additional auxillary information about the MAIN fields.
C
      NNUMM  = 0
      NTXTM  = 0

      DO I = 1, NMAIN

         IF ( FLTYPE(I) .NE. 0 ) THEN

C
C           If the field is of NUMERICAL type, we simply increase
C           the count of numeric fields in the MAIN part of the
C           records.
C
            NNUMM = NNUMM + 1

         ELSE

C
C           If the field of the character type we need to do more work.
C           We increase count of the text fields in the MAIN part of
C           the records (NTXTM), memorize field index (in TMFLDS).
C
            NTXTM         = NTXTM + 1
            TMFLDS(NTXTM) = I

         END IF

      END DO

C
C     Some more stuff - compute starting position of the field value in
C     concatenated text block (TXTBEG). (Note that MAXABS(I) contains
C     negative text field lenght ... that's why it's subtracted rather
C     than added :-)
C
      ISTART = 1

      DO I = 1, NFLDS

         IF ( FLTYPE(I) .EQ. 0 ) THEN
            TXTBEG(I) = ISTART
            ISTART    = ISTART - MAXABS(I)
         END IF

      END DO

C
C     Read the lenght the main part of record.
C
      CALL STGIT2 ( HANDLE, MDMRCL, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The length of the main part of a compressed '//
     .                 'catalog record, stored '                     //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADMAINPARTLENGHT)'                    )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, MRECL )

C
C     Read number of numeric packets (integers) used to compress
C     numeric fields in the MAIN part of the record.
C
      CALL STGIT2 ( HANDLE, MDNPKN, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The number of numeric packets (integers) '   //
     .                 'in a compress catalog record, stored '       //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADNUMBEROFPCKNUM1)'                   )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NPKNUM )

C
C     Check whether number of numeric packets is less or equal to the
C     number of numeric fields in the MAIN part.
C
      IF ( NPKNUM .GT. NNUMM .OR. NPKNUM .LT. 1 ) THEN
         CALL SETMSG ( 'The number of numeric packets (integers) '   //
     .                 'in a compress catalog record, #, stored '    //
     .                 'in the catalog metainformation is less '     //
     .                 'than one or greater '                        //
     .                 'than the number of numeric fields in the '   //
     .                 'MAIN part of a catalog record, #.'           )
         CALL ERRINT ( '#', NPKNUM                                   )
         CALL ERRINT ( '#', NNUMM                                    )
         CALL SIGERR ( 'SPICE(BADNUMBEROFPCKNUM2)'                   )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

C
C     Read number of text packets.
C
      CALL STGIT2 ( HANDLE, MDNPKT, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The number of text packets in a compress '   //
     .                 'catalog record stored '                      //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADNUMBEROFPCKTXT)'                    )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NPKTXT )

C
C     Check whether the sum of the number of numeric packets and the
C     number of text packets is equal to the MRECL.
C
      IF ( NPKTXT + NPKNUM + 1 .NE. MRECL ) THEN
         CALL SETMSG ( 'The sum of the number of numeric packets # ' //
     .                 'and the number of text packets # in the '    //
     .                 'MAIN part of catalog record is not equal '   //
     .                 'to the size of the MAIN part, # minus 1.'    )
         CALL ERRINT ( '#', NPKNUM                                   )
         CALL ERRINT ( '#', NPKTXT                                   )
         CALL ERRINT ( '#', MRECL                                    )
         CALL SIGERR ( 'SPICE(MAINPARTSIZEMISMATCH)'                 )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

C
C     Read packing density for each of the numeric packets (integers)
C     used to compress numeric fields in MAIN part of the records.
C
      CALL STGIT2 ( HANDLE, MDDENS, I, J )
      IF ( ( J - I + 1 ) .NE. NPKNUM ) THEN
         CALL SETMSG ( 'The number of packing densities of the '     //
     .                 'catalog fields, stored in the catalog '      //
     .                 'metainformation at DAS addresses #:# is not '//
     .                 'equal to the number of packets (integers) #.')
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NFLDS                                    )
         CALL SIGERR ( 'SPICE(BADCATALOGFLDDENSITIES)'               )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, DENS )

C
C     Check whether the sum of the densities is equal to the number of
C     numeric fields stored in the main part of the record.
C
      J = 0
      DO I = 1, NPKNUM
         J = J + DENS( I )
      END DO

      IF ( J .NE. NNUMM ) THEN
         CALL SETMSG ( 'The total of the densities stored '          //
     .                 'in the catalog metainformation is not '      //
     .                 'equal to the number of numeric fields in '   //
     .                 'the MAIN part of a catalog record, #.'       )
         CALL ERRINT ( '#', NNUMM                                    )
         CALL SIGERR ( 'SPICE(BADPACKINGDENSITYINFO)'                )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

C
C     Read indexes of the fields contained in the main part of record.
C
      CALL STGIT2 ( HANDLE, MDNMFL, I, J )
      IF ( ( J - I + 1 ) .NE. NNUMM ) THEN
         CALL SETMSG ( 'The number of indexes of the numeric fields '//
     .                 'contained in the main part of a compressed ' //
     .                 'catalog record, stored in the catalog '      //
     .                 'metainformation at DAS addresses #:# is '    //
     .                 'not equal to the number of numeric fields '  //
     .                 'in the main part of the record #. '          )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NNUMM                                    )
         CALL SIGERR ( 'SPICE(BADCATALOGMAINFLDIDXS)'                )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NMFLDS )

C
C     Simple sanity check to make sure that all indexes are within
C     1..NFLDS range and that these fields are indeed numeric fields.
C
      DO I = 1, NNUMM
         IF ( NMFLDS(I) .LT. 0 .OR. NMFLDS(I) .GT. NFLDS ) THEN
            CALL SETMSG ( 'The index of the numeric catalog field '  //
     .                    '# stored in the #th element of the # '    //
     .                    'array of the metatinformation, is '       //
     .                    'less than 1 or greater than number of '   //
     .                    'fields in a catalog record, #.'           )
            CALL ERRINT ( '#', NMFLDS(I)                             )
            CALL ERRINT ( '#', I                                     )
            CALL ERRCH  ( '#', MDNMFL                                )
            CALL ERRINT ( '#', NFLDS                                 )
            CALL SIGERR ( 'SPICE(BADNUMFIELDINDEX)'                  )
            CALL CHKOUT ( 'STLD2'                                    )
            RETURN
         END IF
         IF ( FLTYPE(NMFLDS(I)) .EQ. 0 ) THEN
            CALL SETMSG ( 'The field, index of which '               //
     .                    'stored in the #th element of the # '      //
     .                    'array of the metatinformation, is '       //
     .                    'not a numeric field.'                     )
            CALL ERRINT ( '#', I                                     )
            CALL ERRCH  ( '#', MDNMFL                                )
            CALL SIGERR ( 'SPICE(NOTNUMFIELDINDEX)'                  )
            CALL CHKOUT ( 'STLD2'                                    )
            RETURN
         END IF
      END DO

C
C     Read the number of text fields in auxilary part of a record.
C
      CALL STGIT2 ( HANDLE, MDNTAU, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The number of text fields in the auxilary '  //
     .                 'part of a record, stored '                   //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADAUXTXTFLDNUMBER)'                   )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NTXTA )

C
C     TBD -- need sanity check for negative values of NTXTA.
C

C
C     Read the number of numeric fields in auxilary part of a record.
C
      CALL STGIT2 ( HANDLE, MDNNAU, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The number of numeric fields in the '        //
     .                 'auxilary part of a record, stored '          //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADAUXNUMFLDNUMBER)'                   )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NNUMA )

C
C     TBD -- need sanity check for negative values of NNUMA.
C

C
C     Sanity check for field count mismatch.
C
      IF ( ( NMAIN + NTXTA + NNUMA ) .NE. NFLDS ) THEN
         CALL SETMSG ( 'The sum of the number of fields in MAIN '    //
     .                 '(#), the number of text fields in AUX  '     //
     .                 '(#) and the number of numeric fields in '    //
     .                 'AUX (#) does not equal to the tolat number ' //
     .                 'of fields #.'                                )
         CALL ERRINT ( '#', NMAIN                                    )
         CALL ERRINT ( '#', NTXTA                                    )
         CALL ERRINT ( '#', NNUMA                                    )
         CALL ERRINT ( '#', NFLDS                                    )
         CALL SIGERR ( 'SPICE(FLDCOUNTSMISMATCH)'                    )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

C
C     Another sanity check to not exceding maximum number of auxillary
C     fields.
C
      IF ( ( NTXTA + NNUMA ) .GT. NFAMAX ) THEN
         CALL SETMSG ( 'The sum of the number of text fields in AUX '//
     .                 '(#) and the number of numeric fields in '    //
     .                 'AUX (#) is greater than maximum allowed '    //
     .                 'total count of AUX fields #. '               )
         CALL ERRINT ( '#', NTXTA                                    )
         CALL ERRINT ( '#', NNUMA                                    )
         CALL ERRINT ( '#', NFAMAX                                   )
         CALL SIGERR ( 'SPICE(TOOMANYAUXFIELDS)'                     )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

C
C     Read indexes of text AUX fields .. if there are any.
C
      IF ( NTXTA .NE. 0 ) THEN
         CALL STGIT2 ( HANDLE, MDTAUF, I, J )
         IF ( ( J - I + 1 ) .NE. NTXTA ) THEN
            CALL SETMSG ( 'The number of indexes of the text '       //
     .                    'catalog fields contained in the AUX '     //
     .                    'part of a compressed catalog record, '    //
     .                    'stored in the catalog metainformation '   //
     .                    'at DAS addresses #:# is not equal to '    //
     .                    'the number of text fields in the '        //
     .                    'AUX part of the record #. '               )
            CALL ERRINT ( '#', I                                     )
            CALL ERRINT ( '#', J                                     )
            CALL ERRINT ( '#', NTXTA                                 )
            CALL SIGERR ( 'SPICE(BADCATALOGAUXTXTIDXS)'              )
            CALL CHKOUT ( 'STLD2'                                    )
            RETURN
         END IF
         CALL DASRDI ( HANDLE, I, J, TAFLDS )
      END IF

C
C     Read indexes of numeric AUX fields .. if there are any.
C
      IF ( NNUMA .NE. 0 ) THEN
         CALL STGIT2 ( HANDLE, MDNAUF, I, J )
         IF ( ( J - I + 1 ) .NE. NNUMA ) THEN
            CALL SETMSG ( 'The number of indexes of the numeric '    //
     .                    'catalog fields contained in the AUX '     //
     .                    'part of a compressed catalog record, '    //
     .                    'stored in the catalog metainformation '   //
     .                    'at DAS addresses #:# is not equal to '    //
     .                    'the number of numeric fields in the '     //
     .                    'AUX part of the record #. '               )
            CALL ERRINT ( '#', I                                     )
            CALL ERRINT ( '#', J                                     )
            CALL ERRINT ( '#', NNUMA                                 )
            CALL SIGERR ( 'SPICE(BADCATALOGAUXNUMIDXS)'              )
            CALL CHKOUT ( 'STLD2'                                    )
            RETURN
         END IF
         CALL DASRDI ( HANDLE, I, J, NAFLDS )
      END IF

C
C     Read the information about the catalog geometrical organization.
C
C     Read the number of declination bands.
C
      CALL STGIT2 ( HANDLE, MDNODB, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The number of declination bands, stored '    //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADNUMBEROFBANDS)'                     )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NBANDS )

      IF ( NBANDS .GT. NBMAX ) THEN
         CALL SETMSG ( 'The number of declination bands # is '       //
     .                 'greater than maximum allowed value #.'       )
         CALL ERRINT ( '#', NBANDS                                   )
         CALL ERRINT ( '#', NBMAX                                    )
         CALL SIGERR ( 'SPICE(BADNUMBEROFBANDS)'                     )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

      IF ( NBANDS .LE. 0 ) THEN
         CALL SETMSG ( 'The number of declination bands # is '       //
     .                 'less or equal to zero which doesn''t make '  //
     .                 'sense.'                                      )
         CALL ERRINT ( '#', NBANDS                                   )
         CALL SIGERR ( 'SPICE(ZEROORNEGNUMBEROFBANDS)'               )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

C
C     TBD -- need sanity check for smallest value of NBANDS (1?).
C

C
C     Read the number of elementary zones.
C
      CALL STGIT2 ( HANDLE, MDNOZO, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The number of elementary zones, stored '     //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADNUMBEROFBANDS)'                     )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NZONES )

      IF ( NZONES .GT. NZMAX ) THEN
         CALL SETMSG ( 'The number of elementary zones # is '        //
     .                 'greater than maximum allowed value #.'       )
         CALL ERRINT ( '#', NZONES                                   )
         CALL ERRINT ( '#', NZMAX                                    )
         CALL SIGERR ( 'SPICE(BADNUMBEROFZONES)'                     )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

C
C     TBD -- need sanity check for smallest value of NZONES (1?).
C     TBD -- need sanity check for consistency of NZONES and NBANDS.
C

C
C     Read number of zones (per band.)
C
      CALL STGIT2 ( HANDLE, MDNINB, I, J )
      IF ( ( J - I + 1 ) .NE. NBANDS ) THEN
         CALL SETMSG ( 'The number of elements in the number of '    //
     .                 'zones in band array, stored in the catalog ' //
     .                 'metainformation at DAS addresses #:# is not '//
     .                 'equal to the number of bands #. '            )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NBANDS                                   )
         CALL SIGERR ( 'SPICE(BADZONESINBANDARRAY)'                  )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NINBND )

C
C     Check that all elements of NINBND are greater than 0.
C
      DO I = 1, NBANDS
      END DO

C
C     Read initial position of TBD (one per zone.)
C
      CALL STGIT2 ( HANDLE, MDIPOS, I, J )
      IF ( ( J - I + 1 ) .NE. NZONES ) THEN
         CALL SETMSG ( 'The number of elements in the initial '   //
     .                 'position array, stored in the catalog '   //
     .                 'metainformation at DAS addresses #:# is not '//
     .                 'equal to the number of zones #. '            )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NZONES                                   )
         CALL SIGERR ( 'SPICE(BADINITIALPOSARRAY)'                   )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, INPOS )

C
C     Read number of TBD (one per band.)
C
      CALL STGIT2 ( HANDLE, MDNSUM, I, J )
      IF ( ( J - I + 1 ) .NE. NBANDS ) THEN
         CALL SETMSG ( 'The number of elements in the N_SUM '        //
     .                 'array, stored in the catalog '               //
     .                 'metainformation at DAS addresses #:# is not '//
     .                 'equal to the number of bands #. '            )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NBANDS                                   )
         CALL SIGERR ( 'SPICE(BADNSUMARRAY)'                         )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NSUM )

C
C     Obtain ADDRESS_INFO.
C
C     Read address of the main data block of the file.
C
      CALL STGIT2 ( HANDLE, MDBMAI, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The address of the main data block of the '  //
     .                 'file, stored '                               //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADMAINADDRESS)'                       )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, I, BEGMAI )

C
C     TBD -- need sanity checks on the MAIN address? Non-zero at least?
C

C
C     Read address of the AUX data block of the file.
C
      CALL STGIT2 ( HANDLE, MDBAUX, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The address of the AUX data block of the '   //
     .                 'file, stored '                               //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADAUXADDRESS)'                        )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, I, BEGAUX )

C
C     TBD -- need sanity checks on the AUX address? Non-zero at least?
C

C
C     Read address of the INDEX block of the file.
C
      CALL STGIT2 ( HANDLE, MDBIDX, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The address of the INDEX block of the '      //
     .                 'file, stored '                               //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADINDEXADDRESS)'                      )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, I, BEGIND )

C
C     TBD -- need sanity checks on the AUX address? Non-zero at least?
C     TBD -- need consistency check between BEGMAI, BEGAUX and BEGIND?
C

C
C     Read logical field group counts.
C
C     Read number of fields in position section.
C
      CALL STGIT2 ( HANDLE, MDNINP, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The numberof fields in position section of ' //
     .                 'a record, stored '                           //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADNUMBERINPOS)'                       )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NINPOS )

C
C     Read number of fields in intensity section.
C
      CALL STGIT2 ( HANDLE, MDNINI, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The number of fields in intensity '          //
     .                 'section of a record, stored '                //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADNUMBERININTENS)'                    )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NININT )

C
C     Read array containing indexes of the first non-common characater
C     in each character field.
C
      CALL STGIT2 ( HANDLE, MDCPOS, I, J )
      IF ( ( J - I + 1 ) .NE. NFLDS ) THEN
         CALL SETMSG ( 'The number of catalog record non-common '    //
     .                 'character indexes stored in the catalog '    //
     .                 'metainformation at DAS addresses #:# is not '//
     .                 'equal to the number of fields in the '       //
     .                 'catalog #. '                                 )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL ERRINT ( '#', NFLDS                                    )
         CALL SIGERR ( 'SPICE(BADCATALOGFLDCHRPOS)'                  )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, FLDBPS )

C
C     Do sanity check to make sure that FLDBPS is at least 1 for
C     all character fields.
C
      DO I = 1, NFLDS
         IF ( FLTYPE(I) .EQ. 0 .AND. FLDBPS(I) .LT. 1 ) THEN
            CALL SETMSG ( 'The position of the first non-common '    //
     .                    'character # in the field with index '     //
     .                    '#, stored in the metainformation '        //
     .                    'array # is less than 1.'                  )
            CALL ERRINT ( '#', FLDBPS(I)                             )
            CALL ERRINT ( '#', I                                     )
            CALL ERRCH  ( '#', MDCPOS                                )
            CALL SIGERR ( 'SPICE(NCCHARINDEXISTOOSMALL)'             )
            CALL CHKOUT ( 'STLD2'                                    )
            RETURN
         END IF
      END DO

C
C     Compute accumulated common prefix size that is stored in the
C     METAINFORMATION.
C
      PRFSIZ = 0
      DO I = 1, NFLDS

         IF ( FLTYPE(I) .EQ. 0 .AND. FLDBPS(I) .GT. 1 ) THEN

            PRFSIZ = PRFSIZ + FLDBPS(I) - 1

C
C           Also, do a sanity check on FLDBPS(I) value.
C
            IF ( FLDBPS(I) .GT. TFVMAX ) THEN
               CALL SETMSG ( 'The position of the first non-common ' //
     .                       'character # in the field with index '  //
     .                       '#, stored in the metainformation '     //
     .                       'array # is greater than maximum size ' //
     .                       'of a character field value #.'         )
               CALL ERRINT ( '#', FLDBPS(I)                          )
               CALL ERRINT ( '#', I                                  )
               CALL ERRCH  ( '#', MDCPOS                             )
               CALL ERRINT ( '#', TFVMAX                             )
               CALL SIGERR ( 'SPICE(NCCHARINDEXISTOOBIG)'            )
               CALL CHKOUT ( 'STLD2'                                 )
               RETURN
            END IF

         END IF

      END DO

      IF ( PRFSIZ .GT. 0 ) THEN

C
C        Accumulated prefix is stored in the METAINFORMATION. Get it!
C
         CALL STGIT2 ( HANDLE, MDCPRF, I, J )

C
C        Check the size of the value of accumulated prefix.
C
         IF ( ( MOD( PRFSIZ, NCHARI ) .EQ. 0              .AND.
     .          ( J - I + 1 )    .NE. ( PRFSIZ / NCHARI )         ) .OR.
     .        ( MOD( PRFSIZ, NCHARI ) .NE. 0              .AND.
     .          ( J - I + 1 )    .NE. ( PRFSIZ / NCHARI + 1 ) )   ) THEN
            CALL SETMSG ( 'The size of the accumulated common '      //
     .                    'prefix stored in the catalog '            //
     .                    'metainformation at DAS addresses #:# '    //
     .                    'does not match total of the individual '  //
     .                    'prefix sizes stored in the ''#'' array.'  )
            CALL ERRINT ( '#', I                                     )
            CALL ERRINT ( '#', J                                     )
            CALL ERRCH  ( '#', MDCPOS                                )
            CALL SIGERR ( 'SPICE(BADACCUMPREFIXSIZE)'                )
            CALL CHKOUT ( 'STLD2'                                    )
            RETURN
         END IF

C
C        Get and convert accumulated prefix string.
C
         CALL DASRDI ( HANDLE, I, J, Z     )
         CALL STI2T2 ( Z, J-I+1, PRFVAL, L )

C
C        Split accumulated prefix string.
C
         PRFSIZ = 0
         DO I = 1, NFLDS
            IF ( FLTYPE(I) .EQ. 0 .AND. FLDBPS(I) .GT. 1 ) THEN
               FLDPRF(I)(1:FLDBPS(I)-1) =
     .                               PRFVAL(PRFSIZ+1:PRFSIZ+FLDBPS(I)-1)
               PRFSIZ = PRFSIZ + FLDBPS(I) - 1
            ELSE
               FLDPRF(I) = ' '
            END IF
         END DO

      END IF

C
C     Read the number of Index Tables.
C
      CALL STGIT2 ( HANDLE, MDNITB, I, J )
      IF ( I .NE. J ) THEN
         CALL SETMSG ( 'The number of index tables, stored '         //
     .                 'in the catalog metainformation at DAS '      //
     .                 'addresses #:# is not a single integer. '     )
         CALL ERRINT ( '#', I                                        )
         CALL ERRINT ( '#', J                                        )
         CALL SIGERR ( 'SPICE(BADNUMBERINDEXTABLES)'                 )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF
      CALL DASRDI ( HANDLE, I, J, NINDX )

      IF ( NINDX .GT. NFLDS ) THEN
         CALL SETMSG ( 'The number of index tables # is greater '    //
     .                 'the total number of fields #.'               )
         CALL ERRINT ( '#', NINDX                                    )
         CALL ERRINT ( '#', NFLDS                                    )
         CALL SIGERR ( 'SPICE(BADNUMBERINDEXTABLES2)'                )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

      IF ( NINDX .LT. 0 ) THEN
         CALL SETMSG ( 'The number of index tables # is negative. '  //
     .                 'This is not possible and indicates bad/ '    //
     .                 'catalog file.'                               )
         CALL ERRINT ( '#', NINDX                                    )
         CALL SIGERR ( 'SPICE(BADNUMBERINDEXTABLES3)'                )
         CALL CHKOUT ( 'STLD2'                                       )
         RETURN
      END IF

C
C     Read list of fields which are indexed.
C
      IF ( NINDX .GT. 0 ) THEN

         CALL STGIT2 ( HANDLE, MDLSTT, I, J )
         IF ( ( J - I + 1 ) .NE. NINDX ) THEN
            CALL SETMSG ( 'The number of elements in the array '     //
     .                 'contaning indexes of indexed fields, '       //
     .                 'stored in the catalog '                      //
     .                 'metainformation at DAS addresses #:# is not '//
     .                 'equal to the number indexed fields #. '      )
            CALL ERRINT ( '#', I                                     )
            CALL ERRINT ( '#', J                                     )
            CALL ERRINT ( '#', NINDX                                 )
            CALL SIGERR ( 'SPICE(BADLISTTABARRAY)'                   )
            CALL CHKOUT ( 'STLD2'                                    )
            RETURN
         END IF
         CALL DASRDI ( HANDLE, I, J, LSTTAB )

C
C        Read number of nodes for each index table.
C
         CALL STGIT2 ( HANDLE, MDNNOD, I, J )
         IF ( ( J - I + 1 ) .NE. NINDX ) THEN
            CALL SETMSG ( 'The number of elements in the array '     //
     .                 'containing number of nodes for each index '  //
     .                 'table, stored in the catalog '               //
     .                 'metainformation at DAS addresses #:# is not '//
     .                 'equal to the number indexed fields #. '      )
            CALL ERRINT ( '#', I                                     )
            CALL ERRINT ( '#', J                                     )
            CALL ERRINT ( '#', NINDX                                 )
            CALL SIGERR ( 'SPICE(BADNODECOUNTSARRAY)'                )
            CALL CHKOUT ( 'STLD2'                                    )
            RETURN
         END IF
         CALL DASRDI ( HANDLE, I, J, NNODES )

C
C        TBD -- do we limit maximum number of nodes?
C        TBD -- should we have check non-zero number of nodes?
C

      END IF

C
C     Compute size of the declination band.
C
      DELDEC = PI() / NBANDS

C
C     Epoch flag and set star position and FOV epochs to default value
C     -- catalog epoch (see Particulars in STSEP2 entry.)
C
      EPFLAG = 0
      ETPOS  = ETCAT
      ETFOV  = ETCAT

C
C     Store catalog frame and catalog epoch "previous" values used in
C     STCRD2.
C
      FRAMPR = CFRAME
      ETFPR  = ETCAT

C
C     Set "loaded" flag.
C
      LOADED = .TRUE.

C
C     Perform the rest of necessary initializations.
C
      NCONST = 0
      RECLST = 0
      NREST  = -1
      ISDONE = .FALSE.
      ONLYMA = .FALSE.

C
C     Re-set search/fetch state flag.
C
      SRCHST = .FALSE.

C
C     Reset flag indicating that RA/DECs of the box circumscribing
C     FOV were computed.
C
      BOXSET = .FALSE.

      CALL CHKOUT ( 'STLD2' )

      RETURN


C$Procedure STULD2 ( unload catalog )

      ENTRY STULD2 ( HNDL )

C$ Abstract
C
C     Unload Type 2 SPICE Sky catalog.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               HNDL
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NAME      I/O  Field name to be examined
C     FOUND      O   Flag whether the field really exists
C
C$ Detailed_Input
C
C     NAME           is field name to be examined
C
C$ Detailed_Output
C
C     NAME           is input field name converted to uppercase,
C                    justified left and stripped from nonprintable
C                    symbols
C
C     FOUND          is flag whether the field really exists
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         RETURN
      END IF

      HNDL =  HANDLE
      LOADED = .FALSE.

      RETURN


C$Procedure STBOX2 ( compute RA, DEC box around FOV )

      ENTRY STBOX2

C$ Abstract
C
C     Calculate boundaries for the rectangle circumscribing the FOV.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C     None.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C     2) If no FOV constraint was set prior calling this routine,
C        then the error 'SPICE(FOVNOTSET)' will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     TBD --   need to add description of the algorithm.
C
C     TBD --   need to emphasize that it set RA1/2 and DEC1/2 for
C              future use
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C     Input FOV parameters must be set by calling STSF2 entry before
C     calling this routine.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     find zone boundaries for FOV in type_2 sky_catalog file
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STBOX2' )
      END IF

C
C     Check whether the catalog is really loaded.
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior '  //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STBOX2'                                   )
         RETURN
      END IF

C
C     Check whether FOV constraint was set.
C
      IF ( EPFLAG .EQ. 0 .OR. EPFLAG .EQ. 2 ) THEN
         CALL SETMSG ( 'No FOV constraint was set prior '         //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(FOVNOTSET)'                         )
         CALL CHKOUT ( 'STBOX2'                                   )
         RETURN
      END IF

C
C     Calculate RA and DEC for the FOV boresight.
C
      CALL RECRAD ( BORE, D, RA0, DEC0 )

C
C     Calculate boundaries for the rectangle (in RA, DEC)
C     circumscribing the FOV.
C
      IF ( FOV .EQ. FTCIRC .OR. FOV .EQ. FTELLI ) THEN

C
C        For simplicity, we treat CIRCLEs and ELLIPSEs the same way.
C        For cases when ellipses are very narrow we obtain odd area
C        but keep the approach so far.
C
         IF ( DEC0 + ALPHA .GE. HALFPI() ) THEN

            DEC1 = DEC0 - ALPHA
            DEC2 = HALFPI()
            RA1  = 0D0
            RA2  = TWOPI()

         ELSE IF (DEC0 - ALPHA .LE. -HALFPI() ) THEN

            DEC1 = -HALFPI()
            DEC2 = DEC0 + ALPHA
            RA1  = 0D0
            RA2  = TWOPI()

         ELSE

            DEC1 = DEC0 - ALPHA
            DEC2 = DEC0 + ALPHA
            DELRA = DASIN ( DSIN(ALPHA) / DCOS(DEC0) )

            RA1 = RA0 - DELRA
            IF ( RA1 .LT. 0D0 ) THEN
               RA1 = RA1 + TWOPI()
            END IF

            RA2 = RA0 + DELRA
            IF ( RA2 .LT. 0D0 ) THEN
               RA2 = RA2 + TWOPI()
            END IF

         END IF

      ELSE IF ( FOV .EQ. FTPOLY ) THEN

C
C        For POLYGONs there is a lot more work to be done. We need
C        to check every vertex to find the left-most and right-most
C        ones (with respect to the boresight.) We also need to check
C        whether any of the big circle arcs formed by individual
C        vertex planes has a point with DEC greater/smaller that all
C        vertex vector DECs.
C

         A =  10
         B = -10
         DEC1 =  2
         DEC2 = -2
         DO I = 1, NVERT

            CALL RECRAD ( VERT(1,I), D, RAI, DECI )

C
C           Analyse coordinates of current vertice. Do RAs first.
C
            D = RAI - RA0

            IF ( D .GT.  PI() ) THEN
               D = D - TWOPI()
            END IF

            IF ( D .LT. -PI() ) THEN
               D = D + TWOPI()
            END IF

            IF ( D .LT. A ) THEN
               RA1 = RAI
               A = D
            END IF

            IF ( D .GT. B ) THEN
               RA2 = RAI
               B = D
            END IF

C
C           Now, do DECs.
C
            DEC1 = DMIN1 ( DEC1, DECI )
            DEC2 = DMAX1 ( DEC2, DECI )

         END DO

         DO I = 2, NVERT

C
C           Check whether arc between VERT_i and VERT_i-1 vertices
C           contains points that have declination outside of the
C           VERT_i and VERT_i-1 range.
C
C           Let we have unit vectors R1 and R2. They form plane with
C           normal N12 = R1xR2. In this plane we have so-called
C           "critical" vector S
C                  _     _   _    _   _     o
C                  S = [ N - N  ( N . N  ) ]
C                         0   12   0   12
C
C           This vector corresponds to maximal (in absolute value)
C           declination in the vicinity of R1 and R2 vectors.
C           Here No is unit vector directed along North pole (Z-axis).
C           If S vector is within R1 to R2 arc, then the vector is to
C           be checked in terms of extremal value of declination.
C
C           The condition of S being within the arc can be expressed
C           by the following equation:
C
C                     _   _              _   _        1/2
C                   ( S . T ) > { [ 1+ ( R . R ) ]/2 } ,
C                                         1   2
C                 _                               _   _
C           where T is unit vector directed along R + R  vector.
C                                                  1   2
C
            S(1) =   - NORM(1,I-1) * NORM(3,I-1)
            S(2) =   - NORM(2,I-1) * NORM(3,I-1)
            S(3) = 1 - NORM(3,I-1) * NORM(3,I-1)
            CALL VADD ( VERT(1,I), VERT(1,I-1), T )
            CALL VHAT ( T, T )
            IF ( VDOT(S,T) .GT. DSQRT ( .5D0 * ( 1D0 +
     .              VDOT(VERT(1,I-1), VERT(1,I))))) THEN
               CALL RECRAD (S, D, RAI, DECI )
               DEC1 = DMIN1 ( DEC1, DECI )
               DEC2 = DMAX1 ( DEC2, DECI )
            END IF

         END DO

C
C        Check whether the Polygon covers north or south pole.
C        Remembering that our polygon is convex, this check reduced to
C        making sure that at least one vertix plane normal has negative
C        Z for North Pole to be outside and positive Z for south pole
C        to be outside. Check for North pole first.
C
         GOOD = .TRUE.
         DO I = 1, NVERT
            IF ( NORM(3,I) .LT. 0 ) THEN
               GOOD = .FALSE.
            END IF
         END DO

         IF ( GOOD ) THEN

C
C           The Polygon covers vector ( 0, 0, 1 )
C
            RA1 = 0D0
            RA2 = TWOPI()
            DEC2 = HALFPI()

         ELSE

C
C           Check for South pole.
C
            GOOD = .TRUE.
            DO I = 1, NVERT
               IF ( NORM(3,I) .GT. 0 ) THEN
                  GOOD = .FALSE.
               END IF
            END DO

            IF (GOOD) THEN

C
C              The Polygon covers vector ( 0, 0, -1 )
C
               RA1 = 0D0
               RA2 = TWOPI()
               DEC1 = -HALFPI()

            END IF

         END IF

      END IF

C
C     All done -- set flag indicating that RA/DECs of the box
C     circumscribing FOV were computed.
C
      BOXSET = .TRUE.

      CALL CHKOUT ( 'STBOX2' )

      RETURN


C$Procedure STCHN2 ( check whether the field name exists  )

      ENTRY STCHN2 ( NAME, FOUND )

C$ Abstract
C
C     Check whether the field name really exists, make "cosmetic"
C     editing and set flag "Only Main" if the field belongs to
C     MAIN block of fields
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     CHARACTER*(*)         NAME
C     LOGICAL               FOUND
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NAME      I/O  Field name to be examined
C     FOUND      O   Flag whether the field really exists
C
C$ Detailed_Input
C
C     NAME           is field name to be examined
C
C$ Detailed_Output
C
C     NAME           is input field name converted to uppercase,
C                    justified left and stripped from nonprintable
C                    symbols
C
C     FOUND          is flag whether the field really exists
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         RETURN
      END IF

C
C     "Comb" NAME and convert it to uppercase
C
      CALL STCMB2 ( .TRUE., NAME, NAM )

C
C     Find the NAME field number
C
      IFIELD = ESRCHC ( NAM, NFLDS, FLDNAM )

      IF ( IFIELD .EQ. 0 ) THEN

         CALL SETMSG ( 'Field ''#'' doesn''t exist in the catalog.'  )
         CALL ERRCH  ( '#', NAM                                      )
         CALL SIGERR ( 'SPICE(BADFIELDNAME)'                         )

      ELSE

         FOUND = .TRUE.

C
C        Set the record reading mode ( logical flag ONLYMA )
C
         IF ( IFIELD .LE. NMAIN ) THEN
            ONLYMA = .TRUE.
         ELSE
            ONLYMA = .FALSE.
         END IF

      END IF

      RETURN


C$Procedure STRFC2 ( read character field from the record )

      ENTRY STRFC2 ( COUT, FOUND )

C$ Abstract
C
C     The routine reads text field from the record. At the moment
C     of the routine calling the record is to be already unpacked
C     and the text field number IFIELD is to be defined.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     CHARACTER*(*)         COUT
C     LOGICAL               FOUND
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     COUT       O   Character variable with wanted text
C     FOUND      O   Flag whether the field is not blank
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     COUT           is character variable with wanted text
C
C     FOUND          is logical flag whether the field is not blank
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         RETURN
      END IF

      IF ( IFIELD .LT. 1 .OR. IFIELD .GT. NFLDS ) THEN
         CALL SETMSG ( 'Catalog record data was not loaded and ' //
     .                 'buffered prior to calling this routine.'  )
         CALL SIGERR ( 'SPICE(RECORDNOTLOADED)'                   )
         RETURN
      END IF

C
C     Fetch the character field from TEXT variable using TXTBEG
C     elements.
C
      I1   = TXTBEG(IFIELD)
      I2   = I1 - MAXABS(IFIELD) - 1
      COUT = TEXT(I1:I2)
      FOUND = .FALSE.

      IF ( COUT .NE. ' ' ) THEN

         FOUND = .TRUE.

      END IF

      RETURN


C$Procedure STRFI2 ( read integer field from the record )

      ENTRY STRFI2 ( IOUT, FOUND )

C$ Abstract
C
C     The routine reads integer field from the record. At the moment
C     of the routine calling the record is to be already unpacked
C     and the wanted field number IFIELD is to be defined.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               IOUT
C     LOGICAL               FOUND
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     IOUT       O   Integer variable with wanted value
C     FOUND      O   Flag whether the data exists
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     IOUT           is integer variable with wanted value
C
C     FOUND          is logical flag whether the data exists
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         RETURN
      END IF

      IF ( IFIELD .LT. 1 .OR. IFIELD .GT. NFLDS ) THEN
         CALL SETMSG ( 'Catalog record data was not loaded and ' //
     .                 'buffered prior to calling this routine.'  )
         CALL SIGERR ( 'SPICE(RECORDNOTLOADED)'                   )
         RETURN
      END IF

      FOUND = .FALSE.

      IF ( VALUE(IFIELD) .NE. MAXABS(IFIELD) ) THEN

        IOUT  = MINVAL(IFIELD) + DBLE( MAXABS(IFIELD)+
     .            VALUE(IFIELD) ) / 10**ACCUR(IFIELD)
        FOUND = .TRUE.

      END IF

      RETURN


C$Procedure STRFD2 ( read double precision field from the record )

      ENTRY STRFD2 ( DOUT, FOUND )

C$ Abstract
C
C     The routine reads double precision field from the record.
C     At the moment of the routine calling the record is to be
C     already unpacked and the wanted field number IFIELD is
C     to be defined.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     DOUBLE PRECISION      DOUT
C     LOGICAL               FOUND
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     DOUT       O   Double precision variable with wanted value
C     FOUND      O   Flag whether the data exists
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     DOUT           is double precision variable with wanted value
C
C     FOUND          is logical flag whether the data exists
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     None.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         RETURN
      END IF

      IF ( IFIELD .LT. 1 .OR. IFIELD .GT. NFLDS ) THEN
         CALL SETMSG ( 'Catalog record data was not loaded and ' //
     .                 'buffered prior to calling this routine.'  )
         CALL SIGERR ( 'SPICE(RECORDNOTLOADED)'                   )
         RETURN
      END IF

      FOUND = .FALSE.

      IF ( VALUE(IFIELD) .NE. MAXABS(IFIELD) ) THEN

        DOUT = MINVAL(IFIELD) + DBLE( MAXABS(IFIELD)+
     .            VALUE(IFIELD) ) / 10**ACCUR(IFIELD)
        FOUND = .TRUE.

      END IF

      RETURN


C$Procedure STGB2 ( get range of DEC bands covering the FOV )

      ENTRY STGB2 ( IBAND1, IBAND2 )

C$ Abstract
C
C     Determine the range of declination bands for a given FOV
C     contraint.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               IBAND1
C     INTEGER               IBAND2
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     IBAND1     O   Index of lowest declination band covering FOV
C     IBAND2     O   Index of highest declination band covering FOV
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     IBAND1         is the index of the lowest declination band
C                    covering FOV.
C
C     IBAND2         is the index of the highest declination band
C                    covering FOV.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C     2) If boundaries of the RA-DEC box circumscribing FOV were not
C        prior to calling this entry,  then the error
C        'SPICE(BOUNDARIESNOTSET)' will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     The routine is used to determine the range of declination bands
C     covering FOV that has been set by a call to STSF2 entry of this
C     umbrella.
C
C     Before calling this entry, the STBOX2 entry must be called
C     compute coordinates of RA-DEC box corners circumscribing our FOV.
C     The corners are saved in the local variables RA1, RA2, DEC1,
C     DEC2.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C     The boundaries of the RA-DEC box circumscribing FOV must be
C     determined using STBOX2 entry of this routine prior to
C     calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     get DEC band range for FOV in type_2 sky_catalog file
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STGB2' )
      END IF

C
C     Check whether the catalog is really loaded.
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior '  //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STGB2'                                    )
         RETURN
      END IF

C
C     Check whether RA/DEC box circumscribing FOV was computed.
C
      IF ( .NOT. BOXSET ) THEN
         CALL SETMSG ( 'RA/DEC box circumscribing FOV was not '   //
     .                 'computed by a call to STBOX2 prior '      //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(BOUNDARIESNOTSET)'                  )
         CALL CHKOUT ( 'STGB2'                                    )
         RETURN
      END IF

C
C     Compute indexes of the of the lowest and highest DEC bands in
C     the box circumscribing out FOV. (DELDEC is guaranteed to be
C     non-zero :-)
C
      IBAND1 = 1 + ( HALFPI() - DEC2 ) / DELDEC
      IBAND2 = 1 + ( HALFPI() - DEC1 ) / DELDEC
      IBAND2 = MIN0 ( IBAND2, NBANDS )

      CALL CHKOUT ( 'STGB2' )

      RETURN


C$Procedure STGZ2 ( get range of zones in DEC band covering FOV )

      ENTRY STGZ2 ( IBAND, IZONE1, IZONE2 )

C$ Abstract
C
C     Determine range of zones covering FOV within the specified
C     declination band covering FOV.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               IBAND
C     INTEGER               IZONE1
C     INTEGER               IZONE2
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     IBAND      I   The declination band index
C     IZONE1     O   Index of the leftmost elementary zone within band
C     IZONE2     O   Index of the rightmost elementary zone within band
C
C$ Detailed_Input
C
C     IBAND          is the declination band index.
C
C$ Detailed_Output
C
C     IZONE1         is the index of the leftmost RA zone covering FOV
C                    within the specified declination band covering FOV.
C
C     IZONE2         is the index of the rightmost RA zone covering
C                    FOV within the specified declination band covering
C                    FOV.
C
C                    IZONE2 is always greater or equal to IZONE1, and
C                    for all cases when FOV covers prime meridian
C                    IZONE2 will greater than the number of zones in
C                    the specified declination band.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C     2) If boundaries of the RA-DEC box circumscribing FOV were not
C        prior to calling this entry,  then the error
C        'SPICE(BOUNDARIESNOTSET)' will be signalled.
C
C     3) If specified declination band does not cover FOV, then the
C        error 'SPICE(BANDDOESNCOVERFOV)' will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     The routine is used to determine the range of right ascension
C     zones covering FOV within specified declibation band covering FOV
C     that has been set by a call to STSF2 entry of this umbrella.
C
C     Before calling this entry, the STBOX2 entry must be called
C     compute coordinates of RA-DEC box corners circumscribing our FOV.
C     The corners are saved in the local variables RA1, RA2, DEC1,
C     DEC2.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C     The boundaries of the RA-DEC box circumscribing FOV must be
C     determined using STBOX2 entry of this routine prior to
C     calling this entry.
C
C     The specified declination band must cover FOV.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     get RA zone range for FOV in type_2 sky_catalog file
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STGZ2' )
      END IF

C
C     Check whether the catalog is really loaded.
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior '  //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STGZ2'                                    )
         RETURN
      END IF

C
C     Check whether RA/DEC box circumscribing FOV was computed.
C
      IF ( .NOT. BOXSET ) THEN
         CALL SETMSG ( 'RA/DEC box circumscribing FOV was not '   //
     .                 'computed by a call to STBOX2 prior '      //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(BOUNDARIESNOTSET)'                  )
         CALL CHKOUT ( 'STGZ2'                                    )
         RETURN
      END IF

C
C     Check whether DEC band covers FOV.
C
      IF ( ( IBAND .LT. INT(1+(HALFPI()-DEC2)/DELDEC)         ) .OR.
     .     ( IBAND .GT. MIN0(INT(1+(HALFPI()-DEC1)/DELDEC), NBANDS ) ) )
     .THEN
         CALL SETMSG ( 'DEC band # does not cover FOV.'           )
         CALL ERRINT ( '#', IBAND                                 )
         CALL SIGERR ( 'SPICE(BANDDOESNCOVERFOV)'                 )
         CALL CHKOUT ( 'STGZ2'                                    )
         RETURN
      END IF

C
C     Compute zone size from number of zones in band.
C
      NZON = NINBND(IBAND)
      D = TWOPI() / NZON

C
C     Determine left most and right most zone indexes.
C
      IZONE1 = 1 + RA1 / D
      IZONE2 = 1 + RA2 / D

      IF ( IZONE2 .GT. NZON ) THEN
         IZONE2 = NZON
      END IF

C
C     If IZONE1 is greater that IZONE2, i.e. our FOV covers "prime
C     meridian", then we add number of zones to IZONE2 to place it to
C     the right of IZONE1. This puts IZONE2 outside of the 1..NZON
C     range, but it will ensure incresing indexing when IZONE1 to
C     IZONE2.
C
      IF ( IZONE2 .LT. IZONE1 ) THEN
         IZONE2 = IZONE2 + NZON
      END IF

      CALL CHKOUT ( 'STGZ2' )

      RETURN


C$Procedure STGR2 ( get range of records in specified zone )

      ENTRY STGR2 ( IBAND, IZONE, RECNO1, RECNO2 )

C$ Abstract
C
C     Determine range of catalog record indexes in the specified
C     elementary zone.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               IBAND
C     INTEGER               IZONE
C     INTEGER               RECNO1
C     INTEGER               RECNO2
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     IBAND      I   Index of declination band
C     IZONE      I   Index of elementary zone within the band
C     RECNO1     O   Index of the first record within the zone
C     RECNO2     O   Index of the last record within the zone
C
C$ Detailed_Input
C
C     IBAND          is the declination band index.
C
C     IZONE          is the elementary zone index within given
C                    declination band.
C
C                    This index can be outside of the zone index range
C                    for given declination band. If it is outside, it
C                    will adjusted by adding (if it's less than 1) or
C                    subtracting (if it's greater than the number of
C                    zones) the number of zones in the band to/from it.
C                    For example all
C
C                       IZONE = 5
C                       IZONE = -5
C                       IZONE = 15
C
C                    refer to the zone 5 in the 10 zone band.
C
C$ Detailed_Output
C
C     RECNO1         is the index of the first catalog object within
C                    given zone.
C
C     RECNO2         is the index of the last catalog object within
C                    given zone.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C     2) If specified band is less or equal to 0 or greater than the
C        number of bands in the catalog, then the error
C        'SPICE(INVALIDBANDINDEX)' will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     TBD
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     get range of records for zone of type_2 sky_catalog file
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STGR2' )
      END IF

C
C     Check whether the catalog is really loaded.
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior '  //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STGR2'                                    )
         RETURN
      END IF

C
C     Check whether IBAND makes sense.
C
      IF ( IBAND .LE. 0 .OR. IBAND .GT. NBANDS ) THEN
         CALL SETMSG ( 'Specified band index # is outside of '    //
     .                 'the catalog DEC band range 1..#.'         )
         CALL ERRINT ( '#', IBAND                                 )
         CALL ERRINT ( '#', NBANDS                                )
         CALL SIGERR ( 'SPICE(INVALIDBANDINDEX)'                  )
         CALL CHKOUT ( 'STGR2'                                    )
         RETURN
      END IF

C
C     Get number of zones in the band.
C
      NZON = NINBND( IBAND )

C
C     Generate IZ - elementary zone number in the band.
C
      IZ = IZONE
      IF       ( IZ .LT. 1 )    THEN

         IZ = IZ + NZON
         DO WHILE ( IZ .LT. 1 )
            IZ = IZ + NZON
         END DO

              ELSE IF  ( IZ .GT. NZON ) THEN

         IZ = IZ - NZON
         DO WHILE ( IZ .GT. NZON )
            IZ = IZ - NZON
         END DO

      END IF

C
C     Now compute ITHRGH - through number of the elementary zone.
C
      ITHRGH = IZ + NSUM( IBAND )

C
C     Determine range of record numbers in the zone.
C
      RECNO1 = INPOS( ITHRGH )

      IF ( ITHRGH .EQ. NZONES ) THEN
         RECNO2 = NOBJ
      ELSE
         RECNO2 = INPOS( ITHRGH + 1) - 1
      END IF

      CALL CHKOUT ( 'STGR2' )

      RETURN


C$Procedure STINF2 ( get information necessary for fetch data )

      ENTRY STINF2 ( FOVSET, NCNSTR, NRINDX, INDXED, NOB, FRAME, HNDL )

C$ Abstract
C
C     Get set information about catalog and search constraints that
C     is necessary initialize and carry out data fetch.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     LOGICAL               FOVSET
C     INTEGER               NCNSTR
C     INTEGER               NRINDX
C     INTEGER               INDXED(2,*)
C     INTEGER               NOB
C     CHARACTER*(*)         FRAME
C     INTEGER               HNDL
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     FOVSET     O   Logical flag that the FOV has been set
C     NCNSTR     O   Number of fields that are constrained
C     NRINDX     O   Number of fields that are constrained and indexed
C     INDXED     O   List of constrained field numbers and attributes
C     NOB        O   Number of sky objects in the catalog
C     FRAME      O   Catalog frame name
C     HNDL       O   Catalog file handle
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     FOVSET         is logical flag indicating whether that FOV
C                    constraint has been set.
C
C     NCNSTR         is the number of fields that were constrained.
C                    If any of the constraints would result in
C                    resultless search, NCNSTR is set to -1.
C
C     NRINDX         is the number of indexed fields that were
C                    constrained.
C
C     INDXED         is a two-dimensional integer array containing
C                    numbers of fields that were constrained (elements
C                    INDXED(1,i)), then numbers of index tables
C                    corresponding to these fields (elements
C                    INDXED(2,i)) for all NRINDX fields that are
C                    constrained AND indexed.
C
C     NOB            is the number of sky objects in the catalog.
C
C     FRAME          is catalog frame name.
C
C     HNDL           is catalog file handle.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is loaded at the time when this
C        routine is called, then the error 'SPICE(CATALOGISNOTLOADED)'
C        will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     The entry is used by STFCH2 routine to obtain information
C     about catalog and containts needed to carry out search/fetch
C     process.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be loaded using STLD2 entry
C     of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     get type_2 sky_catalog constraint infrormation
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STINF2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STINF2' )
         RETURN
      END IF

C
C     Check whether the FOV has already been set
C
      IF ( EPFLAG .EQ. 0 .OR. EPFLAG .EQ. 2 ) THEN
         FOVSET = .FALSE.
      ELSE
         FOVSET = .TRUE.
      END IF

C
C     Check whether any of the constraints had "no-result" flag set.
C     If so, set NCNSTR to -1.
C
      NCNSTR = NCONST
      DO I = 1, NCONST
         IF ( .NOT. CTRFLG(I) ) THEN
            NCNSTR = -1
         END IF
      END DO

C
C     Pass local data.
C
      NOB    = NOBJ
      FRAME  = CFRAME
      HNDL   = HANDLE

C
C     Generate array with numbers of the constrained/indexed fields
C     and corresponding index tables.
C
      NRINDX = 0

      DO I = 1, NCONST

         DO J = 1, NINDX

            IF ( FLDPAR(1,I) .EQ. LSTTAB(J) ) THEN

                NRINDX           = NRINDX+1
                INDXED(1,NRINDX) = FLDPAR(1,I)
                INDXED(2,NRINDX) = J

            END IF

         END DO

      END DO

C
C     We filled out array INDXED(2,NRINDX), where NRINDX is the number
C     of fields that are constrained AND indexed. The element
C     INDXED(1,i) of this array is field number for "i-th" field
C     whereas element INDXED(2,i) is the index table number for that
C     field.
C
      CALL CHKOUT ( 'STINF2' )

      RETURN


C$Procedure STRF2 ( set "fast reading" flag )

      ENTRY STRF2

C$ Abstract
C
C     Set logical flag to unpack only MAIN part of DATA record
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     None
C
C$ Brief_I/O
C
C     None
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     Perhaps the most sophisticated routine in the SPICE software
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         RETURN
      END IF

      ONLYMA = .TRUE.

      RETURN


C$Procedure STCHL2 ( check whether a catalog is loaded )

      ENTRY STCHL2 ( OK )

C$ Abstract
C
C     Return logical flag indicating whether Type 2 catalog was
C     loaded.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     None
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     OK         O   Logical flag indicating that the catalog is loaded
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     OK             is logical flag that the catalog is loaded.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     If a Type 2 sky catalog was loaded by calling STLD2 entry of
C     this umbrella, this routine will return OK = .TRUE.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

      IF ( LOADED ) THEN
         OK = .TRUE.
      ELSE
         OK = .FALSE.
      END IF

      RETURN

C$Procedure STSSS2 ( get/set search/fetch status )

      ENTRY STSSS2 ( ACTION, STATUS )

C$ Abstract
C
C     Sets/returns logical flag indicating whether search/fetch in
C     Type 2 catalog is in progress.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     None
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     ACTION     I   String indicating action to be taken by routine
C     STATUS    I/O  Logical flag indicating the search/fetch status
C
C$ Detailed_Input
C
C     ACTION         is a string indicating action to be taken by
C                    routine: 'SET' to set search status, 'GET' to
C                    return search status. Case insensitive.
C
C     STATUS         is the logical flag indicating how search/fetch
C                    status must be set: .TRUE. -- search is in
C                    progress and can continue; .FALSE. -- search
C                    stopped or must be terminated.
C
C$ Detailed_Output
C
C     STATUS         is the logical flag indicating how search/fetch
C                    status was set: .TRUE. -- search is in
C                    progress and can continue; .FALSE. -- search
C                    stopped or must be terminated.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no Type 2 catalog is loaded at the time when this routine
C        is called, then the error 'SPICE(CATALOGISNOTLOADED)' will
C        be signalled.
C
C     2) If specified action is not supported by this routine, then
C        the error 'SPICE(UNSUPPORTEDACTION)' will be signalled.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     This routine is a mechanism that allowed to pass knowledge about
C     current state of the search/fetch process between this umbrella
C     and STFCH2 routine. Such exchange is required to make sure that
C     search/fetch is re-initialized in STFCH2 if any of the
C     constraints set by entries of this routine changed.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     TBD
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
        RETURN
      ELSE
        CALL CHKIN ( 'STSSS2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STSSS2'                                   )
         RETURN
      END IF

C
C     Set or get search/fetch status.
C
      IF      ( EQSTR( ACTION, 'SET' ) ) THEN
         SRCHST = STATUS
      ELSE IF ( EQSTR( ACTION, 'GET' ) ) THEN
         STATUS = SRCHST
      ELSE
         CALL SETMSG ( 'Action ''#'' is not supported by this '  //
     .                 'routine.'                                 )
         CALL ERRCH  ( '#', ACTION                                )
         CALL SIGERR ( 'SPICE(UNSUPPORTEDACTION)'                 )
         CALL CHKOUT ( 'STSSS2'                                   )
         RETURN
      END IF

      CALL CHKOUT ( 'STSSS2' )

      RETURN


C$Procedure  STCIN2 ( get the general information for type 2 catalog )

      ENTRY STCIN2 ( NAME, OBTYP, ETIME, FRAME, MATR, NOB )

C$ Abstract
C
C     Fetch general information from the DAS file with the SPICE
C     catalog
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NAME       O   The catalog name
C     OBTYP      O   Type of the catalog objects
C     ETIME      O   Epoch for sky objects position
C     FRAME      O   Frame for sky objects position
C     MATR       O   Transformation matrix from the catalog frame
C                    to the J2000 inertial frame
C     NOB        O   The number of objects in the catalog
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     NAME           is the Original Catalog name
C
C     OBTYP          is the type of the catalog objects - arbitrary
C                    string ( certain values recommended )
C
C     ETIME          is the epoch for sky objects position ( ET
C                    seconds past J2000 )
C
C     FRAME          is the frame for sky objects position
C                    ( SPICE frame )
C
C     MATR           is the transformation matrix from the catalog
C                    frame to the J2000 inertial frame (used only in
C                    situation when the catalog frame is not
C                    recognized by SPICE)
C
C     NOB            is the number of objects in the catalog
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error Free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     The entry provides user with set of "general" parameters
C     of the SPICE catalog: its name, the number of objects, type
C     of the objects, epoch and frame for their positions. Epoch
C     is presented in ephemery time seconds past 2000. Frame is
C     presented either by character string that is SPICE frame or
C     (if it does not match any SPICE frame) by transfer matrix
C     from the catalog frame to the J2000 inertial frame. In the
C     first case (if the character string is SPICE frame) we do
C     not use the matrix, so its elements could be zeros.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     ?????
C
C-&
C

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
        RETURN
      ELSE
        CALL CHKIN ( 'STCIN2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STCIN2'                                   )
         RETURN
      END IF

C
C     Return all reqired parameters
C
      NAME  = CATNAM
      OBTYP = OBTYPE
      ETIME = ETCAT
      FRAME = CFRAME
      NOB   = NOBJ

      DO I = 1, 3
         DO J = 1, 3
            MATR ( I, J ) = MATRIX ( I, J )
         END DO
      END DO

      CALL CHKOUT ( 'STCIN2' )

      RETURN


C$Procedure  STGCD2 ( get the catalog description )

      ENTRY STGCD2 ( ROOM, FIRST, NRET, DESCR )

C$ Abstract
C
C     Get descriptive information about the SPICE catalog
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TBD
C
C
C$ Declarations
C
C     INTEGER               ROOM
C     INTEGER               FIRST
C     INTEGER               NRET
C     CHARACTER*(*)         DESCR(*)
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     ROOM       I   The largest number of lines to return
C     FIRST      I   Which line to start retrieving
C     NRET       O   The number of lines returned in the DESCR array
C     DESCR      O   Character strings with the catalog description
C
C$ Detailed_Input
C
C     ROOM           is the largest number of lines to return
C
C     FIRST          is "order" which line to start retrieving with
C
C$ Detailed_Output
C
C     NRET           is the number of lines returned
C
C     DESCR          is an array of character strings (lines) with
C                    the catalog description
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error Free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     As it is clear from the abstract, the routine is to provide
C     user with pre-defined portion of descriptive information
C     about the catalog stored in METAINFORMATION segment as
C     character*80 array DESCR.
C
C     Each "portion" of the information is defined by two input
C     parameters ROOM (that is space available for located strings)
C     and FIRST (that is element of DESCR array to start with).
C
C     The task is solved using local integer number NREST that
C     is equal to the number of lines that are not returned so far.
C
C     Before the first call we have (by definition) NREST = -1.
C     At the first call we fetch from the METAINFORMATION segment
C     the number of lines (elements) in DESCR array and assign the
C     number to NREST.
C     Each time (on each call) we return NRET = MIN ( NREST, ROOM )
C     lines and subtract NRET from NREST. And if at current call
C     we obtain and return NRET = 0 it means that we are through
C     with the information and that it is hightime to assign -1
C     to NREST to be ready for next data retrieving.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     ?????
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
        RETURN
      ELSE
        CALL CHKIN ( 'STGCD2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STGCD2'                                   )
         RETURN
      END IF

      IF ( NREST .LT. 0 ) THEN
         CALL STGIT2 ( HANDLE, 'CAT_DESCR_N', I, J )
         CALL DASRDI ( HANDLE, I, J, NREST         )
         CALL STGIT2 ( HANDLE, 'CAT_DESCR', I1, I2 )
      END IF

C
C     NREST shows how many lines are not passed so far.
C     NRET is the number of lines to be returned
C
      NRET = MIN ( NREST, ROOM )

C
C     Read from our DAS file information corresponding to given
C     NRET lines of the catalog description
C
      I = I1 + ( FIRST - 1 ) * (DSCLSZ/NCHARI)
      CALL DASRDI ( HANDLE, I, I+NRET*(DSCLSZ/NCHARI)-1, Z )
      DO I = 1, NRET
         K = 1 + (DSCLSZ/NCHARI) * (I-1)
         CALL STI2T2 ( Z(K), DSCLSZ/NCHARI, DESCR(I), J )
      END DO

C
C     Modify NREST
C
      NREST = NREST - NRET

      IF ( NRET .EQ. 0 ) THEN
         NREST = -1
      END IF

      CALL CHKOUT ( 'STGCD2' )

      RETURN


C$Procedure  STFIN2 ( get the fields information )

      ENTRY  STFIN2 ( NFLD, FLNAM, FLTYP, FLCLS, FLIND )

C$ Abstract
C
C     Get information about the SPICE catalog fields
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               NFLD
C     CHARACTER*(*)         FLNAM (*)
C     CHARACTER*(1)         FLTYP (*)
C     CHARACTER*(*)         FLCLS (*)
C     LOGICAL               FLIND (*)
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NFLD       O   The number of fields in the OTC record
C     FLNAM      O   Array of the field names
C     FLTYP      O   Array of the field types
C     FLCLS      O   Array of the field classes
C     FLIND      O   Array of the field indexing flags
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     NFLD           is the number of fields in the original text
C                    catalog record
C
C     FLNAM          is the array of the field names
C
C     FLTYP          is the array of the field types ( 'C' - text,
C                    'I' - integer, 'D' - double precision )
C
C     FLCLS          is the array of the field classes (see
C                    inlude file for complete list of permitted
C                    field class names.)
C
C     FLIND          is the array of the field indexing flags
C                    (.T. - indexed, .F. - non indexed )
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error Free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     The routine provides user with review of fields
C     characteristics, namely the number of fields, fieldnames,
C     field types and classes. We shall distinguish two kinds of
C     field types: numerical and text. See include file for 
C     the complete list of field classes.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     ?????
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
        RETURN
      ELSE
        CALL CHKIN ( 'STFIN2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STFIN2'                                   )
         RETURN
      END IF

      NFLD = NFLDS

      DO I = 1, NFLDS

         FLNAM(I) = FLDNAM(I)

C
C        Assign output field type using buffered type index.
C
         IF      ( FLTYPE(I) .EQ. 0 ) THEN
            FLTYP(I) = 'C'
         ELSE IF ( FLTYPE(I) .EQ. 1 ) THEN
            FLTYP(I) = 'I'
         ELSE
            FLTYP(I) = 'D'
         END IF

C
C        Assign uutput field class using buffered value.
C
         FLCLS(I) = FLDCLS(I) 

C
C        Assign output indexed flag using buffered integer flag.
C
         IF ( FLDIND(I) .EQ. 0 ) THEN
            FLIND(I) = .FALSE.
         ELSE
            FLIND(I) = .TRUE.
         END IF

      END DO

      CALL CHKOUT ( 'STFIN2' )

      RETURN


C$Procedure  STFLD2 ( get the field description )

      ENTRY STFLD2 ( ROOM, FIRST, NRET, DESCR )

C$ Abstract
C
C     Get descriptive information about the pre-defined field
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               ROOM
C     INTEGER               FIRST
C     INTEGER               NRET
C     CHARACTER*(*)         DESCR(*)
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     FIELD      I   Field name to be examined
C     ROOM       I   The largest number of lines to return
C     FIRST      I   Which line to start retrieving with
C     NRET       O   The number of lines returned in the
C                    DESCR array
C     DESCR      O   Character array containing descriptions
C                    for all consequent fields
C
C$ Detailed_Input
C
C     FIELD          is a name of the field to be examined
C
C     ROOM           is the largest number of lines to return
C
C     FIRST          is "order" which line to start retrieving with
C
C$ Detailed_Output
C
C     NRET           is the number of lines returned in DESCR array
C
C     DESCR          is an array of character strings (lines) with
C                    the field description
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error Free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     As it is clear from the abstract, the routine is to provide
C     user with pre-defined portion of descriptive information
C     about the catalog stored in character*80 array DESCR.
C
C     Each "portion" of the information is defined by two input
C     parameters ROOM (that is space available for located strings)
C     and FIRST (that is element of DESCR array to start with).
C
C     The task is solved using local integer number NREST that
C     is equal to the number of lines that are not returned so far.
C
C     Before the first call we have (by definition) NREST = -1.
C     At the first call we assign FLD_DESC_N to NREST.
C     Each time (on each call) we return NRET = MIN ( NREST, ROOM )
C     lines and subtract NRET from NREST. And if at current call
C     we obtain and return NRET = 0 it means that we are through
C     with the information and that it is hightime to assign -1
C     to NREST to be ready for next data retrieving.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     ?????
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
        RETURN
      ELSE
        CALL CHKIN ( 'STFLD2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STFLD2'                                   )
         RETURN
      END IF

      IF ( NREST .LT. 0 ) THEN

         CALL STGIT2 ( HANDLE, 'FIELD_DESC_N', I1, I2 )
         CALL DASRDI ( HANDLE, I1, I2, Z )

C
C        Now Z array contains FIELDS_DESC_N values for consequent
C        fields.
C
         L = 0
         DO J = 1, IFIELD - 1
            L = L + Z(J)
         END DO
         NREST = Z(IFIELD)
C
C        Now L is the number of lines in entire fields description
C        text to be skipped and NREST is the number of lines for
C        the selected field. So, we are to start read DAS file from
C        record I1 returned by the following statement:
C
         CALL STGIT2 ( HANDLE, 'FIELD_DESC', I1, I2 )

      END IF

C
C     NREST shows how many lines are not passed so far.
C     NRET is the number of lines to be returned
C
      NRET = MIN ( NREST, ROOM )

      IF ( NREST .GT. 0 ) THEN

C
C        Read from our DAS file information corresponding to given
C        NRET lines of the field description
C
         I = I1 + ( FIRST + L - 1 ) * (DSCLSZ/NCHARI)
         CALL DASRDI ( HANDLE, I, I + NRET * (DSCLSZ/NCHARI) - 1, Z )
         DO I = 1, NRET
            K = 1 + (DSCLSZ/NCHARI) * (I-1)
            CALL STI2T2 ( Z(K), DSCLSZ/NCHARI, DESCR(I), J )
         END DO

C
C        Modify NREST
C
         NREST = NREST - NRET

      ELSE

         NREST = -1

      END IF

      CALL CHKOUT ( 'STFLD2' )

      RETURN


C$Procedure  STNFA2 ( get attributes for numerical field )

      ENTRY  STNFA2 ( NAME, MINV, MAXV, NDIG, MISSED )

C$ Abstract
C
C     Get information about certain numerical field features:
C     range, presentation, amount of missing data
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     CHARACTER*(*)         NAME
C     DOUBLE PRECISION      MINV
C     DOUBLE PRECISION      MAXV
C     INTEGER               NDIG
C     INTEGER               MISSED
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NAME       I   Field name to be examined
C     MINV       O   Minimal value in the field through
C                    all the catalog converted to
C                    double precision
C     MAXV       O   Maximal value in the field through
C                    all the catalog converted to
C                    double precision
C     NDIG       O   The number of digits after decimal
C                    point in the parameter presentation
C     MISSED     O   The number of missing data in the
C                    field through all the catalog
C
C$ Detailed_Input
C
C     NAME           is a name of the field to be examined
C
C$ Detailed_Output
C
C     MINV           is the minimal value in the field through
C                    all the catalog converted to double precision
C
C     MAXV           is the maximal value in the field through
C                    all the catalog converted to double precision
C
C     NDIG           is the number of digits after decimal point
C                    in the parameter presentation
C
C     MISSED         is the number of missing data in the field
C                    through all the catalog
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error Free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     At the very beginning of the catalog generation we look
C     through the original text catalog and analyze range and
C     presentation format for each numerical parameter of the
C     catalog objects. Besides, we obtain the number of missing
C     data for each parameter.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     ?????
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
        RETURN
      ELSE
        CALL CHKIN ( 'STNFA2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STNFA2'                                   )
         RETURN
      END IF

C
C     "Comb" NAME and convert it to uppercase
C
      CALL STCMB2 ( .TRUE., NAME, NAM )

C
C     Find the NAME field number
C
      IFIELD = ESRCHC ( NAM, NFLDS, FLDNAM )

      IF ( IFIELD .EQ. 0 ) THEN

         CALL SETMSG ( 'Field ''#'' doesn''t exist in the catalog.' )
         CALL ERRCH  ( '#', NAM                                     )
         CALL SIGERR ( 'SPICE(BADFIELDNAME)'                        )
         CALL CHKOUT ( 'STNFA2'                                     )
         RETURN

      END IF
C
C     Fetch all required information for the field number obtained
C
      MINV = MINVAL (IFIELD)
      MAXV = MINV + MAXABS(IFIELD) * 2D0 / 10**ACCUR(IFIELD)
      NDIG = ACCUR  (IFIELD)
      MISSED = MISS (IFIELD)

      CALL CHKOUT ( 'STNFA2' )

      RETURN



C$Procedure STCFA2 ( get attributes for text field )

      ENTRY STCFA2 ( NAME, SIZE, MISSED )

C$ Abstract
C
C     Get information about certain text field features:
C     maximal size, amount of missing data
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               SIZE
C     INTEGER               MISSED
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NAME       I   Field name to be examined
C     SIZE       O   Maximal size of text string in the
C                      field through all the catalog (in bytes)
C     MISSED     O   The number of missing data in the
C                      field through all the catalog
C
C$ Detailed_Input
C
C     NAME           is a name of the field to be examined
C
C$ Detailed_Output
C
C     SIZE           is the maximal size of text string in the
C                    field through all the catalog (in bytes)
C
C     MISSED         is the number of missing data in the field
C                    through all the catalog
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error Free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     At the very beginning of the catalog generation we look
C     through the original text catalog and analyze maximal size
C     for each character parameter of the catalog objects. Besides,
C     we obtain the number of missing data for each parameter.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     ?????
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
        RETURN
      ELSE
        CALL CHKIN ( 'STCFA2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STCFA2'                                   )
         RETURN
      END IF

C
C     "Comb" NAME and convert it to uppercase
C
      CALL STCMB2 ( .TRUE., NAME, NAM )

C
C     Find the NAME field number
C
      IFIELD = ESRCHC ( NAM, NFLDS, FLDNAM )

      IF ( IFIELD .EQ. 0 ) THEN

         CALL SETMSG ( 'Field ''#'' doesn''t exist in the catalog.' )
         CALL ERRCH  ( '#', NAM                                     )
         CALL SIGERR ( 'SPICE(BADFIELDNAME)'                        )
         CALL CHKOUT ( 'STCFA2'                                     )
         RETURN

      END IF

C
C     Fetch all required information for the field number obtained
C
      SIZE = - MAXABS (IFIELD)
      MISSED = MISS   (IFIELD)

      CALL CHKOUT ( 'STCFA2' )

      RETURN


C$Procedure STZSZ2 ( get size of a zone in declination )

      ENTRY STZSZ2 ( VAL )

C$ Abstract
C
C     Get information about the SPICE catalog geometrical
C     organization - about the celestial sphere splitting to
C     bands and zones and about the catalog objects distribution
C     along the zones
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     DOUBLE PRECISION      VAL
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     VAL        O   Size of elementary zone in radians
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     VAL            is size of elementary zone in radians
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error Free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     The following scheme of "positional" catalog organization
C     is suggested. The celestial sphere is divided to ordered
C     set of "elementary zones" with the following geometry.
C     The celestial sphere is subdivided to "declination bands"
C     that are bounded by small circles and correspond equally
C     spaced declinations from +pi/2 to -pi/2 with constant step
C     delDEC. Each band is subdivided into "elementary zones" by
C     great circles of right ascension. In each band this "cutting"
C     is carried out in such a way to obtain equal zones with width
C     as close to height as possible. Within each zone objects are
C     ordered by right ascension.
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     ?????
C
C-&

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         RETURN
      END IF

      VAL = PI() / NBANDS

      RETURN


C$Procedure STZAT2 ( get information about elementary zones )

      ENTRY STZAT2 ( NBAND, NZ, INBAND, INZONE )

C$ Abstract
C
C     Get information about the SPICE catalog geometrical
C     organization - about the celestial sphere splitting to
C     bands and zones and about the catalog objects distribution
C     along the zones
C
C$ Copyright
C
C     Copyright (1999), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     None.
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               NBAND
C     INTEGER               NZ
C     INTEGER               INBAND (*)
C     INTEGER               INZONE (*)
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NBAND      O   The number of declination bands
C                    on the celestial sphere
C     NZ         O   Total number of elementary zones
C                    on the celestial sphere
C     INBAND     O   Integer array of NBAND
C                    elements where i-th element is the
C                    number of elementary zones belonging
C                    to the i-th declination band
C     INZONE     O   Integer array of NZ elements
C                    where i-th element is the number of
C                    objects within the i-th elementary zone
C
C$ Detailed_Input
C
C     None
C
C$ Detailed_Output
C
C     NBAND          is the number of declination bands on the
C                    celestial sphere
C
C     NZ             is total number of elementary zones on the
C                    celestial sphere
C
C     INBAND         is integer array of NBAND elements
C                    where i-th element is the number of elementary
C                    zones belonging to the i-th declination band
C
C     INZONE         is integer array of NZ elements where
C                    i-th element is the number of objects within
C                    the i-th elementary zone
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     Error Free.
C
C$ Files
C
C     See main umbrella routine header.
C
C$ Particulars
C
C     The following scheme of "positional" catalog organization
C     is suggested. The celestial sphere is divided to ordered
C     set of "elementary zones" with the following geometry.
C     The celestial sphere is subdivided to "declination bands"
C     that are bounded by small circles and correspond equally
C     spaced declinations from +pi/2 to -pi/2 with constant step
C     delDEC. Each band is subdivided into "elementary zones" by
C     great circles of right ascension. In each band this "cutting"
C     is carried out in such a way to obtain equal zones with width
C     as close to height as possible. Within each zone objects are
C     ordered by right ascension.
C
C     We perform spiral-like tracing of declination bands: at first
C     north polar declination band from pi/2 - delDEC to pi/2, then
C     next band from pi/2 - 2*delDEC to pi/2 - delDEC, and so on
C     until south polar declination band (ratio pi/delDEC is integer
C     value Ndel).
C
C     Within each band we carry out zones tracing counter-clock-wise
C     if viewing from the North pole; the first zone in any band
C     corresponds to interval of right ascension (0, delRA), where
C     delRA is zone width in the declination band. So let Nbands is
C     number of declination bands, delDEC=pi/Nbands. Then for i-th
C     declination band bounded by pi/2-i*delDEC and pi/2-(i-1)*delDEC
C     we have surface area Si=4*pi*sin(delDEC/2)*sin((i-0.5)*delDEC).
C
C$ Examples
C
C     See main umbrella routine header.
C
C$ Restrictions
C
C     None
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     ?????
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
        RETURN
      ELSE
        CALL CHKIN ( 'STZAT2' )
      END IF

C
C     Check whether the catalog is really loaded
C
      IF ( .NOT. LOADED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was loaded prior ' //
     .                 'calling this routine.'                    )
         CALL SIGERR ( 'SPICE(CATALOGISNOTLOADED)'                )
         CALL CHKOUT ( 'STZAT2'                                   )
         RETURN
      END IF

C
C     Fetch data required from METAINFORMATION loaded
C
      NBAND = NBANDS
      NZ = NZONES

      DO I = 1, NBAND
         INBAND(I) = NINBND(I)
      END DO

      DO I = 1, NZ - 1
         INZONE(I) = INPOS(I+1) - INPOS(I)
      END DO

      INZONE(NZ) = NOBJ - INPOS(NZ-1)

      CALL CHKOUT ( 'STZAT2' )

      RETURN

**************************************************************************
**************************************************************************
******                                                             *******
******      Entry below is used for debugging only !!!             *******
******      The entry generates ASCII file METAINFO. containing    *******
******      data of the METAINFORMATION segment.                   *******
******                                                             *******
**************************************************************************
**************************************************************************

      ENTRY STMET2

      OPEN ( 7, FILE = 'METAINFO' )
      WRITE ( 7, * ) '     METAINFORMATION for our catalog:'
      WRITE ( 7, * )
      WRITE ( 7, * ) '   Contents of  METADIRECTORY  segment:'
      WRITE ( 7, * ) ' --------------------------------------'
      CALL DASRDI ( HANDLE, 1, 1, N )
      WRITE ( 7, '(''  number of integers in Contents'',I8)' ) N
      K = ( N-1 ) / 6
      WRITE ( 7, '(''  number of "arrays" in Contents'',I8)' ) K
      WRITE ( 7, * )
      DO I = 1, K
         J = 2 + (I-1) * 6
         CALL DASRDI ( HANDLE, J, J+5, Z )
         CALL STI2T2 ( Z, METNLN/NCHARI, STRING, N   )
         WRITE ( 7, '(I5,5X,A16,2I7)' ) I, STRING(1:16), Z(5), Z(6)
      END DO
      WRITE ( 7, * )


      WRITE ( 7, * ) ' Contents of  METAINFORMATION  segment:'
      WRITE ( 7, * ) ' --------------------------------------'
      WRITE ( 7, * )
* ..........................................................GENERAL_INFO

      WRITE(7,'(''CAT_NAME       '',(A))') CATNAM
      WRITE(7,'(''OBJECT_TYPE    '',(A))') OBTYPE
      WRITE(7,'(''ET  '',F25.2)')          ETCAT
      WRITE(7,'(''FRAME          '',(A))') CFRAME
      WRITE(7,'(''MATRIX      '',9F7.3)')  MATRIX
      WRITE(7,'(''PM_SCALE    '',9F7.3)')  PMSCAL
      WRITE(7,'(''N_OF_OBJECTS'',I7)')     NOBJ

* ...........................................................FIELDS_INFO

      WRITE(7,'(''N_OF_FIELDS '',I7)')     NFLDS
      WRITE(7,'(''NMAIN       '',I7)')     NMAIN
      WRITE(7,'(A)')'FIELD_NAME:.....................'
      WRITE(7,'(10X,A20)')    (FLDNAM(I),I=1,NFLDS)
      WRITE(7,'(A)')'FIELD_TYPE:.....................'
      WRITE(7,'(30I2)')       (FLTYPE(I),I=1,NFLDS)
      WRITE(7,'(A)')'FIELD_INDX:.....................'
      WRITE(7,'(30I2)')       (FLDIND(I),I=1,NFLDS)
      WRITE(7,'(A)')'MISS:...........................'
      WRITE(7,'(20I4)')       (MISS(I),I=1,NFLDS)
      WRITE(7,'(A)')'MIN_VALUE:......................'
      WRITE(7,'(5G15.6)')     (MINVAL(I),I=1,NFLDS)
      WRITE(7,'(A)')'ACCUR:..........................'
      WRITE(7,'(20I4)')       (ACCUR(I),I=1,NFLDS)
      WRITE(7,'(A)')'MAXABS:.........................'
      WRITE(7,'(6I12)')       (MAXABS(I),I=1,NFLDS)
      WRITE(7,'(A)')'TEXT_BEG:.......................'
      WRITE(7,'(20I4)')       (TXTBEG(I),I=1,NFLDS)
      WRITE(7,'(''N_TXT_MAIN  '',I10)') NTXTM
      WRITE(7,'(''TXT_MAIN_FIELDS:   '',(26I3))') (TMFLDS(I),I=1,NTXTM)
      WRITE(7,'(''N_PCK_TXT   '',I10)')    NPKTXT
      WRITE(7,'(''MAIN_RECL   '',I10)')    MRECL
      WRITE(7,'(''N_NUM_MAIN  '',I10)')    NNUMM
      WRITE(7,'(''NUM_FIELDS:        '',(26I3))') (NMFLDS(I),I=1,NNUMM)
      WRITE(7,'(''N_PCK_NUM   '',I10)')    NPKNUM
      WRITE(7,'(''DENSITY:           '',(26I3))') (DENS(I),I=1,NPKNUM)
      WRITE(7,'(''N_NUM_AUX   '',I10)')    NNUMA
      WRITE(7,'(''NUM_AUX_FIELDS:    '',(26I3))') (NAFLDS(I),I=1,NNUMA)
      WRITE(7,'(''N_TXT_AUX   '',I10)')    NTXTA
      WRITE(7,'(''TXT_AUX_FIELDS:    '',(26I3))') (TAFLDS(I),I=1,NTXTA)
      WRITE(7,'(''START POSITIONS:   '',(26I3))') (FLDBPS(I),I=1,NFLDS)
      WRITE(7,'(A)')'PREFIXES: ......................'
      DO I = 1, NFLDS
         IF(FLDBPS(I).GT.1) WRITE(7,'(I5,5X,A20)') I,FLDPRF(I)
      END DO
      WRITE(7,'(''PREFIX SIZE '',I10)')    PRFSIZ
      WRITE(7,'(A)')'GLUED PREFIXES:      '//PRFVAL(1:57)

C .........................................................DIVISION_INFO

      WRITE(7,'(''N_OF_DEC_BANDS'',I8)')    NBANDS
      WRITE(7,'(''N_OF_ZONES    '',I8)')    NZONES
      WRITE(7,'(A)')'N_IN_BAND:......................'
      WRITE(7,'(20I4)')   (NINBND(I),I=1,NBANDS)
      WRITE(7,'(A)')'N_SUM:..........................'
      WRITE(7,'(20I4)')   (NSUM(I),I=1,NBANDS)
      WRITE(7,'(A)')'INIT_POS:.......................'
      WRITE(7,'(20I4)')   (INPOS(I),I=1,NZONES)

C ..........................................................SORTING_INFO

      WRITE(7,'(''N_IND_TAB   '',I10)')    NINDX
      WRITE(7,'(''LIST_TAB:          '',(26I3))') (LSTTAB(I),I=1,NINDX)
      WRITE(7,'(''N_NODES:           '',(26I3))') (NNODES(I),I=1,NINDX)

C ..........................................................ADDRESS_INFO

      WRITE(7,'(''BEG_MAIN    '',I10)')    BEGMAI
      WRITE(7,'(''BEG_AUX     '',I10)')    BEGAUX
      WRITE(7,'(''BEG_INDX    '',I10)')    BEGIND
      CLOSE(7)

      RETURN
************************************************************************
*********************    Vot, sobstvenno, i vse    *********************
************************************************************************


      END
