C$Procedure   STWMG2  ( Write Type 2 SPICE Sky Catalog )

      SUBROUTINE STWMG2 ( FNAME, IFNAME, NCOMCH, HNDL, CATNAM,
     .      OBTYPE, EPOCH, FRAME, MATRIX, NOB,  NCATDS, DESCR,
     .      NFLD, FLNAM, FLTYP, FLCLS, FLINDX, NFLDDS, ZONSIZ,
     .      IREC, RA, DEC, PMSCAL, FLDNO, STRING             )

C$ Abstract
C
C     Write Type 2 SPICE Sky Catalog.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations

      IMPLICIT              NONE

      INCLUDE               'starlib.inc'

      CHARACTER*(*)         FNAME
      CHARACTER*(*)         IFNAME
      INTEGER               NCOMCH
      INTEGER               HNDL
      CHARACTER*(*)         CATNAM
      CHARACTER*(*)         OBTYPE
      CHARACTER*(*)         EPOCH
      CHARACTER*(*)         FRAME
      DOUBLE PRECISION      MATRIX(3,3)
      INTEGER               NOB
      INTEGER               NCATDS
      CHARACTER*(*)         DESCR  (*)
      INTEGER               NFLD
      CHARACTER*(*)         FLNAM  (*)
      CHARACTER*(1)         FLTYP  (*)
      CHARACTER*(*)         FLCLS  (*)
      LOGICAL               FLINDX (*)
      INTEGER               NFLDDS (*)
      DOUBLE PRECISION      ZONSIZ
      INTEGER               IREC
      DOUBLE PRECISION      RA
      DOUBLE PRECISION      DEC
      DOUBLE PRECISION      PMSCAL (2)
      INTEGER               FLDNO
      CHARACTER*(*)         STRING

C$ Brief_I/O
C
C     VARIABLE  I/O  ENTRY POINTS
C     --------  ---  --------------------------------------------------
C     FNAME      I   STWOP2
C     IFNAME     I   STWOP2
C     NCOMCH     I   STWOP2
C     HNDL      I/0  STWOP2, STWCL2
C     CATNAM     I   STWCI2
C     OBTYPE     I   STWCI2
C     EPOCH      I   STWCI2
C     FRAME      I   STWCI2
C     MATRIX     I   STWCI2
C     NOB        I   STWCI2
C     NCATDS     I   STWCI2
C     DESCR      I   STWCI2
C     NFLD       I   STWFI2
C     FLNAM      I   STWFI2
C     FLTYP      I   STWFI2
C     FLCLS      I   STWFI2
C     FLINDX     I   STWFI2
C     ZONSIZ     I   STWZS2
C     IREC      I/O  STWRD2, STWPF2, STWRC2
C     RA         I   STWRD2
C     DEC        I   STWRD2
C     PMSCAL     I   STWPM2
C     FLDNO      I   STWPF2
C     STRING     I   STWPF2
C
C$ Detailed_Input
C
C     See the ENTRY points for a discussion of their arguments.
C
C$ Detailed_Output
C
C     See the ENTRY points for a discussion of their arguments.
C
C$ Parameters
C
C     ST2TYP     is the SPICE catalog type. It is a string that
C                appears in the architecture/type identifier
C                stored in the first 8 bytes of the file.
C
C     NOBMAX     is maximal number of objects in the catalog.
C                It is maximum number of objects that can be
C                stored in memory during fetch process.
C
C     NBMAX      is maximal number of declination bands onto the
C                celestial sphere.
C
C     NZMAX      is maximal number of elementary zones onto the
C                celestial sphere. It depends on the only argument:
C                the number of declination bands. Below there is a
C                table that shows how the elementary zone height
C                DELDEC and the number of elementary zones NZONES
C                depend on the number of declination bands NBANDS:
C
C                    NBANDS    DELDEC     NZONES
C
C                      30         6         1144
C                      45         4         2576
C                      60         3         4584
C                      90         2        10312
C                     180         1        41252
C                     360       0.5       165016
C
C                Approximately NZONES can be expressed as follows:
C                              4 * NBANDS^2 / PI.
C
C     NNMAX      is maximal number of elements in so-called "node
C                sequence" (see SPICE Catalog Design) to provide
C                fast access to indexed parameter of the catalog
C                object.
C
C     NFLMAX     is maximal number of fields in the catalog object
C                record
C
C     NFAMAX     is maximal number of fields in the auxilary part
C                of the catalog object record
C
C     NCHARI     is the number of characters packed into a single
C                integer.
C
C     CATNLN     is the catalog name length.
C
C     OBJTLN     is object type length.
C
C     FRMNLN     is reference frame name length.
C
C     FLDNLN     is field name length.
C
C     FOVTLN     is FOV type length.
C
C     DSCLSZ     is catalog/field description line size.
C
C     DPHXSZ     is the size of a string used to store HEX encoded DP.
C
C     TFVMAX     is maximum text field value size.
C
C     FNBAND     is field name for declination band number
C
C     FNZONE     is field name for elementary zone number
C                within declination band
C
C     FNRA       is field name for right ascension offset
C                with respect of the zone center
C
C     FNDEC      is field name for declination offset with
C                respect of the zone center
C
C     FCID       is ID field class
C
C     FCRA       is right ascension offset field class
C
C     FCDEC      is declination offset field class
C
C     FCRAZ      is right ascension zone number field class
C
C     FCDECB     is declination band number field class
C
C     FCRAS      is right ascension shift field class
C
C     FCDECS     is declination shift field class
C
C     FCPMRA     is proper motion for right ascension field class
C
C     FCPMDC     is proper motion for declination field class
C
C     FCPRLX     is parallax field class
C
C     FCRVEL     is radial velocity field class
C
C     FCINTE     is intensity field class
C
C     FCCLSS     is class index field class
C
C     FCOTYP     is object type field class
C
C     PFNBAN     is text string with description of declination
C                band number field
C
C     PFNZON     is text string with description of field for
C                elementary zone number within declination band
C
C     PFNRA      is text string with description of field for
C                RA offset with respect of the zone center
C
C     PFNDEC     is text string with description of field for
C                DEC offset with respect of the zone center
C
C     AORMPR     is threshold for missed data percentage that
C                determines whether field goes to MAIN or AUX
C                block of DATA segment (see STWMG2/STWSW2 for
C                details for decision process)
C
C     AORMSZ     is threshold for text field size that
C                determines whether field goes to MAIN or AUX
C                block of DATA segment (see STWMG2/STWSW2 for
C                details for decision process)
C
C     FTCIRC     is FOV type for circular FOVs
C
C     FTELLI     is FOV type for elliptical FOVs
C
C     FTPOLY     is FOV type for polygonal FOVs
C
C     NVRMAX     is maximum number of vertices for polygonal FOVs
C
C     METNLN     is Meta information array name length in
C                metablock directory
C
C     MDCNAM     is name of metainformation array for the
C                catalog name
C
C     MDOTYP     is name of metainformation array for object type
C
C     MDNOFO     is name of metainformation array for the number
C                of catalog objects
C
C     MDFRAM     is name of metainformation array for the catalog
C                frame
C
C     MDEPOC     is name of metainformation array for the catalog
C                epoch
C
C     MDPMSC     is name of metainformation array for proper
C                motion data scale
C
C     MDMATR     is name of metainformation array for
C                transformation matrix from catalog frame
C                to J2000
C
C     MDNOFF     is name of metainformation array for total
C                number of fields for the catalog object
C
C     MDNMAI     is name of metainformation array for number
C                of fields in MAIN data block
C
C     MDFNAM     is name of metainformation array for field names
C
C     MDFCLA     is name of metainformation array for field
C                classes
C
C     MDFTYP     is name of metainformation array for field types
C
C     MDFIDX     is name of metainformation array for field
C                indexes
C
C     MDMINV     is name of metainformation array for minimal
C                values of field parameters
C
C     MDACCU     is name of metainformation array for value
C                increments of field parameters
C
C     MDMAXA     is name of metainformation array for value
C                range of field parameters
C
C     MDNPKT     is name of metainformation array for number of
C                integer packets needed to hold concatenated
C                text fields of MAIN part of the record
C
C     MDNPKN     is name of metainformation array for number of
C                integer packets needed to hold numerical
C                fields of MAIN part of the record
C
C     MDNMFL     is name of metainformation array for
C                numerical fields of MAIN part of the record
C
C     MDMRCL     is name of metainformation array for number of
C                integer packets in MAIN part of the record
C                including pointer to AUX part
C
C     MDDENS     is name of metainformation array for packing
C                density of numerical fields in MAIN part of
C                the record
C
C     MDNTAU     is name of metainformation array for number of
C                text fields concerning to AUX part of the record
C
C     MDNNAU     is name of metainformation array for number of
C                numerical fields concerning to AUX part of the
C                record
C
C     MDTAUF     is name of metainformation array for text
C                fields of AUX part of the record
C
C     MDNAUF     is name of metainformation array for numerical
C                fields of AUX part of the record
C
C     MDNODB     is name of metainformation array for number of
C                declination bands on the celestial sphere
C
C     MDNOZO     is name of metainformation array for number of
C                elementary zones on the celestial sphere
C
C     MDNINB     is name of metainformation array for number of
C                elementary zones in declination bands on the
C                celestial sphere
C
C     MDIPOS     is name of metainformation array for numbers
C                of records that are first in consequent
C                elementary zones on the celestial sphere
C
C     MDNSUM     is name of metainformation array where i-th
C                element is the number of elementary zones
C                belonging to declination bands up to i-1.
C
C     MDBEGM     is name of metainformation array for address
C                of first record of MAIN DATA segment in DAS
C                file with the SPICE catalog
C
C     MDBAUX     is name of metainformation array for address
C                of first record of AUX DATA segment in DAS
C                file with the SPICE catalog
C
C     MDBIDX     is name of metainformation array for address
C                of first record of Index Tables segment in DAS
C                file with the SPICE catalog
C
C     MDNINP     is name of metainformation array for number of
C                "positional" fields
C
C     MDNINI     is name of metainformation array for number of
C                "intensity" fields
C
C     MDNITB     is name of metainformation array for number of
C                indexed fields
C
C     MDLSTT     is name of metainformation array for list of
C                indexed fields numbers
C
C     MDNNOD     is name of metainformation array for number of
C                elements in "node" sequence for each indexed
C                field
C
C     MDMISS     is name of metainformation array for number of
C                missed data for each field
C
C     MDFDSC     is name of metainformation array for all fields
C                descriptions
C
C     MDFDSN     is name of metainformation array for number of
C                lines in descriptions for all consequent fields
C
C     MDCDSC     is name of metainformation array for the
C                catalog description
C
C     MDNDSC     is name of metainformation array for number of
C                lines in the catalog description
C
C     MDCPRF     is name of metainformation array for all so
C                called "common prefixes" accumulated into one
C                line
C
C     MDCPOS     is name of metainformation array for first
C                position of "non-common" character in text
C                fields
C
C     OFFSCL     is the number of "bins" (fractions) in the
C                integer representation of RA/DEC offset with
C                respect to the center of an elementary zone
C                reduced by two
C
C     RATMAX     is maxumum Number of "bins" (fractions) in the
C                integer representation of a numeric field:
C                ( 2**30 - 1 ) * 2 - 1
C
C     RDMAXA     is the "safest" cross-platform value of INTMAX
C                used to encode upper boundary for maximum
C                absolute value in integer representation of a
C                numeric field
C
C     RDMINV     is the "safest" cross-platform value of INTMIN
C                used to encode lower boundary for minimal value
C                of positional offset
C
C     NWC        is the number of characters in a single comment
C                area record
C
C     FNSIZE     is the catalog file name size
C
C
C     RMTTOL     is tolerance used in determining whether input
C                catalog matrix is a rotation matrix and whether
C                it's equal to the SPICE version of the same
C                rotation.
C
C$ Exceptions
C
C     If this routine is called directly, then the error
C     'SPICE(BOGUSENTRY)' will be signalled.
C
C$ Files
C
C     TBD
C
C$ Particulars
C
C     STWMG2 should never be called directly, but should instead be
C     accessed only through its entry points.
C
C     The purpose of this routine is to write a Type SPICE Sky Catalog.
C     The following entry points of this routine should be used
C     to accomplish this.
C
C           STWOP2 ( open catalog for writing           )
C           STWCI2 ( put the general information        )
C           STWFI2 ( put fields information             )
C           STWZS2 ( define approximate size of a zone  )
C           STWPM2 ( put scale/flag for proper motion   )
C           STWIN2 ( prepare to generate the catalog    )
C           STWRD2 ( put RA and DEC of the object       )
C           STWPF2 ( put character string for the field )
C           STWSW2 ( start the catalog writing          )
C           STWRC2 ( write a record to the catalog      )
C           STWFW2 ( complete the catalog generation    )
C           STWCL2 ( close DAS file with the catalog    )
C
C     To create a Type 2 Sky Catalog, the entry points of this routine
C     must be called in the following order (for a source catalog that
C     NOB objects and NFLS fields, not including position fields, each
C     object record):
C
C     C
C     C     Open catalog file and provide information about
C     C     catalog and its fields.
C     C
C           CALL STWOP2 ( ... )
C           CALL STWCI2 ( ... )
C           CALL STWFI2 ( ... )
C           CALL STWZS2 ( ... )
C           CALL STWPM2 ( ... )
C
C     C
C     C     Prepare for the first cycle of providing source catalog
C     C     data.
C     C
C           CALL STWIN2
C
C     C
C     C     Perform the first cycle -- provide position and other
C     C     field data for each object in the source catalog,
C     C
C           DO IREC = 1, NOB
C
C     C
C     C        Provide object position.
C     C
C              CALL STWRD2 ( ... )
C
C              DO I = 1, NFLD
C     C
C     C           Provide value for the I-th catalog field.
C     C
C                 CALL STWPF2 ( ... )
C
C              END DO
C
C           END DO
C
C     C
C     C     Finish the first cycle and prepare for the second cycle
C     C     of providing source catalog data.
C     C
C           CALL STWSW2
C
C     C
C     C     Perform the second cycle -- provide position and other
C     C     field data + write output catalog record for each object
C     C     in the source catalog
C     C
C           DO IREC = 1, NOB
C
C     C
C     C        Provide object position.
C     C
C              CALL STWRD2 ( ... )
C
C              DO I = 1, NFLD
C     C
C     C           Provide value for the Ith catalog field.
C     C
C                 CALL STWPF2 ( ... )
C
C              END DO
C
C     C
C     C        Write output catalog record for the object.
C     C
C              CALL STWRC2 ( ... )
C
C           END DO
C
C     C
C     C     Finish writing and close the catalog.
C     C
C           CALL STWFW2
C           CALL STWCL2
C
C
C     See the Examples section of this header for complete example of
C     how a catalog can be generated.
C
C     See the Particulars sections of the entry point headers for
C     detailed description of functions each entry point accomplishes..
C
C$ Examples
C
C     The example below creates a type 2 SPICE Sky catalog from a given
C     source text catalog. Note that to make the example self-contaned,
C     source catalog records are buffered in a string array.
C
C     C
C     C     Let we want to generate SPICE catalog by original text
C     C     catalog "Skipidar" that consists of 14 objects.
C     C     Each record of the catalog contains the object name,
C     C     RA and DEC of the object in B1950 frame and eight
C     C     parameters of the object. All parameters but RA and DEC
C     C     correspond to the following fields:
C     C
C     C       Field #      Field name
C     C
C     C          1         SKIPIDAR
C     C          2         SP
C     C          3         VMAG
C     C          4         SMELL
C     C          5         SEX
C     C          6         MARK
C     C          7         SCALE
C     C          8         CLASS
C     C          9         CODE
C     C
C     C     Field 1 is the object ID in the catalog, field 2 is
C     C     spectral class of the object, field 3 is visual magnitude.
C     C     Fields 1,2,5,6,8,9 are of character type, fields 3 and 7
C     C     are of float type, whereas field 4 is of integer type.
C     C
C     C     All the catalog data are stored in text strings CATDAT.
C     C
C     C     In this example we have no proper motion.
C     C
C           IMPLICIT              NONE
C
C     C
C     C     Sky catalog parameters.
C     C
C           INCLUDE               'starlib.inc'
C
C     C
C     C     Local parameters.
C     C
C           INTEGER               LINSIZ
C           PARAMETER           ( LINSIZ = 80 )
C
C           INTEGER               WRDSIZ
C           PARAMETER           ( WRDSIZ = 32 )
C
C
C     C
C     C     Local variables.
C     C
C           CHARACTER*(LINSIZ)    FNAME
C           CHARACTER*(80)        IFNAME
C           INTEGER               NCOMR
C           INTEGER               HANDLE
C           CHARACTER*(CATNLN)    CATNAM
C           CHARACTER*(OBJTLN)    OBJTYP
C           CHARACTER*(WRDSIZ)    EPOCH
C           CHARACTER*(FRMNLN)    FRAME
C           INTEGER               NOBJ
C           INTEGER               NFLDS
C           INTEGER               CDESCN
C           CHARACTER*(DSCLSZ)    CDESC      (10)
C           CHARACTER*(FLDNLN)    FLDNAM     (9)
C           CHARACTER*(1)         FLDTYP     (9)
C           CHARACTER*(WRDSIZ)    FLDCLS     (9)
C           LOGICAL               FLDIND     (9)
C           INTEGER               FDESCN     (9)
C           CHARACTER*(DSCLSZ)    FDESC      (10)
C           CHARACTER*(LINSIZ)    CATDAT     (14)
C           CHARACTER*(WRDSIZ)    FRM        (9)
C           CHARACTER*(LINSIZ)    STR
C
C           DOUBLE PRECISION      ZSIZE
C           DOUBLE PRECISION      MATRIX     (3,3)
C           DOUBLE PRECISION      RA
C           DOUBLE PRECISION      DEC
C           DOUBLE PRECISION      PSCALE     (2)
C
C           INTEGER               IREC
C           INTEGER               I
C
C     C
C     C     SPICE functions.
C     C
C           DOUBLE PRECISION      RPD
C
C     C
C     C     Skipidar catalog data.
C     C
C           DATA
C          . NOBJ     / 14                                            /,
C          . FNAME    / 'skipidar.cat'                                /,
C          . IFNAME   / 'Example of Skipidar'                         /,
C          . NCOMR    / 7                                             /,
C          . CATNAM   / 'Skipidar Catalog of tiny plimmers'           /,
C          . OBJTYP   / 'Plimmer'                                     /,
C          . EPOCH    / '23 Oct 1941 12:00:00'                        /,
C          . FRAME    / 'B1950'                                       /
C
C           DATA
C          . NFLDS    / 9                                             /,
C          . FLDNAM   /
C          .'SKIPIDAR', 'SP', 'VMAG', 'SMELL', 'SEX', 'MARK', 'SCALE',
C          .'CLASS', 'CODE'                                           /,
C          . FLDTYP   / 'C', 'C', 'D', 'I', 'C', 'C', 'D', 'C', 'C'   /,
C          . FLDIND   /
C          . .FALSE., .FALSE., .TRUE. , .TRUE., .FALSE.,
C          . .FALSE., .TRUE. , .FALSE., .TRUE.                        /,
C          . FLDCLS   /
C          .'ID', 'CLASS_INDEX', 'INTENSITY', ' ',' ',' ',' ',' ',' ' /
C
C           DATA
C          . CATDAT   /
C          .'S00124  24.55 -22.33 K2 11.4  2 F Yes 25.44 Isabella U123',
C          .'S00072  34.72  22.44 A1  1.4 12 F     25.44 Tetra    A323',
C          .'S00033  55.55 -44.55 F1  2.2 12 M Yes 25.41 Tvishi   B123',
C          .'S00335  66.77 -33.66 A3 12.4      No  25.42 Kabernet D524',
C          .'S00414  78.90 -22.33 K2 11.4 11 M No  25.43          U623',
C          .'S00021  82.14  11.11 K4  4.1 11 M     25.45 Portvein E123',
C          .'S00624 124.55 -21.21 A2  5.4 11 M Hmm 25.46 Isabella     ',
C          .'S00524 143.06 -66.99 K6 10.3 14 F Hmm 25.47          H123',
C          .'S00424 176.12 -77.77 K0 11.1 14       25.48 Muskat   T123',
C          .'S00724 202.55  44.33 K2 11.2 12 F Pss 25.49 Isabella W124',
C          .'S00824 224.31 -88.33 A0 11.2    M Yes       Isabella U126',
C          .'S00924 269.55  55.55 K2  8.4 14 M No  25.01 Isabella     ',
C          .'S00027 324.15 -55.33 K2  8.4 12 F     25.02 Isabella L123',
C          .'S00112 351.26 -11.77 K2  8.4 12   Pss 25.03 Isabella Z123'/,
C          . FRM         /
C          .'(    A6) ', '(21X,A2)', '(23X,A5)', '(28X,A3)', '(32X,A1)',
C          .'(34X,A3)',  '(38X,A5)', '(44X,A8)', '(53X,A4)'           /
C
C           DATA
C          . PSCALE      / 0D0, 0D0  /,
C          . ZSIZE       / 30D0      /
C
C           DATA
C          . CDESCN      / 10        /
C          . CDESC       /
C          .'So, there is a little tale to tell of many things. Perhaps ',
C          .'to the promiscuous ear of the Walrus it shall come with    ',
C          .'most avail; for init there are indeed shoes and ships and  ',
C          .'sealing-wax and cabbage-palmsand presidents instead of     ',
C          .'kings. Add to these a little love and counterplotting, and ',
C          .'scatter everywhere throughout the maze a trail of tropical ',
C          .'dollars--dollars warmed no more by the torrid sun than by  ',
C          .'the hot palms of the scouts of Fortune--and, after all,    ',
C          .'here seems to be Life, itself, with talk enough to weary   ',
C          .'the most garrulous of Walruses.'                           /
C
C           DATA
C          . FDESCN      / 1, 1, 2, 1, 1, 1, 1, 1, 1                    /,
C          . FDESC       /
C          .'SKIPIDAR field contains object ID in the Skipidar Catalog. ',
C          .'SP field contains spectral class index for certain plimmer.',
C          .'VMAG field contains visual magnitude for certain plimmer   ',
C          .'according to Richard Vagner classification.                ',
C          .'SMELL field is specific L-quality for certain plimmer.     ',
C          .'SEX field contains flag of sub-pattern for certain plimmer.',
C          .'MARK field presents internal Q-mark for certain plimmer.   ',
C          .'SCALE field is expected size of plimmer (in Sweepers).     ',
C          .'CLASS field corresponds to observer taste class.           ',
C          .'CODE field is an alternative plimmer name according to IAU.'/
C
C     C
C     C     Generate MATRIX rotating object positons from catalog
C     C     frame to J2000.
C     C
C           CALL PXFORM ( FRAME, 'J2000', 0D0, MATRIX )
C
C     C
C     C     Load leapseconds kernel.
C     C
C           CALL LDPOOL ( 'naif0007.tls' )
C
C     C
C     C     Provide catalog writer with necessary information about
C     C     catalog and its fields.
C     C
C           CALL STWOP2 ( FNAME, IFNAME, NCOMR, HANDLE )
C           CALL STWCI2 ( CATNAM, OBJTYP, EPOCH, FRAME, MATRIX, NOBJ,
C          .                                      CDESCN, CDESC )
C           CALL STWFI2 ( NFLDS, FLDNAM, FLDTYP, FLDCLS, FLDIND,
C          .                                      FDESCN, FDESC )
C           CALL STWZS2 ( ZSIZE * RPD() )
C           CALL STWPM2 ( PSCALE )
C
C     C
C     C     Prepare for the first cycle of providing source catalog
C     C     data.
C     C
C           CALL STWIN2 ()
C
C     C
C     C     Perform first cycle.
C     C
C           DO IREC = 1, NOBJ
C
C     C
C     C        Fetch RA and DEC from source catalog record IREC and
C     C        pass it to catalog writer.
C     C
C              READ ( CATDAT (IREC), '(6X, 2F7.2)' ) RA, DEC
C              CALL STWRD2 ( IREC, RA * RPD(), DEC * RPD() )
C
C              DO I = 1, NFLDS
C
C     C
C     C           Fetch string corresponding to field # I from source
C     C           catalog record and pass it to catalog writer
C     C
C                 STR = ' '
C                 READ ( CATDAT (IREC), FRM(I) ) STR
C                 CALL STWPF2 ( IREC, I, STR )
C
C              END DO
C
C           END DO
C
C     C
C     C     Now we start the final stage of the catalog generation.
C     C     Complete statistics processing, geometrical indexing,
C     C     fields rearrangement and start writing catalog.
C     C
C           CALL STWSW2 ()
C
C     C
C     C     Perform second cycle.
C     C
C           DO IREC = 1, NOBJ
C
C     C
C     C        Fetch RA and DEC from source catalog record IREC and
C     C        pass it to catalog writer.
C     C
C              READ ( CATDAT (IREC), '(6X, 2F7.2)' ) RA, DEC
C              CALL STWRD2 ( IREC, RA * RPD(), DEC * RPD() )
C
C              DO I = 1, NFLDS
C
C     C
C     C           Fetch string corresponding to field # I from source
C     C           catalog record and pass it to catalog writer.
C     C
C                 STR = ' '
C                 READ ( CATDAT (IREC), FRM(I) ) STR
C                 CALL STWPF2 ( IREC, I, STR )
C
C              END DO
C
C     C
C     C        Write output catalog record for the object.
C     C
C              CALL STWRC2 ( IREC )
C
C           END DO
C
C     C
C     C     Finish writing and close the catalog.
C     C
C           CALL STWFW2 ()
C           CALL STWCL2 ()
C
C     C
C     C     That's it.
C     C
C           END
C
C$ Restrictions
C
C     TBD
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     ?????
C
C-&

C
C     Local parameters.
C

C
C     Number of characters in a single comment area record.
C
      INTEGER               NWC
      PARAMETER           ( NWC    = 1024 )

C
C     File name size.
C
      INTEGER               FNSIZE
      PARAMETER           ( FNSIZE = 256 )

C
C     Tolerance used in determining whether input catalog matrix is
C     a rotation matrix and whether it's equal to the SPICE version
C     of the same rotation. At this point allowed quite relaxed
C     tolerance assuming possibility of a single precision matrix on
C     the input.
C
      DOUBLE PRECISION      RMTTOL
      PARAMETER           ( RMTTOL = 1.D-07 )

C
C     Local variables.
C

C
C     Catalog attributes.
C
      DOUBLE PRECISION      MATR (3,3)
      DOUBLE PRECISION      PMCOEF (2)
      INTEGER               NOBJ

C
C     Field attributes and buffers.
C
      INTEGER               NFLDS
      CHARACTER*(FLDNLN)    FLDNAM (NFLMAX)
      CHARACTER*(FLDCLN)    FLDCLS (NFLMAX)
      INTEGER               FLTYPE (NFLMAX)
      INTEGER               FLDIND (NFLMAX)
      INTEGER               NFDESC (NFLMAX)
      CHARACTER*(TFVMAX)    FLDPRF (NFLMAX)
      INTEGER               FLDBPS (NFLMAX)

      INTEGER               MISS   (NFLMAX)
      INTEGER               SIZE   (NFLMAX)
      DOUBLE PRECISION      MAXVAL (NFLMAX)
      DOUBLE PRECISION      MINVAL (NFLMAX)
      INTEGER               MAXABS (NFLMAX)
      INTEGER               ACCUR  (NFLMAX)
      INTEGER               ORDER  (NFLMAX)
      INTEGER               RANK   (NFLMAX)
      INTEGER               TXTBEG (NFLMAX)
      INTEGER               NMFLDS (NFLMAX)
      INTEGER               TMFLDS (NFLMAX)
      INTEGER               NAFLDS (NFLMAX)
      INTEGER               TAFLDS (NFLMAX)
      INTEGER               FIELDS (NFLMAX)
      INTEGER               VALUE  (NFLMAX)
      INTEGER               VLIREC (NFLMAX)
      INTEGER               DENS   (NFLMAX)
      INTEGER               DENAUX (NFAMAX)
      INTEGER               PACKED (NFLMAX)
      INTEGER               NPKNUM
      INTEGER               NPKTXT
      INTEGER               NMAIN
      INTEGER               TXTSIZ
      INTEGER               NNUMM
      INTEGER               NTXTM
      INTEGER               NNUMA
      INTEGER               NTXTA
      INTEGER               NPCKED

C
C     Geometric organization related.
C
      INTEGER               NBANDS
      DOUBLE PRECISION      DELDEC
      INTEGER               NZONES

      INTEGER               NINBND (NBMAX)
      INTEGER               NSUM   (NBMAX)

      INTEGER               INPOS  (NZMAX)
      INTEGER               OBJINZ (NZMAX)

      INTEGER               ARR1   (NOBMAX)
      INTEGER               ARR2   (NOBMAX)
      INTEGER               ARR3   (NOBMAX)
      INTEGER               Z      (NFLMAX)

C
C     Field indexing related.
C
      INTEGER               NINDX
      INTEGER               LSTTAB (NFLMAX)
      INTEGER               NNODES (NFLMAX)
      INTEGER               NODES  (NNMAX)
      INTEGER               ININDX (NNMAX)

C
C     File handles.
C
      INTEGER               HANDLE
      INTEGER               DSCDAS

C
C     File addresses.
C
      INTEGER               BEGMAI
      INTEGER               BEGAUX
      INTEGER               BEGIND

C
C     Accumulated common prefix and its size.
C
      INTEGER                    PRFSIZ
      CHARACTER*(NFLMAX*TFVMAX)  PRFVAL

C
C     Misc. local variables.
C
      INTEGER               IZONE
      INTEGER               DAT       (1000)
      INTEGER               I
      INTEGER               J
      INTEGER               K
      INTEGER               L
      INTEGER               M
      INTEGER               I1
      INTEGER               I2
      INTEGER               J1
      INTEGER               J2
      INTEGER               IBAND
      INTEGER               INBAND
      INTEGER               SHFTRA
      INTEGER               SHFTDC
      INTEGER               CYCLE
      INTEGER               C1PCNT
      INTEGER               C2PCNT
      INTEGER               C1VCNT ( NFLMAX )
      INTEGER               C2VCNT ( NFLMAX )
      INTEGER               NMAXBN
      INTEGER               ISTART
      INTEGER               RATIO
      INTEGER               MRECL
      INTEGER               MASK
      INTEGER               NNUM
      INTEGER               NTXT
      INTEGER               ITXT
      INTEGER               STRLEN
      INTEGER               IFLD
      INTEGER               IOBJ
      INTEGER               IINDX
      INTEGER               NINPOS
      INTEGER               NINTEN
      INTEGER               ISTAUX
      INTEGER               IAUX
      INTEGER               JTXT
      INTEGER               JAUX
      INTEGER               N
      INTEGER               NCR
      INTEGER               NBINS

      DOUBLE PRECISION      SHFDRA
      DOUBLE PRECISION      SHFDDC
      DOUBLE PRECISION      A
      DOUBLE PRECISION      ET
      DOUBLE PRECISION      RA0
      DOUBLE PRECISION      DEC0
      DOUBLE PRECISION      DELRA
      DOUBLE PRECISION      C1
      DOUBLE PRECISION      C2

      CHARACTER*(CATNLN*2)  LINE
      CHARACTER*(DSCLSZ*4)  ERROR
      CHARACTER*(1)         CH
      CHARACTER*(NFLMAX*TFVMAX) TEXT
      CHARACTER*(NFLMAX*TFVMAX) TXT
      CHARACTER*(FNSIZE)    FNAM

      INTEGER               FRCODE
      INTEGER               FRCENT
      INTEGER               FRCLSS
      INTEGER               FRCLID
      DOUBLE PRECISION      SPCMAT (3,3)
      DOUBLE PRECISION      QUAT   ( 4 )

      LOGICAL               FOUND

      LOGICAL               OPENED
      LOGICAL               WCI2FL
      LOGICAL               WFI2FL
      LOGICAL               WZS2FL
      LOGICAL               WPM2FL
      LOGICAL               IDXDNE

C
C     SPICELIB functions.
C
      DOUBLE PRECISION      PI
      DOUBLE PRECISION      HALFPI
      DOUBLE PRECISION      TWOPI
      INTEGER               STDIG2
      INTEGER               ESRCHC
      INTEGER               ISRCHI
      INTEGER               RTRIM
      INTEGER               NBLEN
      INTEGER               STF2I2
      LOGICAL               RETURN
      LOGICAL               SAMCHI
      LOGICAL               FAILED
      LOGICAL               ISROT
      DOUBLE PRECISION      VDISTG
      INTEGER               SUMAI
      INTEGER               INTMIN
      INTEGER               INTMAX

C
C     Saved variables.
C
      SAVE

C
C     Initial values.
C
      DATA                  CYCLE    / 0 /,
     .                      C1PCNT   / 0 /,
     .                      C2PCNT   / 0 /,
     .                      OPENED   / .FALSE. /,
     .                      WCI2FL   / .FALSE. /,
     .                      WFI2FL   / .FALSE. /,
     .                      WZS2FL   / .FALSE. /,
     .                      WPM2FL   / .FALSE. /

C
C     Standard SPICE error handling.
C

      IF ( .NOT. RETURN () ) THEN

         CALL CHKIN  ( 'STWMG2'                                       )
         CALL SETMSG ( 'Your program has referenced the umbrella '    //
     .                 'subroutine STWMG2.  This  may indicate a '    //
     .                 'programming error.'                           )
         CALL SIGERR ( 'SPICE(BOGUSENTRY)'                            )
         CALL CHKOUT ( 'STWMG2'                                       )

      END IF

      RETURN

C$Procedure  STWOP2 ( open Type 2 Sky catalog for writing )

      ENTRY STWOP2 ( FNAME, IFNAME, NCOMCH, HNDL )

C$ Abstract
C
C     Open new type 2 SPICE Sky catalog file for write access.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     CHARACTER*(*)         FNAME
C     CHARACTER*(*)         IFNAME
C     INTEGER               NCOMCH
C     INTEGER               HNDL
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     FNAME      I   The name of the sky catalog file to be created.
C     IFNAME     I   The internal filename for the sky catalog file.
C     NCOMCH     I   The number of characters to reserve for comments.
C     HNDL       O   The handle of the opened sky catalog file.
C
C$ Detailed_Input
C
C     FNAME          is the name of a new sky catalog file to be
C                    created.
C
C     IFNAME         is the internal file name of a new sky catalog.
C                    The internal file name may be up to 60 characters
C                    in length.
C
C     NCOMCH         is the amount of space, measured in characters, to
C                    be allocated in the comment area when the new sky
C                    catalog file is created. It is not necessary to
C                    allocate space in advance in order to add
C                    comments, but doing so may greatly increase the
C                    efficiency with which comments may be added.
C                    Making room for comments after data has already
C                    been added to the file involves moving the data,
C                    and thus is slower.
C
C                    NCOMCH must be greater than or equal to zero.
C
C$ Detailed_Output
C
C     HANDLE         is the handle of the file designated by FNAME.
C                    This handle is used to identify the file to other
C                    sky catalog routines.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1)  If NCOMCH is less than zero, the error SPICE(INVALIDCOUNT)
C         will be signalled. No file will be created.
C
C     2)  If IFNAME is invalid, the error will be diagnosed by routines
C         called by this routine.
C
C     3)  If the indicated file cannot be opened, the error will be
C         diagnosed by routines called by this routine.
C
C     4)  If an I/O error occurs while reading or writing the indicated
C         file, the error will be diagnosed by routines called by this
C         routine.
C
C     5) If another catalog has already been opened by a call to this
C        entry but not completed, then the error 'SPICE(CATALOGISOPENED)'
C        will be signalled.
C
C$ Files
C
C     TBD.
C
C$ Particulars
C
C     After carrying out set of checks (see above) we open new DAS
C     file for write access and store its handle as an "internal"
C     parameter.
C
C     Then we clear area devoted for the META DIRECTORY, perform
C     some special initialization and set flag indicating that
C     catalog was opened successfully.
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     None.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     open new type_2 sky_catalog file
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWOP2' )
      END IF

C
C     Check whether some catalog has already been opened for writing
C     but not completed.
C
      IF ( OPENED ) THEN
         CALL SETMSG ( 'Type 2 Sky catalog, ''#'', has already '  //
     .                 'been opened for writing but not finished '//
     .                 'correctly prior to calling this routine.' )
         CALL ERRCH  ( '#', FNAM                                  )
         CALL SIGERR ( 'SPICE(CATALOGISOPENED)'                   )
         CALL CHKOUT ( 'STWOP2'                                   )
         RETURN
      END IF

C
C     Check the comment character count.
C
      IF ( NCOMCH .LT. 0 ) THEN

         CALL SETMSG ( 'The number of reserved comment characters ' //
     .                 'must be non-negative but was #.'            )
         CALL ERRINT ( '#',  NCOMCH                                 )
         CALL SIGERR ( 'SPICE(INVALIDCOUNT)'                        )
         CALL CHKOUT ( 'STWOP2'                                     )
         RETURN

      END IF

C
C     Reserve enough comment records to accommodate the requested
C     number of comment characters.
C
      NCR  =  ( NWC + NCOMCH - 1 ) / NWC

C
C     Open new DAS file for write access.
C
      FNAM = FNAME
      CALL DASONW ( FNAM, ST2TYP, IFNAME, NCR, HNDL )

      IF ( FAILED() ) THEN
         CALL CHKOUT ( 'STWOP2' )
         RETURN
      END IF

C
C     Store the DAS file handle as an "internal" parameter
C
      HANDLE = HNDL

C
C     Clear BEGMET-1 records devoted for the META DIRECTORY and
C     write down "one" in the first record (to start with). Remind
C     that the first record of the SPICE Catalog is the number of
C     records in its META DIRECTORY.
C
      J = 0
      DO I = 1, BEGMET - 1
         CALL DASADI ( HANDLE, 1, J )
      END DO

      J = 1
      CALL DASUDI ( HANDLE, 1, 1, J )

C
C     Set flag indicating that catalog was opened successfully.
C
      OPENED = .TRUE.

      CALL CHKOUT ( 'STWOP2' )
      RETURN


C$Procedure STWCI2 ( store general sky catalog information )

      ENTRY STWCI2 ( CATNAM, OBTYPE, EPOCH, FRAME,
     .                 MATRIX, NOB, NCATDS, DESCR )

C$ Abstract
C
C     Stores general information about sky catalog in the
C     metainformation area of the catalog file.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     CHARACTER*(*)         CATNAM
C     CHARACTER*(*)         OBTYPE
C     CHARACTER*(*)         EPOCH
C     CHARACTER*(*)         FRAME
C     DOUBLE PRECISION      MATRIX  ( 3, 3 )
C     INTEGER               NOB
C     INTEGER               NCATDS
C     CHARACTER*(*)         DESCR   (*)
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     CATNAM     I   Name of the catalog
C     OBTYPE     I   Type of sky objects in the catalog
C     EPOCH      I   Epoch for the catalog objects position
C     FRAME      I   Frame for the catalog objects position
C     MATRIX     I   Transformation matrix from catalog frame to J2000
C     NOB        I   The number of objects in the catalog
C     NCATDS     I   The number of lines in the catalog description
C     DESCR      I   The catalog description itself
C
C$ Detailed_Input
C
C     CATNAM         is the name of the catalog.
C
C     OBTYPE         is the type of sky objects in the catalog.
C
C     EPOCH          is the time of the catalog object positions.
C                    This time can be in any form recognized by the
C                    SPICE time system. TDB times are recommended.
C
C     FRAME          is the name of the frame in which the catalog
C                    object positions are specified.
C
C     MATRIX         is the transformation matrix from catalog frame
C                    FRAME specified to the J2000 inertial frame.
C
C     NOB            is the number of objects in the catalog.
C
C     NCATDS         is the number of lines in the catalog description.
C
C     DESCR          is array of lines containing the catalog
C                    description.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is opened for writing at the time
C        when this routine is called, then the error
C        'SPICE(CATALOGISNOTOPENED)' will be signalled.
C
C     2) If conversion of EPOCH to ET seconds fails, appropriate
C        error message will be signaled by STR2ET called by this
C        entry point.
C
C     3) If this entry is called the second time, then the error
C        'SPICE(ENTRYALREADYCALLED)' will be signalled.
C
C     4) If specified catalog name is too long, then the error
C        'SPICE(CATALOGNAMETOOLONG)' will be signalled.
C
C     5) If specified catalog name is too long, then the error
C        'SPICE(OBJECTTYPETOOLONG)' will be signalled.
C
C     6) If specified catalog frame name is too long, then the error
C        'SPICE(FRAMENAMETOOLONG)'
C
C     7) If specified catalog frame name is supported in SPICE, but
C        it's not an inertial frame, then the error
C        'SPICE(NOTINERTIALFRAME)' will be signalled.
C
C     8) If specified transformation matrix is not a rotation
C        matrix within given tolerance, then the error
C        'SPICE(NOTAROTATIONMATRIX)' will be signalled.
C
C     9) If SPICE transformation from catalog frame to J2000 is
C        different from the provided input matrix, the the error
C        'SPICE(BADINPUTMATRIX)' will be signalled.
C
C     10) If number of lines in the catalog description is less
C        then or equal to zero, then the error
C        'SPICE(BADNUMBEROFLINES)' will be signalled.
C
C     11) If number of objects in the catalog is less then or
C        equal to zero, then the error 'SPICE(BADNUMBEROFOBJECTS)'
C        will be signalled.
C
C     12) If encoded description cannot be fit into internal buffer,
C        then the error 'SPICE(STWCI2DESIGNFLAW)' will be signalled.
C
C     13) If specified number of objects in the catalog is greater
C        than the maximum  number of objects that this writer was
C        designed to handle defined in the parameter NOBMAX, then the
C        error 'SPICE(TOOMANYOBJECTS)' will be signalled.
C
C$ Files
C
C     TBD
C
C$ Particulars
C
C     At the very beginning we check:
C
C     - whether the catalog is opened for writing,
C     - whether this entry has already been called,
C     - whether the number of objects in the catalog makes sense.
C
C     On successful completion the checks we buffer number of objects
C     and write it to the metainformation area. Then we do some special
C     manipulations to set up META DIRECTORY mechanism for the future
C     additions.
C
C     And then we perform the additions:
C
C     - "register" the catalog name (after certain checks),
C     - "register" the object type (after certain checks),
C     - "register" catalog epoch as standard SPICE J2000 ET seconds,
C     - "register" catalog frame and the frame to J2000 transfer
C        matrix (after checks whether specified matrix is a rotation
C        matrix, whether we can recognize the frame, whether the
C        frame is inertial, etc.),
C     - "register" number of lines in the catalog description (after
C        certain check),
C     - "register" catalog description text (after certain check).
C
C     On completion we set flag indicating that metainformation
C     directory and data area were initialized correctly.
C
C     This entry must be called only once, after call to STWOP2 and
C     before call to any other entry of this umbrella.
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be opened for writing using STWOP2
C     entry of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     write general information to type_2 sky_catalog
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWCI2' )
      END IF

C
C     Check whether the catalog is opened for writing.
C
      IF ( .NOT. OPENED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was opened for  '   //
     .                 'writing prior to calling this routine.'   )
         CALL SIGERR ( 'SPICE(CATALOGISNOTOPENED)'                )
         CALL CHKOUT ( 'STWCI2'                                   )
         RETURN
      END IF

C
C     Check whether this entry has already been called.
C
      IF ( WCI2FL ) THEN
         CALL SETMSG ( 'This entry has already been called after '//
     .                 'the catalog was opened; it can be '       //
     .                 'called only once.'                        )
         CALL SIGERR ( 'SPICE(ENTRYALREADYCALLED)'                )
         CALL CHKOUT ( 'STWCI2'                                   )
         RETURN
      END IF

C
C     Check whether the number of objects in the catalog makes sense.
C
      IF ( NOB .LE. 0 ) THEN
         CALL SETMSG ( 'Specified number of objects in the '      //
     .                 'catalog, #, is less then or equal to '    //
     .                 'zero. This doesn''t make sense.'          )
         CALL ERRINT ( '#', NOB                                   )
         CALL SIGERR ( 'SPICE(BADNUMBEROFOBJECTS)'                )
         CALL CHKOUT ( 'STWCI2'                                   )
         RETURN
      END IF

C
C     Check whether the number of objects is less or equal to the
C     maximum number that this writer was designed to handle.
C
      IF ( NOB .GT. NOBMAX ) THEN
         CALL SETMSG ( 'Specified number of objects in the '      //
     .                 'catalog, #, is greater than the maximum ' //
     .                 'number of objects that this writer '      //
     .                 'was designed to handle. Current '         //
     .                 'maximum is # objects and it is defined '  //
     .                 'by parameter NOBMAX.'                     )
         CALL ERRINT ( '#', NOB                                   )
         CALL ERRINT ( '#', NOBMAX                                )
         CALL SIGERR ( 'SPICE(TOOMANYOBJECTS)'                    )
         CALL CHKOUT ( 'STWCI2'                                   )
         RETURN
      END IF

C
C     Buffer number of objects and write it to the metainformation
C     area.
C
      NOBJ = NOB
      CALL STAIT2 ( HANDLE, MDNOFO, 1, NOBJ )

C
C     Since the number of objects was the first item added to the
C     metainformation area, we need to do some special manipulations
C     to set up META DIRECTORY mechanism for the future additions.
C
C     The purpose of these manipulations to update pointers the first
C     and the last byte of the value referred to by the first entry
C     in the metadirectory. These pointers are set incorrectly by the
C     preceding call to STAIT2 and they have to be adjusted to point
C     the first element of the META INFORMATION value area in which
C     NOBJ was actually stored.
C
      CALL DASUDI ( HANDLE, 6, 6, BEGMET )
      CALL DASUDI ( HANDLE, 7, 7, BEGMET )

C
C     Now we can proceed with STAIT2 without fear: no more special
C     adjustments will be needed.
C

C
C     Check length of the catalog name.
C
      CALL STCMB2 ( .FALSE., CATNAM, LINE )

      IF ( NBLEN(LINE) .GT. CATNLN ) THEN
         CALL SETMSG ( 'The length of the specified catalog '     //
     .                 'name, #, is greater than the number of '  //
     .                 'characters that can be stored, #.'        )
         CALL ERRINT ( '#', NBLEN(LINE)                           )
         CALL ERRINT ( '#', CATNLN                                )
         CALL SIGERR ( 'SPICE(CATALOGNAMETOOLONG)'                )
         CALL CHKOUT ( 'STWCI2'                                   )
         RETURN
      END IF

C
C     Convert to INTs and "register" catalog name.
C
      CALL STT2I2 ( LINE, CATNLN, Z, J          )
      CALL STAIT2 ( HANDLE, MDCNAM, CATNLN/NCHARI, Z )

C
C     Check length of the object type.
C
      CALL STCMB2 ( .FALSE., OBTYPE, LINE )

      IF ( NBLEN(LINE) .GT. OBJTLN ) THEN
         CALL SETMSG ( 'The length of the specified object '      //
     .                 'type, #, is greater than the number of '  //
     .                 'characters that can be stored, #.'        )
         CALL ERRINT ( '#', NBLEN(LINE)                           )
         CALL ERRINT ( '#', OBJTLN                                )
         CALL SIGERR ( 'SPICE(OBJECTTYPETOOLONG)'                 )
         CALL CHKOUT ( 'STWCI2'                                   )
         RETURN
      END IF

C
C     Convert to INTs and "register" catalog object type.
C
      CALL STT2I2 ( LINE, OBJTLN, Z, J )
      CALL STAIT2 ( HANDLE, MDOTYP, OBJTLN/NCHARI, Z )

C
C     "register" EPOCH as standard SPICE J2000 ET seconds.
C
      CALL STR2ET ( EPOCH, ET )
      CALL DP2HX  ( ET, LINE, K           )
      CALL STT2I2 ( LINE, 20, Z, K        )
      CALL STAIT2 ( HANDLE, MDEPOC, 5, Z  )

C
C     Check length of the catalog frame name.
C
      CALL STCMB2 ( .TRUE., FRAME, LINE )

      IF ( NBLEN(LINE) .GT. FRMNLN ) THEN
         CALL SETMSG ( 'The length of the catalog frame '         //
     .                 'name, #, is greater than the number of '  //
     .                 'characters that can be stored, #.'        )
         CALL ERRINT ( '#', NBLEN(LINE)                           )
         CALL ERRINT ( '#', FRMNLN                                )
         CALL SIGERR ( 'SPICE(FRAMENAMETOOLONG)'                  )
         CALL CHKOUT ( 'STWCI2'                                   )
         RETURN
      END IF

C
C     Check whether specified matrix is a rotation matrix (within
C     tolerance.) If not, complain; if yes, make it into an "exact"
C     rotation matrix.
C
      IF ( .NOT. ISROT ( MATRIX, RMTTOL, RMTTOL ) ) THEN
         CALL SETMSG ( 'Specified catalog frame to J2000 '        //
     .                 'transformation matrix is not a rotation ' //
     .                 'matrix within # tolerance.'               )
         CALL ERRDP  ( '#', RMTTOL                                )
         CALL SIGERR ( 'SPICE(NOTAROTATIONMATRIX)'                )
         CALL CHKOUT ( 'STWCI2'                                   )
         RETURN
      ELSE

C
C        Pull matrix through M2Q/Q2M to make it into an exact rotation.
C
         CALL M2Q( MATRIX, QUAT )
         CALL Q2M( QUAT,   MATR )

      END IF

C
C     Check whether we can recognize this frame.
C
      CALL NAMFRM ( LINE, FRCODE )

      IF ( FRCODE .NE. 0 ) THEN

C
C        Find out whether this frame is inertial. Complain if not.
C
         CALL FRINFO ( FRCODE, FRCENT, FRCLSS, FRCLID, FOUND )

         IF ( FRCLSS .NE. 1 ) THEN
            CALL SETMSG ( 'Though specified frame ''#'' is '         //
     .                    'supported in SPICE, it''s not '           //
     .                    'recognized as inertial frame; it''s a '   //
     .                    'frame of class #.'                        )
            CALL ERRCH  ( '#', LINE                                  )
            CALL ERRINT ( '#', FRCLSS                                )
            CALL SIGERR ( 'SPICE(NOTINERTIALFRAME)'                  )
            CALL CHKOUT ( 'STWCI2'                                   )
            RETURN
         END IF

C
C        Get SPICE version of rotation matrix from catalog frame
C        to J2000.
C
         CALL PXFORM ( LINE, 'J2000', 0.D0, SPCMAT )

C
C        Compare SPICE matrix with input matrix.
C
         IF ( VDISTG( MATR, SPCMAT, 9 ) .GT. RMTTOL ) THEN
            CALL SETMSG ( 'The SPICE version of the matrix '         //
     .                    'rotating vectors from specified frame '   //
     .                    '''#'' to J2000 is substantially '         //
     .                    'different from the provided input matrix.')
            CALL ERRCH  ( '#', LINE                                  )
            CALL SIGERR ( 'SPICE(BADINPUTMATRIX)'                    )
            CALL CHKOUT ( 'STWCI2'                                   )
            RETURN
         END IF

      END IF

C
C     We check all we could about frame and matrix. Convert them to
C     INTs and "register" in the metainformation.
C
      CALL STT2I2 ( LINE, FRMNLN, Z, J )
      CALL STAIT2 ( HANDLE, MDFRAM, FRMNLN/NCHARI, Z )

      DO I = 1, 3
         DO J = 1, 3
            LINE = ' '
            CALL DP2HX  ( MATR(I,J), LINE, K )
            CALL STT2I2 ( LINE, DPHXSZ,
     .                    Z ( (3*I+J-4) * (DPHXSZ/NCHARI) + 1 ), K )
         END DO
      END DO
      CALL STAIT2 ( HANDLE, MDMATR, 9*(DPHXSZ/NCHARI), Z )

C
C     Check whether number of lines in the catalog description makes
C     sense.
C
      IF ( NCATDS .LE. 0 ) THEN
         CALL SETMSG ( 'Specified number of lines in the catalog '//
     .                 'description, #, is less then or equal to '//
     .                 'zero. This doesn''t make sense.'          )
         CALL ERRINT ( '#', NCATDS                                )
         CALL SIGERR ( 'SPICE(BADNUMBEROFLINES)'                  )
         CALL CHKOUT ( 'STWCI2'                                   )
         RETURN
      END IF

C
C     "register" number of lines in the description.
C
      CALL STAIT2 ( HANDLE, MDNCDS, 1, NCATDS )

C
C     Sanity check to make sure that we will be able to fit catalog
C     description encoded by INTs into main temporary buffer.
C
      IF ( NCATDS * (DSCLSZ/NCHARI) .GT. NOBMAX ) THEN
         CALL SETMSG ( 'Design flaw. Encoded description cannot ' //
     .                 'be fit into internal buffer.'             )
         CALL ERRINT ( '#', NCATDS                                )
         CALL SIGERR ( 'SPICE(STWCI2DESIGNFLAW)'                  )
         CALL CHKOUT ( 'STWCI2'                                   )
         RETURN
      END IF

C
C     Convert to INTs NCATDS and "register" catalog description text.
C
      DO I = 1, NCATDS
         CALL STT2I2 ( DESCR(I), DSCLSZ,
     .                 ARR3(1+(I-1)*(DSCLSZ/NCHARI)), J)
      END DO
      CALL STAIT2 ( HANDLE, MDCDSC, (DSCLSZ/NCHARI)*NCATDS, ARR3 )

C
C     Set flag indicating that this routine was called meaning that
C     metainformation directory and data area were initialized
C     correctly.
C
      WCI2FL = .TRUE.

C
C     All done. Checking out.
C
      CALL CHKOUT( 'STWCI2' )

      RETURN


C$Procedure STWFI2 ( store sky catalog field information )

      ENTRY STWFI2 ( NFLD, FLNAM, FLTYP, FLCLS, FLINDX, NFLDDS, DESCR)

C$ Abstract
C
C     Stores general information about sky catalog fields in
C     the metainformation area of the catalog file.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               NFLD
C     CHARACTER*(*)         FLNAM  (*)
C     CHARACTER*(1)         FLTYP  (*)
C     CHARACTER*(*)         FLCLS  (*)
C     LOGICAL               FLINDX (*)
C     INTEGER               NFLDDS (*)
C     CHARACTER*(*)         DESCR  (*)
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     NFLD       I   Number of fields in a catalog record
C     FLNAM      I   Catalog field names
C     FLTYP      I   Catalog field types
C     FLCLS      I   Catalog field classes
C     FLINDX     I   Fields indicating whether fields should be indexed
C     NFLDDS     I   Numbers of lines in catalog field descriptions
C     DESCR      I   Field descriptions
C
C$ Detailed_Input
C
C     NFLD           is the number of fields in a catalog record, NOT
C                    including object position fields.
C
C     FLNAM          is a character array containing catalog field
C                    names. Maximum length of a catalog field name
C                    is 24 characters (parameter FLDNLN).
C
C     FLTYP          is a character array specifying catalog field
C                    types. The following types are valid: 'C' - text,
C                    'I' - integer, 'D' - double precision.
C
C     FLCLS          is a character array specifying catalog field
C                    classes. The following classes can be assigned 
C                    to catalog fields by a user:
C
C                          'ID'
C                          'RA_PM'
C                          'DEC_PM'
C                          'PARALLAX'
C                          'RADIAL_VELOCITY'
C                          'INTENSITY'
C                          'CLASS_INDEX'
C                          'OBJECT_TYPE'
C
C                    Any other class values are ignored.
C
C                    One catalog field must be of class 'ID'.
C
C                    If a field of class 'RA_PM' is present, then a
C                    field of class 'DEC_PM' must also be present and
C                    vice versa.
C
C                    None or only one field can have class 'PARALLAX'.
C
C                    None or only one field can have class 
C                    'RADIAL_VELOCITY'.
C
C                    None, one or a few fields can have class
C                    'INTENSITY'.
C
C                    None or only one field can have class
C                    'OBJECT_TYPE'.
C
C                    None or only one field can have class
C                    'CLASS_INDEX'.
C
C     FLINDX         is a logical array specifying which of the
C                    catalog fields should be indexed. If a catalog
C                    field should be indexed, then corresponding
C                    element of the array must be set to .TRUE.;
C                    otherwise it must be set to .FALSE.
C
C     NFLDDS         is an integer array where "i-th" element is the
C                    number of lines in the "i-th" field description.
C
C     DESCR          is a character array containing all catalog field
C                    descriptions.
C
C$ Detailed_Output
C
C     None.
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is opened for writing at the time
C        when this routine is called, then the error
C        'SPICE(CATALOGISNOTOPENED)' will be signalled.
C
C     2) If this entry is called the second time, then the error
C        'SPICE(ENTRYALREADYCALLED)' will be signalled.
C
C     3) If this entry was called before STWCI2, then the error
C        'SPICE(CALLEDOUTOFORDER)' will be signalled.
C
C     4) If number of fields in the catalog is less then or equal to
C        zero, then the error 'SPICE(BADNUMBEROFFIELDS)' will be
C        signalled.
C
C     5) If name of a field is too long, them the error
C        'SPICE(FIELDNAMETOOLONG)' will be signaled.
C
C     6) If type of a field cannot be recognized, then the error
C        'SPICE(BADFIELDTYPE)' will be signalled.
C
C     7) If none of the fields was marked as having class 'ID', then
C        the error 'SPICE(NOIDFIELD)' will be signalled.
C
C     8) If 'DEC_PM' field was provided but 'RA_PM' not, then the error
C        'SPICE(ONLYPMDECSPECIFIED)' will be signalled.
C
C     9) If 'RA_PM' field was provided but 'DEC_PM' not, then the error
C        'SPICE(ONLYPMRASPECIFIED)' will be signalled.
C
C     10) If more than one field of class 'ID' was specified, then the
C        error 'SPICE(TOOMANYIDFLDS)' will be signalled.
C
C     11) If more than one field of class 'RA_PM' was specified, then
C        the error 'SPICE(TOOMANYPMRAFLDS)' will be signalled.
C
C     12) If more than one field of class 'DEC_PM' was specified,
C        then the error 'SPICE(TOOMANYPMDECFLDS)' will be signalled.
C
C     13) If more than one field of class 'PARALLAX' was specified,
C        then the error 'SPICE(TOOMANYPRLXFLDS)' will be signalled.
C
C     14) If more than one field of class 'RADIAL_VELOCITY' was 
C        specified, then the error 'SPICE(TOOMANYRADVELFLDS)' will be 
C        signalled.
C
C     15) If more than one field of class 'OBJECT_TYPE' was specified,
C        then the error 'SPICE(TOOMANYOBJTYPFLDS)' will be signalled.
C
C     16) If more than one field of class 'CLASS_INDEX' was specified,
C        then the error 'SPICE(TOOMANYCLSIDXFLDS)' will be signalled.
C
C     17) If scratch DAS file cannot be opened, the error will be
C        diagnosed by routines called by this routine.
C
C     18) If specified number of lines in the description of a field
C        is negative, the the error 'SPICE(BADNUMBEROFDLINES)'
C        will be signalled.
C
C     19) If specified number of fields in the catalog is greater
C        then maximum number of fields that SPICE Type 2 can
C        accommodate (NFLMAX), then the error 'SPICE(TOOMANYFIELDS)'
C        will be signalled.
C
C     20) If a field was specified as to be indexed, but catalog
C        has only one object, then the error 'SPICE(CANNOTINDEXFLD)'
C        will be signalled.
C
C     21) If class name specified for a given field is not one of 
C        the supported classes for Type 2 Sky catalog fields, then
C        the error 'SPICE(UNSUPPFLDCLASS)' will be signalled.
C
C$ Files
C
C     This routine open scratch DAS file and write all lines from
C     DESCR to it.
C
C$ Particulars
C
C     We perform a lot of checks concerning fields features and
C     buffer them (with certain processing) as internal parameters.
C     On successful completion of all checks for exceptions we
C     open scratch DAS file and "dump" all lines from DESCR to it.
C
C     This entry must be called only once, after call to STWCI2 and
C     before call to STWIN2 entry of this umbrella.
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be opened for writing using STWOP2
C     entry of this routine prior to calling this entry.
C
C     The catalog file metainformation area and directory must
C     initialized using STWCI2 entry of this routine prior to calling
C     this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     write field information to type_2 sky_catalog
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWFI2' )
      END IF

C
C     Check whether the catalog is opened for writing.
C
      IF ( .NOT. OPENED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was opened for  '   //
     .                 'writing prior to calling this routine.'   )
         CALL SIGERR ( 'SPICE(CATALOGISNOTOPENED)'                )
         CALL CHKOUT ( 'STWFI2'                                   )
         RETURN
      END IF

C
C     Check whether this entry is called after STWCI2.
C
      IF ( .NOT. WCI2FL ) THEN
         CALL SETMSG ( 'This entry cannot be called before '      //
     .                 'STWCI2 has been called.'                  )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER)'                  )
         CALL CHKOUT ( 'STWFI2'                                   )
         RETURN
      END IF

C
C     Check whether this entry has already been called.
C
      IF ( WFI2FL ) THEN
         CALL SETMSG ( 'This entry has already been called after '//
     .                 'the catalog was opened; it can be '       //
     .                 'called only once.'                        )
         CALL SIGERR ( 'SPICE(ENTRYALREADYCALLED)'                )
         CALL CHKOUT ( 'STWFI2'                                   )
         RETURN
      END IF

C
C     Check whether number of fields in the catalog makes sense.
C
      IF ( NFLD .LE. 0 ) THEN
         CALL SETMSG ( 'Specified number of fields in the '       //
     .                 'catalog, #, is less then or equal to '    //
     .                 'zero. This doesn''t make sense.'          )
         CALL ERRINT ( '#', NFLD                                  )
         CALL SIGERR ( 'SPICE(BADNUMBEROFFIELDS)'                 )
         CALL CHKOUT ( 'STWFI2'                                   )
         RETURN
      END IF

C
C     Check whether number of fields in the catalog makes sense. Note
C     that we need to reduce field count
C
      IF ( NFLD .GT. NFLMAX - 4 ) THEN
         CALL SETMSG ( 'Specified number of fields in the '       //
     .                 'catalog, #, is greater then maximum '     //
     .                 'number of fields, #, that SPICE Type 2 '  //
     .                 'can accomodate.'                          )
         CALL ERRINT ( '#', NFLD                                  )
         CALL ERRINT ( '#', NFLMAX - 4                            )
         CALL SIGERR ( 'SPICE(TOOMANYFIELDS)'                     )
         CALL CHKOUT ( 'STWFI2'                                   )
         RETURN
      END IF

C
C     Buffer inputs for each of the fields.
C
      NFLDS = NFLD

      DO I = 1, NFLDS

C
C        Move field information to internal buffers. First, do field
C        names. Check field name length and complain if it doesn't
C        into the space we have for it.
C
         CALL STCMB2 ( .TRUE., FLNAM(I), LINE )
         IF ( NBLEN( LINE ) .GT. FLDNLN ) THEN
            CALL SETMSG ( 'The length of the field No. # name, '     //
     .                    '#, is greater than the number of '        //
     .                    'characters that can be stored, #.'        )
            CALL ERRINT ( '#', I                                     )
            CALL ERRINT ( '#', NBLEN(LINE)                           )
            CALL ERRINT ( '#', FLDNLN                                )
            CALL SIGERR ( 'SPICE(FIELDNAMETOOLONG)'                  )
            CALL CHKOUT ( 'STWFI2'                                   )
            RETURN
         END IF

         FLDNAM(I) = LINE

C
C        Second, do field class. At this point, check only for 
C        permitted values. More class assigment consistency and 
C        appropiatness checks will be done after this loop.
C
         CALL STCMB2 ( .TRUE., FLCLS(I), FLDCLS(I) )
         IF ( .NOT. ( FLDCLS(I) .EQ. ' '    .OR.
     .                FLDCLS(I) .EQ. FCID   .OR.
     .                FLDCLS(I) .EQ. FCPMRA .OR.
     .                FLDCLS(I) .EQ. FCPMDC .OR.
     .                FLDCLS(I) .EQ. FCPRLX .OR.
     .                FLDCLS(I) .EQ. FCRVEL .OR.
     .                FLDCLS(I) .EQ. FCINTE .OR.
     .                FLDCLS(I) .EQ. FCCLSS .OR.
     .                FLDCLS(I) .EQ. FCOTYP      ) ) THEN
            CALL SETMSG ( 'The class ''#'' assigned to the field '   //
     .                    'No. # is not supported for Type 2 Sky '   //
     .                    'catalogs.'                                )
            CALL ERRCH  ( '#', FLCLS(I)                              )
            CALL ERRINT ( '#', I                                     )
            CALL SIGERR ( 'SPICE(UNSUPPFLDCLASS)'                    )
            CALL CHKOUT ( 'STWFI2'                                   )
            RETURN
         END IF

C
C        Third, the number of lines in each field description. Sanity
C        check to make sure that this number of not negative.
C
         IF ( NFLDDS(I) .LT. 0 ) THEN
            CALL SETMSG ( 'Specified number of lines, #, in the '    //
     .                    'description of the fields No. # is '      //
     .                    'negative. This doesn''t make sense.'      )
            CALL ERRINT ( '#', NFLDDS(I)                             )
            CALL ERRINT ( '#', I                                     )
            CALL SIGERR ( 'SPICE(BADNUMBEROFDLINES)'                 )
            CALL CHKOUT ( 'STWFI2'                                   )
            RETURN
         END IF

         NFDESC(I) = NFLDDS(I)

C
C        Initialize field prefix string and position of the first
C        non-common character.
C
         FLDPRF(I) = ' '
         FLDBPS(I) = 1

C
C        Generate FLDIND integer array
C
         IF ( FLINDX(I) ) THEN

C
C           Check whether number of objects in the catalog is greater
C           than 1. Obviously, we cannot index any fields in a catalog
C           with only one object :)
C
            IF ( NOBJ .EQ. 1 ) THEN
              CALL SETMSG ( 'Cannot generate index table for '      //
     .                      'any of the fields in the catalog '     //
     .                      'that has only one object. Field '      //
     .                      'number # was specified as to be '      //
     .                      'indexed.'                              )
              CALL ERRINT ( '#', I                                  )
              CALL SIGERR ( 'SPICE(CANNOTINDEXFLD)'                 )
              CALL CHKOUT ( 'STWFI2'                                )
              RETURN
            END IF

            FLDIND(I) = 1
         ELSE
            FLDIND(I) = 0
         END IF

C
C        Generate FLTYPE integer array. Complain if field type is not
C        recognized.
C
         CALL UCASE( FLTYP(I), CH )
         IF      ( CH .EQ. 'C' ) THEN
            FLTYPE(I) = 0
         ELSE IF ( CH .EQ. 'I' ) THEN
            FLTYPE(I) = 1
         ELSE IF ( CH .EQ. 'D' ) THEN
            FLTYPE(I) = 2
         ELSE
            CALL SETMSG ( 'Cannot recognize type of field No. # '    //
     .                    '-- #. Field type can be ''C'', ''I'' or ' //
     .                    '''D''.'                                   )
            CALL ERRINT ( '#', I                                     )
            CALL SIGERR ( 'SPICE(BADFIELDTYPE)'                      )
            CALL CHKOUT ( 'STWFI2'                                   )
            RETURN
         END IF

      END DO

C
C     Verify that one field is marked as 'ID' field. If not, complain.
C
      I = ESRCHC ( FCID, NFLDS, FLDCLS )
      IF ( I .EQ. 0 ) THEN
         CALL SETMSG ( 'One field in the catalog must have '      //
     .                 'class ''#''. None of the specified '      //
     .                 'fields was marked as having this class.'  )
         CALL ERRCH  ( '#', FCID                                  )
         CALL SIGERR ( 'SPICE(NOIDFIELD)'                         )
         CALL CHKOUT ( 'STWFI2'                                   )
         RETURN
      END IF

C
C     Verify that there is only one 'ID' field.
C
      IF ( I .LT. NFLDS ) THEN
         K = ESRCHC ( FCID, NFLDS-I, FLDCLS(I+1) )
         IF ( K .NE. 0 ) THEN
            CALL SETMSG ( 'More than one field of class ''#'' '      //
     .                    'was specified.'                           )
            CALL ERRCH  ( '#', FCID                                  )
            CALL SIGERR ( 'SPICE(TOOMANYIDFLDS)'                     )
            CALL CHKOUT ( 'STWFI2'                                   )
            RETURN
         END IF
      END IF

C
C     Verify that none or both -- RA and DEC -- PM-class fields were
C     provided.
C
      I = ESRCHC ( FCPMRA, NFLDS, FLDCLS )
      K = ESRCHC ( FCPMDC, NFLDS, FLDCLS )

      IF      ( I .EQ. 0 .AND. K .NE. 0 ) THEN
         CALL SETMSG ( 'None or both -- RA and DEC -- proper '    //
     .                 'motion class fields must be provided. '   //
     .                 'Only ''#'' was.'                          )
         CALL ERRCH  ( '#', FCPMDC                                )
         CALL SIGERR ( 'SPICE(ONLYPMDECSPECIFIED)'                )
         CALL CHKOUT ( 'STWFI2'                                   )
         RETURN
      ELSE IF ( I .NE. 0 .AND. K .EQ. 0 ) THEN
         CALL SETMSG ( 'None or both -- RA and DEC -- proper '    //
     .                 'motion class fields must be provided. '   //
     .                 'Only ''#'' was.'                          )
         CALL ERRCH  ( '#', FCPMRA                                )
         CALL SIGERR ( 'SPICE(ONLYPMRASPECIFIED)'                 )
         CALL CHKOUT ( 'STWFI2'                                   )
         RETURN
      END IF

C
C     Verify that only one of each, PMRA and PMDEC, was specified.
C
      IF ( I .NE. 0 .AND. I .LT. NFLDS ) THEN
         J = ESRCHC ( FCPMRA, NFLDS-I, FLDCLS(I+1) )
         IF ( J .NE. 0 ) THEN
            CALL SETMSG ( 'More than one field of class ''#'' '      //
     .                    'was specified.'                           )
            CALL ERRCH  ( '#', FCPMRA                                )
            CALL SIGERR ( 'SPICE(TOOMANYPMRAFLDS)'                   )
            CALL CHKOUT ( 'STWFI2'                                   )
            RETURN
         END IF
      END IF

      IF ( K .NE. 0 .AND. K .LT. NFLDS ) THEN
         J = ESRCHC ( FCPMDC, NFLDS-K, FLDCLS(K+1) )
         IF ( J .NE. 0 ) THEN
            CALL SETMSG ( 'More than one field of class ''#'' '      //
     .                    'was specified.'                           )
            CALL ERRCH  ( '#', FCPMDC                                )
            CALL SIGERR ( 'SPICE(TOOMANYPMDECFLDS)'                  )
            CALL CHKOUT ( 'STWFI2'                                   )
            RETURN
         END IF
      END IF

C
C     Verify that none or only one of each, 'PARALLAX', 
C     'RADIAL_VELOCITY', 'OBJECT_TYPE' and 'CLASS_INDEX', 
C     was specified.
C
      K = ESRCHC ( FCPRLX,  NFLDS, FLDCLS )
      IF ( K .NE. 0 .AND. K .LT. NFLDS ) THEN
         J = ESRCHC ( FCPRLX, NFLDS-K, FLDCLS(K+1) )
         IF ( J .NE. 0 ) THEN
            CALL SETMSG ( 'More than one field of class ''#'' '      //
     .                    'was specified.'                           )
            CALL ERRCH  ( '#', FCPRLX                                )
            CALL SIGERR ( 'SPICE(TOOMANYPRLXFLDS)'                   )
            CALL CHKOUT ( 'STWFI2'                                   )
            RETURN
         END IF
      END IF

      K = ESRCHC ( FCRVEL,  NFLDS, FLDCLS )
      IF ( K .NE. 0 .AND. K .LT. NFLDS ) THEN
         J = ESRCHC ( FCRVEL, NFLDS-K, FLDCLS(K+1) )
         IF ( J .NE. 0 ) THEN
            CALL SETMSG ( 'More than one field of class '            //
     .                    '''#'' was specified.'                     )
            CALL ERRCH  ( '#', FCRVEL                                )
            CALL SIGERR ( 'SPICE(TOOMANYRADVELFLDS)'                 )
            CALL CHKOUT ( 'STWFI2'                                   )
            RETURN
         END IF
      END IF

      K = ESRCHC ( FCOTYP,  NFLDS, FLDCLS )
      IF ( K .NE. 0 .AND. K .LT. NFLDS ) THEN
         J = ESRCHC ( FCOTYP, NFLDS-K, FLDCLS(K+1) )
         IF ( J .NE. 0 ) THEN
            CALL SETMSG ( 'More than one field of class '            //
     .                    '''#'' was specified.'                     )
            CALL ERRCH  ( '#', FCOTYP                                )
            CALL SIGERR ( 'SPICE(TOOMANYOBJTYPFLDS)'                 )
            CALL CHKOUT ( 'STWFI2'                                   )
            RETURN
         END IF
      END IF

      K = ESRCHC ( FCCLSS,  NFLDS, FLDCLS )
      IF ( K .NE. 0 .AND. K .LT. NFLDS ) THEN
         J = ESRCHC ( FCCLSS, NFLDS-K, FLDCLS(K+1) )
         IF ( J .NE. 0 ) THEN
            CALL SETMSG ( 'More than one field of class '            //
     .                    '''#'' was specified.'                     )
            CALL ERRCH  ( '#', FCCLSS                                )
            CALL SIGERR ( 'SPICE(TOOMANYCLSIDXFLDS)'                 )
            CALL CHKOUT ( 'STWFI2'                                   )
            RETURN
         END IF
      END IF

C
C     Open scratch DAS file and write all DESCR lines into it.
C
      CALL DASOPS ( DSCDAS )
      CALL DASADC ( DSCDAS, SUMAI(NFDESC, NFLDS)*DSCLSZ, 1, DSCLSZ,
     .                                                      DESCR   )

C
C     Set flag indicating that this routine was called meaning that
C     field attributes were buffered already.
C
      WFI2FL = .TRUE.

C
C     All done. Checking out.
C
      CALL CHKOUT( 'STWFI2' )

      RETURN


C$Procedure STWZS2 ( define approximate size of a zone )

      ENTRY STWZS2 ( ZONSIZ )

C$ Abstract
C
C     Define approximate size of elementary zone from which the rest of
C     the parameters of the celestial sphere splitting will be derived.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     DOUBLE PRECISION      ZONSIZ
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     ZONSIZ     I   approximate height of the elementary zone, radians
C
C$ Detailed_Input
C
C     ZONSIZ         is approximate size (height) of elementary zone
C                    in radians.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is opened for writing at the time
C        when this routine is called, then the error
C        'SPICE(CATALOGISNOTOPENED)' will be signalled.
C
C     2) If this entry is called the second time, then the error
C        'SPICE(ENTRYALREADYCALLED)' will be signalled.
C
C     3) If this entry was called before STWCI2, then the error
C        'SPICE(CALLEDOUTOFORDER)' will be signalled.
C
C     4) If input elementary zone size is smaller than minimum zone
C        size supported in current version of SPICE Type 2 Sky
C        catalog, then the error 'SPICE(ZONEISTOOSMALL)' will be
C        signalled.
C
C     5) If input elementatry zone size is bigger than PI, then the
C        error 'SPICE(ZONEISTOOBIG)' will be signalled.
C
C$ Files
C
C     TBD
C
C$ Particulars
C
C     On successful completion of certain checks we compute the exact
C     number of declination bands. Then based on the obtained number
C     we compute complete set of celestial sphere splitting parameters:
C     height of the elementary zones, the number of the zones and their
C     distribution along declination bands.
C     Then we register all these parameters in the METAINFORMATION
C     segment.
C
C     This entry must be called only once, after call to STWCI2 and
C     before call to STWIN2 entry of this umbrella.
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be opened for writing using STWOP2
C     entry of this routine prior to calling this entry.
C
C     The catalog file metainformation area and directory must
C     initialized using STWCI2 entry of this routine prior to calling
C     this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     define zone size for type_2 sky_catalog
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWZS2' )
      END IF

C
C     Check whether the catalog is opened for writing.
C
      IF ( .NOT. OPENED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was opened for '    //
     .                 'writing prior to calling this routine.'   )
         CALL SIGERR ( 'SPICE(CATALOGISNOTOPENED)'                )
         CALL CHKOUT ( 'STWZS2'                                   )
         RETURN
      END IF

C
C     Check whether this entry is called after STWCI2.
C
      IF ( .NOT. WCI2FL ) THEN
         CALL SETMSG ( 'This entry cannot be called before '      //
     .                 'STWCI2 has been called.'                  )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER)'                  )
         CALL CHKOUT ( 'STWZS2'                                   )
         RETURN
      END IF

C
C     Check whether this entry has already been called.
C
      IF ( WZS2FL ) THEN
         CALL SETMSG ( 'This entry has already been called after '//
     .                 'the catalog was opened; it can be '       //
     .                 'called only once.'                        )
         CALL SIGERR ( 'SPICE(ENTRYALREADYCALLED)'                )
         CALL CHKOUT ( 'STWZS2'                                   )
         RETURN
      END IF

C
C     Check the input value. It must be greater than the minimum zone
C     size supported by current version (see include file for
C     discussion) and less than PI (common sense :-).
C
      IF      ( ZONSIZ .LT. PI()/(NBMAX-0.5D0) ) THEN
         CALL SETMSG ( 'Input elementatry zone size, #, is '      //
     .                 'smaller than minimum zone size supported '//
     .                 'SPICE Type 2 Sky catalog, #.'             )
         CALL ERRDP  ( '#', ZONSIZ                                )
         CALL ERRDP  ( '#', PI()/(NBMAX-0.5D0)                    )
         CALL SIGERR ( 'SPICE(ZONEISTOOSMALL)'                    )
         CALL CHKOUT ( 'STWZS2'                                   )
         RETURN
      ELSE IF ( ZONSIZ .GT. PI()       ) THEN
         CALL SETMSG ( 'Input elementatry zone size, #, is '      //
     .                 'bigger than PI. This doesn''t make sense.')
         CALL ERRDP  ( '#', ZONSIZ                                )
         CALL SIGERR ( 'SPICE(ZONEISTOOBIG)'                      )
         CALL CHKOUT ( 'STWZS2'                                   )
         RETURN
      END IF

C
C     Compute the exact number of declination bands.
C
      NBANDS = PI() / ZONSIZ + 0.5D0

C
C     Compute complete set of celestial sphere splitting parameters
C     for this number of DEC bands.
C
      CALL STDIV2 ( NBANDS, DELDEC, NZONES, NINBND, NSUM )

C
C     Register all these parameters in the METAINFORMATION segment.
C
      CALL STAIT2 ( HANDLE, MDNOZO, 1,      NZONES )
      CALL STAIT2 ( HANDLE, MDNODB, 1,      NBANDS )
      CALL STAIT2 ( HANDLE, MDNINB, NBANDS, NINBND )
      CALL STAIT2 ( HANDLE, MDNSUM, NBANDS, NSUM   )

C
C     Set flag indicating that this routine was called meaning that
C     all celestial sphere splitting parameters were stored in
C     the metainformation area.
C
      WZS2FL = .TRUE.

C
C     All done. Checking out.
C
      CALL CHKOUT( 'STWZS2' )

      RETURN


C$Procedure STWPM2 ( define scale factor for proper motion )

      ENTRY STWPM2 ( PMSCAL )

C$ Abstract
C
C     Define the proper motion "scale coefficients" converting
C     units in which RA and DEC proper motions are given in the 
C     corresponding catalog fields to arcsec/year.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     DOUBLE PRECISION      PMSCAL(2)
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     PMSCAL     I   scale coefficients for proper motion in RA and DEC
C
C$ Detailed_Input
C
C     PMSCAL         are scale coefficients for RA and DEC proper motion 
C                    fields of the catalog. It is applied to calalog 
C                    proper motion values as follows:
C
C              RA_PM  arcsec/year = PMSCAL(1) * RA_PM  "catalog units"
C              DEC_PM arcsec/year = PMSCAL(2) * DEC_PM "catalog units"
C
C                    If catalog contains RA and DEC proper motion
C                    fields (as specified via FLCLS argument of
C                    STWFI2), then PMSCALs must be non-zero positive
C                    numbers.
C
C                    If catalog doesn't contain RA and DEC proper 
C                    motion fields (as specified via FLCLS argument of
C                    STWFI2), then PMSCALs must be zeroes.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is opened for writing at the time
C        when this routine is called, then the error
C        'SPICE(CATALOGISNOTOPENED)' will be signalled.
C
C     2) If this entry is called the second time, then the error
C        'SPICE(ENTRYALREADYCALLED)' will be signalled.
C
C     3) If this entry was called before STWFI2, then the error
C        'SPICE(CALLEDOUTOFORDER)' will be signalled.
C
C     4) If one of specified proper motion scale factors is less than 
C        or equal to zero while there are some fields marked as 
C        PM-class fields, then the error 'SPICE(BADPMSCALVALUE1)' will
C        be signalled.
C
C     5) If one of specified proper motion scale factors is greater 
C        than zero while there are no fields marked as 
C        PM-class fields, then the error 'SPICE(BADPMSCALVALUE2)' will
C        be signalled.
C
C$ Files
C
C     TBD
C
C$ Particulars
C
C     On successful completion of all the checks we buffer proper
C     motion scale coefficients and register in METAINFORMATION.
C
C     This entry must be called only once, after call to STWFI2 and
C     before call to STWIN2 entry of this umbrella.
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be opened for writing using STWOP2
C     entry of this routine prior to calling this entry.
C
C     The field attribute information must be provided using STWFI2
C     entry of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     define proper motion scale factor for type_2 sky_catalog
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWPM2' )
      END IF

C
C     Check whether the catalog is opened for writing.
C
      IF ( .NOT. OPENED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was opened for '    //
     .                 'writing prior to calling this routine.'   )
         CALL SIGERR ( 'SPICE(CATALOGISNOTOPENED)'                )
         CALL CHKOUT ( 'STWPM2'                                   )
         RETURN
      END IF

C
C     Check whether this entry is called after STWFI2.
C
      IF ( .NOT. WFI2FL ) THEN
         CALL SETMSG ( 'This entry cannot be called before '      //
     .                 'STWFI2 has been called.'                  )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER)'                  )
         CALL CHKOUT ( 'STWPM2'                                   )
         RETURN
      END IF

C
C     Check whether this entry has already been called.
C
      IF ( WPM2FL ) THEN
         CALL SETMSG ( 'This entry has already been called after '//
     .                 'the catalog was opened; it can be '       //
     .                 'called only once.'                        )
         CALL SIGERR ( 'SPICE(ENTRYALREADYCALLED)'                )
         CALL CHKOUT ( 'STWPM2'                                   )
         RETURN
      END IF

C
C     Check PMSCAL value. If catalog contains 'RA_PM' and 'DEC_PM' 
C     class fields, the PMSCAL must non-zero positive number.
C
C     Since we have already checked anything we could about 'RA_PM' and
C     'DEC_PM' in STWFI2 and verified that STWFI2 has been called,
C     checking that 'RA_PM' is present in FLDCLS is enough.
C
      I = ESRCHC ( FCPMRA,  NFLDS, FLDCLS )

      IF ( I .GT. 0  .AND.
     .   ( PMSCAL(1) .LE. 0.D0 .OR. PMSCAL(2) .LE. 0.D0 )) THEN
         CALL SETMSG ( 'While catalog contains both RA and DEC '  //
     .                 'proper motions, one of specified proper ' //
     .                 'motion scale factors (# and #) is less '  //
     .                 'than or equal to zero. This is not '      //
     .                 'permitted.'                               )
         CALL ERRDP  ( '#', PMSCAL(1)                             )
         CALL ERRDP  ( '#', PMSCAL(2)                             )
         CALL SIGERR ( 'SPICE(BADPMSCALVALUE1)'                   )
         CALL CHKOUT ( 'STWPM2'                                   )
         RETURN
      END IF

      IF ( I .EQ. 0  .AND.
     .   ( PMSCAL(1) .GT. 0.D0 .OR. PMSCAL(2) .GT. 0.D0 )) THEN
         CALL SETMSG ( 'While both specified proper motion '      //
     .                 'scale factors (# and #) were greater '    //
     .                 'than zero, no catalog fields were marked '//
     .                 'as PM-class fields. This is not '         //
     .                 'permitted.'                               )
         CALL ERRDP  ( '#', PMSCAL(1)                             )
         CALL ERRDP  ( '#', PMSCAL(2)                             )
         CALL SIGERR ( 'SPICE(BADPMSCALVALUE2)'                   )
         CALL CHKOUT ( 'STWPM2'                                   )
         RETURN
      END IF



C
C     PMSCAL seem to be OK ... or it just doesn't matter. Buffer it
C     and register in metainformation.
C
      CALL MOVED  ( PMSCAL, 2, PMCOEF )

      DO I = 1,2
         CALL DP2HX  ( PMCOEF(I), LINE, K    )
         CALL STT2I2 ( LINE, DPHXSZ, Z((I-1)*(DPHXSZ/NCHARI)+1), K )
      END DO
      CALL STAIT2 ( HANDLE, MDPMSC, 2*(DPHXSZ/NCHARI), Z )

C
C     Set flag indicating that this routine was called meaning that
C     proper motion scale factor has been stored in metainformation
C     area of the catalog file.
C
      WPM2FL = .TRUE.

C
C     All done. Checking out.
C
      CALL CHKOUT( 'STWPM2' )

      RETURN


C$Procedure  STWIN2 ( initialize catalog for writing )

      ENTRY STWIN2

C$ Abstract
C
C     Perform initialization for the catalog writing.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C     None.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is opened for writing at the time
C        when this routine is called, then the error
C        'SPICE(CATALOGISNOTOPENED)' will be signalled.
C
C     2) If this entry is called the second time, then the error
C        'SPICE(ENTRYALREADYCALLED)' will be signalled.
C
C     3) If this entry was called before STWCI2, STWFI2, STWZS2 or
C        STWPM2, then the error 'SPICE(CALLEDOUTOFORDER#)' will be
C        signalled.
C
C     4) If scratch DAS file cannot be opened, the error will be
C        diagnosed by routines called by this routine.
C
C$ Files
C
C     TBD
C
C$ Particulars
C
C     On successful completion of certain checks we find maximum
C     number of elementary zones in declination band, clear
C     parameters and provide setup for the 1st Large Cycle.
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be opened for writing using STWOP2
C     entry of this routine prior to calling this entry.
C
C     The general catalog information must be provided using STWCI2
C     entry of this routine prior to calling this entry.
C
C     The field attribute information must be provided using STWFI2
C     entry of this routine prior to calling this entry.
C
C     The zone size must be provided using STWZS2 entry of this
C     routine prior to calling this entry.
C
C     The PM scale factor must be provided using STWPM2 entry of this
C     routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     complete initialization of type_2 sky_catalog for writing
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWIN2' )
      END IF

C
C     Check whether the catalog is opened for writing.
C
      IF ( .NOT. OPENED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was opened for '    //
     .                 'writing prior to calling this routine.'   )
         CALL SIGERR ( 'SPICE(CATALOGISNOTOPENED)'                )
         CALL CHKOUT ( 'STWIN2'                                   )
         RETURN
      END IF

C
C     Check whether this entry is called after STWCI2.
C
      IF ( .NOT. WCI2FL ) THEN
         CALL SETMSG ( 'This entry cannot be called before '      //
     .                 'STWCI2 has been called.'                  )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER1)'                 )
         CALL CHKOUT ( 'STWIN2'                                   )
         RETURN
      END IF

C
C     Check whether this entry is called after STWFI2.
C
      IF ( .NOT. WFI2FL ) THEN
         CALL SETMSG ( 'This entry cannot be called before '      //
     .                 'STWFI2 has been called.'                  )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER2)'                 )
         CALL CHKOUT ( 'STWIN2'                                   )
         RETURN
      END IF

C
C     Check whether this entry is called after STWPM2.
C
      IF ( .NOT. WPM2FL ) THEN
         CALL SETMSG ( 'This entry cannot be called before '      //
     .                 'STWPM2 has been called.'                  )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER3)'                 )
         CALL CHKOUT ( 'STWIN2'                                   )
         RETURN
      END IF

C
C     Check whether this entry is called after STWZS2. In the future,
C     when we will come up with a way to choose the "best" zone size
C     for any catalog using some heuristics, we will eliminate this
C     error check. In cases when STWZS2 was not called, we will simply
C     come up with the best zone size ourselves. But it's in the
C     future, not now :-).
C
      IF ( .NOT. WZS2FL ) THEN
         CALL SETMSG ( 'This entry cannot be called before '      //
     .                 'STWZS2 has been called.'                  )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER4)'                 )
         CALL CHKOUT ( 'STWIN2'                                   )
         RETURN
      END IF

C
C     Check whether this entry has already been called.
C
      IF ( CYCLE .NE. 0 ) THEN
         CALL SETMSG ( 'This entry has already been called after '//
     .                 'the catalog was opened; it can be '       //
     .                 'called only once.'                        )
         CALL SIGERR ( 'SPICE(ENTRYALREADYCALLED)'                )
         CALL CHKOUT ( 'STWIN2'                                   )
         RETURN
      END IF

C
C     Find maximum number of elementary zones in declination band
C
      NMAXBN = 0
      DO I = 1, NBANDS
         NMAXBN = MAX0 ( NMAXBN, NINBND(I) )
      END DO

C
C     Prepare for the 1st Large Cycle. Clear all buffers.
C
      CALL CLEARI ( NFLMAX, MISS          )
      CALL CLEARI ( NFLMAX, NMFLDS        )
      CALL CLEARI ( NFLMAX, TMFLDS        )
      CALL CLEARI ( NFLMAX, NAFLDS        )
      CALL CLEARI ( NFLMAX, TAFLDS        )
      CALL CLEARI ( NFLMAX, TXTBEG        )
      CALL CLEARI ( NFLMAX, SIZE          )
      CALL CLEARI ( NFLMAX, LSTTAB        )
      CALL CLEARI ( NFLMAX, NNODES        )

      CALL CLEARI ( NZONES, OBJINZ        )

      CALL CLEARI ( NFLMAX, Z             )

C
C     Fill out defaut values.
C
      CALL FILLI  ( -1,      NFLMAX, ACCUR  )
      CALL FILLD  (  1.0D10, NFLMAX, MINVAL )
      CALL FILLD  ( -1.0D10, NFLMAX, MAXVAL )

C
C     Fill out counters.
C
      CALL FILLI  (  0,      NFLMAX, C1VCNT )
      CALL FILLI  (  0,      NFLMAX, C2VCNT )

C
C     Reset sizes and counters.
C
      NNUMM  = 0
      NTXTM  = 0
      NNUMA  = 0
      NTXTA  = 0
      NINDX  = 0
      TXTSIZ = 0

C
C     Reset merged string values buffer.
C
      TEXT = ' '

C
C     Clear up buffers for ZONE numbers and SHFTRAs.
C
      CALL FILLI  ( 0, NOBJ, ARR1 )
      CALL FILLI  ( 0, NOBJ, ARR2 )

C
C     Change CYCLE value to indicate that we are now processing values
C     catalog field value in the firts loop.
C
      CYCLE = 1

C
C     All done. Checking out.
C
      CALL CHKOUT( 'STWIN2' )

      RETURN


C$Procedure STWRD2 ( process RA and DEC of an object )

      ENTRY STWRD2 ( IREC, RA, DEC )

C$ Abstract
C
C     Process position of a catalog object with a given
C     source catalog record number.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               IREC
C     DOUBLE PRECISION      RA
C     DOUBLE PRECISION      DEC
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     IREC       I   Source catalog record number for the object
C     RA         I   Right ascension of the object, radians
C     DEC        I   Declination of the object, radians
C
C$ Detailed_Input
C
C     IREC           is the source catalog record number of the object.
C
C     RA             is the right ascension of the object. RA value
C                    must be specified in radians within 0..2pi.
C                    range.
C
C     DEC            is the declination of the object. DEC value
C                    must be specified in radians within -1/2pi..1/2pi
C                    range.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is opened for writing at the time
C        when this routine is called, then the error
C        'SPICE(CATALOGISNOTOPENED)' will be signalled.
C
C     2) If this entry was called before STWIN2 or after STWFW2, then
C        the error 'SPICE(CALLEDOUTOFORDER)' will be signalled.
C
C     3) If scratch DAS file cannot be opened, the error will be
C        diagnosed by routines called by this routine.
C
C     4) If RA value is not within within 0..2pi radians range, then
C        the error 'SPICE(BADRAVALUE)' will be signalled.
C
C     5) If DEC value is not within within -1/2pi..1/2pi radians
C        range, then the error 'SPICE(BADRAVALUE)' will be signalled.
C
C     6) If IREC is not between 1 and number of objects in the catalog,
C        then the error 'SPICE(BADIRECVALUE)' will be signalled.
C
C     7) If this entry is called in the first cycle more times than
C        the number of objects in the catalog, then the error
C        'SPICE(TOOMANYCYCLE1CALLS)' will be signalled.
C
C     8) If this entry is called in the second cycle more times than
C        the number of objects in the catalog, then the error
C        'SPICE(TOOMANYCYCLE2CALLS)' will be signalled.
C
C     9) If position provided during the second cycle was different
C        from position provided during the first cycle, then the error
C        'SPICE(INCONSISTENTDATA)' will be signalled.
C
C$ Files
C
C     TBD
C
C$ Particulars
C
C     The routine is used at both Large Cycles and works in
C     different ways at the cycles. Each time we compute zone
C     zone number and so-called SHFTRA (that is delta RA
C     with respect to the center of the zone) for the object.
C
C     Then, during the First Large Cycle we increment the number
C     of objects in the elementary zone and buffer the zone # and
C     SHFTRA.
C
C     During the Second Large Cycle we compute additionally
C     delta DEC with respect to the center of the zone and save
C     band, zone and RA and DEC offsets in the VALUE buffer.
C
C     In parallel we perform a lot of boring but necessary checks.
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be opened for writing using STWOP2
C     entry of this routine prior to calling this entry.
C
C     The first or second cycle must be initialized using STWIN2 or
C     STWSW2 entry of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     process type_2 sky_catalog object position for writing
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWRD2' )
      END IF

C
C     Check whether the catalog is opened for writing.
C
      IF ( .NOT. OPENED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was opened for '    //
     .                 'writing prior to calling this routine.'   )
         CALL SIGERR ( 'SPICE(CATALOGISNOTOPENED)'                )
         CALL CHKOUT ( 'STWRD2'                                   )
         RETURN
      END IF

C
C     This routine is called "outside" first and second cycles.
C     If yes, signal an error.
C
      IF ( CYCLE .NE. 1 .AND. CYCLE .NE. 2 ) THEN
         CALL SETMSG ( 'This entry must not be called before '    //
     .                 'the first pass over catalog data (first ' //
     .                 'cycle) initiated by STWIN2 or after '     //
     .                 'completion of the second pass over '      //
     .                 'catalog data (second cycle) closed by '   //
     .                 'STWFW2.'                                  )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER)'                  )
         CALL CHKOUT ( 'STWRD2'                                   )
         RETURN
      END IF

C
C     Check whether IREC is between 1 and NOBJ.
C
      IF ( IREC .LE. 0 .OR. IREC .GT. NOBJ ) THEN
         CALL SETMSG ( 'Source catalog record number must be '    //
     .                 'greater than 0 and less or equal to the ' //
     .                 'number of objects in the catalog, #. '    //
     .                 'It was #.'                                )
         CALL ERRINT ( '#', NOBJ                                  )
         CALL ERRINT ( '#', IREC                                  )
         CALL SIGERR ( 'SPICE(BADIRECVALUE)'                      )
         CALL CHKOUT ( 'STWRD2'                                   )
         RETURN
      END IF

C
C     Check that RA and DEC have values in correct range: 0..360 for
C     RA and -90..90 for DEC.
C
      IF ( RA .LT. 0.0D0 .OR. RA .GT. TWOPI() ) THEN
         CALL SETMSG ( 'Bad RA value # for record #. RA value '   //
     .                 'must be specified in radians within '     //
     .                 '0..2pi range.'                            )
         CALL ERRDP  ( '#', RA                                    )
         CALL ERRINT ( '#', IREC                                  )
         CALL SIGERR ( 'SPICE(BADRAVALUE)'                        )
         CALL CHKOUT ( 'STWRD2'                                   )
         RETURN
      END IF

      IF ( DEC .LT. -HALFPI() .OR. DEC .GT. HALFPI() ) THEN
         CALL SETMSG ( 'Bad DEC value # for record #. DEC value ' //
     .                 'must be specified in radians within '     //
     .                 '-1/2pi..1/2pi range.'                     )
         CALL ERRDP  ( '#', DEC                                   )
         CALL ERRINT ( '#', IREC                                  )
         CALL SIGERR ( 'SPICE(BADDECVALUE)'                       )
         CALL CHKOUT ( 'STWRD2'                                   )
         RETURN
      END IF

C
C     Compute zone number IZONE and SHFTRA for the object
C
      IBAND  = 1 + ( HALFPI() - DEC ) / DELDEC
      INBAND = 1 + RA * NINBND(IBAND) / TWOPI()
      IZONE  = INBAND + NSUM(IBAND)
      DELRA  = TWOPI() / NINBND(IBAND)
      RA0    = DELRA * ( INBAND - 0.5D0 )
      SHFDRA = ( RA - RA0 ) / DELRA * OFFSCL + 0.5D0

C
C     Before we assign DP RA shift value (SHFDRA) to INT RA shift
C     value (SHFTRA) that will be stored in the catalog, we need to
C     verify that we are within INT number boundaries.
C
      IF ( SHFDRA .GE. DBLE( INTMIN() ) .AND.
     .     SHFDRA .LE. DBLE( INTMAX() )       ) THEN
         SHFTRA = SHFDRA
      ELSE
         CALL SETMSG ( 'Encoded value for the RA shift, #, with ' //
     .                 'respect to the center of the zone '       //
     .                 'is outside of integer number range, # .. '//
     .                 '#, on this platform. This indicates a '   //
     .                 'problem in the position encoding design. '//
     .                 'Contact NAIF.'                            )
         CALL ERRDP  ( '#', A                                     )
         CALL ERRINT ( '#', INTMIN()                              )
         CALL ERRINT ( '#', INTMAX()                              )
         CALL SIGERR ( 'SPICE(RAENCODINGOVERFLOW)'                )
         CALL CHKOUT ( 'STWRD2'                                   )
         RETURN
      END IF

      IF      ( CYCLE .EQ. 1 ) THEN

C
C        See if this routine was called too many times in the first
C        cycle. Since we accumulate initial zone distribution data in
C        the buffers, we can only allow it to be called NOBJ times,
C        one time per object.
C
         C1PCNT = C1PCNT + 1

         IF ( C1PCNT .GT. NOBJ ) THEN
            CALL SETMSG ( 'This routine should be called in the '    //
     .                    'first pass over source catalog data '     //
     .                    '(first cycle) only as many times as '     //
     .                    'many objects are in the catalog. '        //
     .                    'It was called # time while the number '   //
     .                    'of objects passed through STWCI2 was '    //
     .                    'only #. Input arguments were: IREC = #, ' //
     .                    'RA = #, DEC = #.'                         )
            CALL ERRINT ( '#', C1PCNT                                )
            CALL ERRINT ( '#', NOBJ                                  )
            CALL ERRINT ( '#', IREC                                  )
            CALL ERRDP  ( '#', RA                                    )
            CALL ERRDP  ( '#', DEC                                   )
            CALL SIGERR ( 'SPICE(TOOMANYCYCLE1CALLS)'                )
            CALL CHKOUT ( 'STWRD2'                                   )
            RETURN
         END IF

C
C        Increment the number of objects in the zone and buffer the
C        zone # and SHFTRA.
C
         OBJINZ(IZONE) = OBJINZ(IZONE) + 1
         ARR1(IREC) = IZONE
         ARR2(IREC) = SHFTRA

      ELSE IF ( CYCLE .EQ. 2 ) THEN

C
C        See if this routine was called too many times in the second
C        cycle. This check is not as important for this cycle as it is
C        for the first one, but we will still do it ... just out of
C        genral paranoia towards possible mis-uses :-)
C
         C2PCNT = C2PCNT + 1

         IF ( C2PCNT .GT. NOBJ ) THEN
            CALL SETMSG ( 'This routine should be called in the '    //
     .                    'second pass over source catalog data '    //
     .                    '(second cycle) only as many times as '    //
     .                    'many objects are in the catalog. '        //
     .                    'It was called # time while the number '   //
     .                    'of objects passed through STWCI2 was '    //
     .                    'only #. Input arguments were: IREC = #, ' //
     .                    'RA = #, DEC = #.'                         )
            CALL ERRINT ( '#', C2PCNT                                )
            CALL ERRINT ( '#', NOBJ                                  )
            CALL ERRINT ( '#', IREC                                  )
            CALL ERRDP  ( '#', RA                                    )
            CALL ERRDP  ( '#', DEC                                   )
            CALL SIGERR ( 'SPICE(TOOMANYCYCLE2CALLS)'                )
            CALL CHKOUT ( 'STWRD2'                                   )
            RETURN
         END IF

C
C        Check SHFTRA stored in the first cycle against the one we
C        computed in this cycle. Complain if they are not the
C        same -- they should be if user passed the same position for this
C        IREC in both cycles! (Of course, user could have screwed up
C        DEC and still get same SHFTRA ... but we don't have a way
C        to check it too.)
C
         IF ( ARR2(ARR1(IREC)) .NE. SHFTRA ) THEN
            CALL SETMSG ( 'Position of the object with original '    //
     .                    'catalog record number # provided during ' //
     .                    'the second pass over source catalog '     //
     .                    'data (second cycle) is different than '   //
     .                    'position provided during the first '      //
     .                    'pass (first cycle.) Values provided '     //
     .                    'during the second pass were: RA = #, '    //
     .                    'DEC = #.'                                 )
            CALL ERRINT ( '#', IREC                                  )
            CALL ERRDP  ( '#', RA                                    )
            CALL ERRDP  ( '#', DEC                                   )
            CALL SIGERR ( 'SPICE(INCONSISTENTDATA)'                  )
            CALL CHKOUT ( 'STWRD2'                                   )
            RETURN
         END IF

C
C        Compute DEC shift and save band, zone and RA and DEC shifts
C        in the VALUE buffer.
C
         DEC0   = HALFPI() - DELDEC * ( IBAND - 0.5D0 )
         SHFDDC = ( DEC - DEC0 ) / DELDEC * OFFSCL + 0.5D0

C
C        Before we assign DP DEC shift value (SHFDDC) to INT DEC shift
C        value (SHFTDC) that will be stored in the catalog, we need to
C        verify that we are within INT number boundaries.
C
         IF ( SHFDDC .GE. DBLE( INTMIN() ) .AND.
     .        SHFDDC .LE. DBLE( INTMAX() )       ) THEN
            SHFTDC = SHFDDC
         ELSE
            CALL SETMSG ( 'Encoded value for the DEC shift, #, with '//
     .                    'respect to the center of the zone '       //
     .                    'is outside of integer number range, # .. '//
     .                    '#, on this platform. This indicates a '   //
     .                    'problem in the position encoding design. '//
     .                    'Contact NAIF.'                            )
            CALL ERRDP  ( '#', A                                     )
            CALL ERRINT ( '#', INTMIN()                              )
            CALL ERRINT ( '#', INTMAX()                              )
            CALL SIGERR ( 'SPICE(DCENCODINGOVERFLOW)'                )
            CALL CHKOUT ( 'STWRD2'                                   )
            RETURN
         END IF

C
C        Buffer computed position data.
C
         VALUE(2) = IBAND  - MINVAL(2) - MAXABS(2)
         VALUE(3) = INBAND - MINVAL(3) - MAXABS(3)
         VALUE(4) = SHFTRA
         VALUE(5) = SHFTDC

C
C        We also memorize IREC for each of the VALUE elements which
C        we just assigned. We will use it to check consistenly of the
C        elements in VALUE in STWRC2.
C
         CALL FILLI ( IREC, 4, VLIREC(2) )

      ELSE

C
C        We cannot possibly get here becasue upon the entry to
C        have checked that we are in cycle 1 or 2. But just in case
C        we will signal an error.
C
         CALL SETMSG ( 'Cycle index was #. This is STWRD2 bug. '  //
     .                 'Contact NAIF.'                            )
         CALL ERRINT ( '#', CYCLE                                 )
         CALL SIGERR ( 'SPICE(STWRD2BUG1)'                        )
         CALL CHKOUT ( 'STWRD2'                                   )
         RETURN

      END IF

C
C     All done. Checking out.
C
      CALL CHKOUT( 'STWRD2' )

      RETURN


C$Procedure STWPF2 ( process character substring for given field )

      ENTRY STWPF2 ( IREC, FLDNO, STRING )

C$ Abstract
C
C     Process a string that contains value of a specified field of
C     of a catalog object with a given source catalog record number.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               IREC
C     INTEGER               FLDNO
C     CHARACTER*(*)         STRING
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     IREC       I   Source catalog record number for the object
C     FLDNO      I   Field number
C     STRING     I   String containing field value
C
C$ Detailed_Input
C
C     IREC           is the source catalog record number of the object.
C
C     FLDNO          is the index of the field in the catalog
C                    record.
C
C     STRING         is the character string containing field value.
C                    For character fields this value will be
C                    left-justified and stripped off non-printing
C                    characters before it is written to the catalog
C                    file.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is opened for writing at the time
C        when this routine is called, then the error
C        'SPICE(CATALOGISNOTOPENED)' will be signalled.
C
C     2) If this entry was called before STWIN2 orafter STWFW2, then
C        the error 'SPICE(CALLEDOUTOFORDER)' will be signalled.
C
C     3) If IREC is not between 1 and number of objects in the catalog,
C        then the error 'SPICE(BADIRECVALUE)' will be signalled.
C
C     4) If FLDNO is not between 1 and the number of fields in a record,
C        then the error 'SPICE(BADFLDNOVALUE)' will be signalled.
C
C     5) If this entry is called for a given field in the first cycle
C        more times than the number of objects in the catalog, then
C        the error 'SPICE(TOOMANYCYCLE1CALLS)' will be signalled.
C
C     6) If this entry is called for a given field in the second cycle
C        more times than the number of objects in the catalog, then
C        the error 'SPICE(TOOMANYCYCLE2CALLS)' will be signalled.
C
C     7) If a value of integer field cannot be parsed as integer
C        during the first cycle, then the error
C        'SPICE(BADINTVALUECYCLE1)' will be signalled.
C
C     8) If a value of DP field cannot be parsed as DP
C        during the first cycle, then the error
C        'SPICE(BADDPVALUECYCLE1)' will be signalled.
C
C     9) If a value of integer field cannot be parsed as integer
C        during the second cycle, then the error
C        'SPICE(BADINTVALUECYCLE2)' will be signalled.
C
C     10)If a value of DP field cannot be parsed as DP
C        during the second cycle, then the error
C        'SPICE(BADDPVALUECYCLE2)' will be signalled.
C
C     11)If a value of DP field provided during the second cycle
C        is outside of the field range determined during the
C        first cycle, then the error 'SPICE(INCOSISTENTDPVALUE)'
C        will be signalled.
C
C     12)If a value of CHAR field provided during the second cycle
C        is longer than the maximum length determined during the
C        first cycle, then the error 'SPICE(INCOSISTENTCHVALUE)'
C        will be signalled.
C
C$ Files
C
C     None.
C
C$ Particulars
C
C     TBD
C
C     Attention! FLDNO is field number by PRELIMINARY fields list
C     rather than final, i.e. according to FLNAM list loaded at
C     the very beginning of the catalog writing procedure!
C
C     The routine is used at both Large Cycles and works at the
C     cycles in different ways.
C
C     During the First Large Cycle we compute so-called "statistics".
C     First, we count the number of missing data for each field.
C     Then, for each field of CHARACTER type we find out three things:
C        - maximum value length,
C        - common prefix,
C        - index of the first non-common character.
C     For each numerical fields we find range and presentation format:
C        - minimum field value,
C        - maximum field value,
C        - field accuracy (number of digits after decimal point).
C
C     During the Second Large Cycle we convert each substring to
C     accepted form and write it to a proper place for future
C     packing and writing to the catalog DAS file. At that each
C     text field is inserted into big string that contains all
C     character field values for this record. Then, each numerical
C     parameter is converted to integer presentation and stored
C     in corresponding element of VALUE array.
C
C     In parallel we perform a lot of boring but necessary checks.
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be opened for writing using STWOP2
C     entry of this routine prior to calling this entry.
C
C     The first or second cycle must be initialized using STWIN2 or
C     STWSW2 entry of this routine prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     process type_2 sky_catalog object field value for writing
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWPF2' )
      END IF

C
C     Check whether the catalog is opened for writing.
C
      IF ( .NOT. OPENED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was opened for '    //
     .                 'writing prior to calling this routine.'   )
         CALL SIGERR ( 'SPICE(CATALOGISNOTOPENED)'                )
         CALL CHKOUT ( 'STWPF2'                                   )
         RETURN
      END IF

C
C     This routine is called "outside" first and second cycles.
C     If yes, signal an error.
C
      IF ( CYCLE .NE. 1 .AND. CYCLE .NE. 2 ) THEN
         CALL SETMSG ( 'This entry must not be called before '    //
     .                 'the first pass over catalog data (first ' //
     .                 'cycle) initiated by STWIN2 or after '     //
     .                 'completion of the second pass over '      //
     .                 'catalog data (second cycle) closed by '   //
     .                 'STWFW2.'                                  )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER)'                  )
         CALL CHKOUT ( 'STWPF2'                                   )
         RETURN
      END IF

C
C     Check whether IREC is between 1 and NOBJ.
C
      IF ( IREC .LE. 0 .OR. IREC .GT. NOBJ ) THEN
         CALL SETMSG ( 'Source catalog record number must be '    //
     .                 'greater than 0 and less or equal to the ' //
     .                 'number of objects in the catalog, #. '    //
     .                 'It was #.'                                )
         CALL ERRINT ( '#', NOBJ                                  )
         CALL ERRINT ( '#', IREC                                  )
         CALL SIGERR ( 'SPICE(BADIRECVALUE)'                      )
         CALL CHKOUT ( 'STWPF2'                                   )
         RETURN
      END IF

C
C     Check whether FLDNO is between 1 and NFLDS.
C
      IF ( FLDNO .LE. 0 .OR. FLDNO .GT. NFLDS ) THEN
         CALL SETMSG ( 'Record field number must be '             //
     .                 'greater than 0 and less or equal to the ' //
     .                 'number of field in a record, #. '         //
     .                 'It was #.'                                )
         CALL ERRINT ( '#', NFLDS                                 )
         CALL ERRINT ( '#', FLDNO                                 )
         CALL SIGERR ( 'SPICE(BADNFLDVALUE)'                      )
         CALL CHKOUT ( 'STWPF2'                                   )
         RETURN
      END IF

      IF ( CYCLE .EQ. 1 ) THEN

C
C        "Comb" the input string -- remove non-printing characters,
C        left-justify and uppercase for the first cycle processing.
C
         CALL STCMB2 ( .TRUE., STRING, TXT )

C
C        See if this routine was called for this field too many
C        times in the first cycle. The maximum number of times it
C        should be called for this field is equal to the number
C        of objects.
C
         C1VCNT ( FLDNO ) = C1VCNT ( FLDNO ) + 1

         IF ( C1VCNT ( FLDNO ) .GT. NOBJ ) THEN
            CALL SETMSG ( 'This routine should be called for the '   //
     .                    'field number # in the '                   //
     .                    'first pass over source catalog data '     //
     .                    '(first cycle) only as many times as '     //
     .                    'many objects are in the catalog. '        //
     .                    'It was called # time while the number '   //
     .                    'of objects passed through STWCI2 was '    //
     .                    'only #. Input arguments were: IREC = #, ' //
     .                    'FLDNO = #, STRING = #.'                   )
            CALL ERRINT ( '#', FLDNO                                 )
            CALL ERRINT ( '#', C1VCNT ( FLDNO )                      )
            CALL ERRINT ( '#', NOBJ                                  )
            CALL ERRINT ( '#', IREC                                  )
            CALL ERRINT ( '#', FLDNO                                 )
            CALL ERRCH  ( '#', STRING                                )
            CALL SIGERR ( 'SPICE(TOOMANYCYCLE1CALLS)'                )
            CALL CHKOUT ( 'STWPF2'                                   )
            RETURN
         END IF

C
C        Is our value blank?
C
         IF ( TXT .EQ. ' ' ) THEN

C
C           Yes, and this means that we deal with missing data.
C           Increase the missing data count for this field.
C
            MISS(FLDNO) = MISS(FLDNO) + 1

         ELSE

C
C           The value is not blank. Depending on the type of the field
C           we will collect different statistics.
C
            IF ( FLTYPE(FLDNO) .EQ. 0 ) THEN

C
C              The parameter is of CHARACTER type. For fields of this
C              type we need to find out three things:
C
C                 -- maximum value length;
C                 -- common prefix;
C                 -- index of the first non-common character;
C
C              First, check the value length against current maximum
C              field size and update the size if it's greater.
C
               SIZE (FLDNO) = MAX( SIZE(FLDNO), NBLEN(TXT) )

C
C              Then, let's determine common prefix for this field and
C              index of the first non-common character. For example,
C              if in the catalog we deal with a field has values
C              like  this
C
C                               XXXXX00001,
C                               XXXXX00002,
C                               ..........,
C                               XXXXX12345
C
C              then the commn prefix is XXXXX and index of the first
C              non-common character is in the 6th position.
C
C              If this is the first time when this entry is called
C              for this field in the first cycle?
C
               IF ( C1VCNT ( FLDNO ) .EQ. 1 ) THEN

C
C                 Yes, initialize prefix and index using current
C                 field value.
C
                  FLDPRF(FLDNO) = TXT
                  FLDBPS(FLDNO) = TFVMAX + 1

               ELSE

C
C                 This is not the first value we are going to examine.
C                 But we will look for common character only if we
C                 detected common part in the field values that we have
C                 examined earlier.
C
                  IF ( FLDBPS(FLDNO) .GT. 1 ) THEN

C
C                    Find first non-common character and save its
C                    index. (SAMCHI is case insensitive.)
C
                     J1 = 1
                     DO WHILE ( SAMCHI( FLDPRF(FLDNO), J1, TXT, J1 ) )
                        J1 = J1 + 1
                     END DO

                     FLDBPS(FLDNO) = MIN0 ( FLDBPS(FLDNO), J1 )

C
C                    If it turns out that our field doesn't have common
C                    prefix, reset the prefix value.
C
                     IF ( FLDBPS(FLDNO) .EQ. 1 ) THEN
                        FLDPRF(FLDNO) = ' '
                     END IF

                  END IF

               END IF

            ELSE

C
C              This field is not a character field. For numeric fields
C              we need to determine:
C
C                 -- minimum field value;
C                 -- maximum field value;
C                 -- field accuracy (number of digits after decimal
C                    point);
C
C              Depending on whether the field is integer or DP we do
C              parsing differently.
C
               IF ( FLTYPE(FLDNO) .EQ. 1 ) THEN

C
C                 The parameter is of INTEGER type; try to parse value
C                 as INTEGER.
C
                  CALL NPARSI ( TXT, I, ERROR, J )

                  IF ( J .NE. 0 ) THEN
                     CALL SETMSG ( 'Value of the field number # ' //
     .                             'is the record number # was '  //
     .                             'was not an integer number, '  //
     .                             'although the field was '      //
     .                             'specified to be of integer '  //
     .                             'type. The value was ''#''. '  //
     .                             '''Combed'' value was ''#''. ' //
     .                             'Parsing error was: #.'        )
                     CALL ERRINT ( '#', FLDNO                     )
                     CALL ERRINT ( '#', IREC                      )
                     CALL ERRCH  ( '#', STRING                    )
                     CALL ERRCH  ( '#', TXT                       )
                     CALL ERRCH  ( '#', ERROR                     )
                     CALL SIGERR ( 'SPICE(BADINTVALUECYCLE1)'     )
                     CALL CHKOUT ( 'STWPF2'                       )
                     RETURN
                  END IF

                  A = I

               ELSE IF ( FLTYPE(FLDNO) .EQ. 2 ) THEN

C
C                 The parameter is of DOUBLE PRECISION type; try to
C                 parse as DP.
C
                  CALL NPARSD ( TXT, A, ERROR, J )

                  IF ( J .NE. 0 ) THEN
                     CALL SETMSG ( 'Value of the field number # ' //
     .                             'is the record number # was '  //
     .                             'was not an DP number, '       //
     .                             'although the field was '      //
     .                             'specified to be of DP '       //
     .                             'type. The value was ''#''. '  //
     .                             '''Combed'' value was ''#''. ' //
     .                             'Parsing error was: #.'        )
                     CALL ERRINT ( '#', FLDNO                     )
                     CALL ERRINT ( '#', IREC                      )
                     CALL ERRCH  ( '#', STRING                    )
                     CALL ERRCH  ( '#', TXT                       )
                     CALL ERRCH  ( '#', ERROR                     )
                     CALL SIGERR ( 'SPICE(BADDPVALUECYCLE1)'      )
                     CALL CHKOUT ( 'STWPF2'                       )
                     RETURN
                  END IF

               END IF

               MINVAL(FLDNO) = DMIN1(MINVAL(FLDNO), A )
               MAXVAL(FLDNO) = DMAX1(MAXVAL(FLDNO), A )
               ACCUR(FLDNO)  = MAX0(ACCUR(FLDNO), STDIG2(A))

            END IF

         END IF

      ELSE IF ( CYCLE .EQ. 2 ) THEN

C
C        "Comb" the input string -- remove non-printing characters,
C        left-justify and BUT NOT uppercase because we need to
C        preserve case of the values that we store in the catalog.
C
         CALL STCMB2 ( .FALSE., STRING, TXT )

C
C        See if this routine was called for this field too many
C        times in the first cycle. The maximum number of times it
C        should be called for this field is equal to the number
C        of objects.
C
         C2VCNT ( FLDNO ) = C2VCNT ( FLDNO ) + 1

         IF ( C2VCNT ( FLDNO ) .GT. NOBJ ) THEN
            CALL SETMSG ( 'This routine should be called for the '   //
     .                    'field number # in the '                   //
     .                    'second pass over source catalog data '    //
     .                    '(second cycle) only as many times as '    //
     .                    'many objects are in the catalog. '        //
     .                    'It was called # time while the number '   //
     .                    'of objects passed through STWCI2 was '    //
     .                    'only #. Input arguments were: IREC = #, ' //
     .                    'FLDNO = #, STRING = #.'                   )
            CALL ERRINT ( '#', FLDNO                                 )
            CALL ERRINT ( '#', C2VCNT ( FLDNO )                      )
            CALL ERRINT ( '#', NOBJ                                  )
            CALL ERRINT ( '#', IREC                                  )
            CALL ERRINT ( '#', FLDNO                                 )
            CALL ERRCH  ( '#', STRING                                )
            CALL SIGERR ( 'SPICE(TOOMANYCYCLE2CALLS)'                )
            CALL CHKOUT ( 'STWPF2'                                   )
            RETURN
         END IF

C
C        Determine "final" field number according to our numeration:
C        using the RANK and ORDER vectors we can easily make a
C        correspondence between "Final field #" and "Initial field #":
C
C           "Final field #"   =  RANK  ( Initial field # )
C           "Initial field #" =  ORDER ( Final field #   )
C
         I = RANK ( FLDNO )

C
C        As in the first cycle we do different processing for strings
C        numbers.
C
         IF ( FLTYPE(I) .EQ. 0 ) THEN

C
C           The parameter is of CHARACTER type. First check whether
C           the value length is less of equal to the maxumum length for
C           the field.
C
            K = NBLEN(TXT)
            IF ( K .GT. -MAXABS(I) ) THEN
               CALL SETMSG ( 'Value ''#'' of the field number # '//
     .                       'of the record number # specified ' //
     .                       'during the second cycle is '       //
     .                       'longer than the maximum field '    //
     .                       'value length # determined during ' //
     .                       'the first cycle.'                  )
               CALL ERRCH  ( '#', STRING                         )
               CALL ERRINT ( '#', FLDNO                          )
               CALL ERRINT ( '#', IREC                           )
               CALL ERRINT ( '#', -MAXABS(I)                     )
               CALL SIGERR ( 'SPICE(INCOSISTENTCHVALUE)'         )
               CALL CHKOUT ( 'STWPF2'                            )
               RETURN
            END IF

C
C           Determine position of the our value in big concatenated
C           string containing all character field values for this record.
C
            I1 = TXTBEG(I)
            I2 = I1 - MAXABS(I) - 1

C
C           If value is not blank (i.e. not NULL), insert it into the
C           string. Otherwise, fill the slot with blanks.
C
            IF ( K .GT. 0 ) THEN
               TEXT(I1:I2) = TXT(1:K)
            ELSE
               TEXT(I1:I2) = ' '
            END IF

         ELSE

C
C           The field is numeric field. Check whether current value is
C           NULL (i.e. blank string.)
C
            IF ( TXT .EQ. ' ' ) THEN

C
C              Set value to be MAXABS, the NULL value per catalog
C              design.
C
               VALUE(I) = MAXABS(I)

            ELSE

C
C              Current value is not null. Parse it depending on
C              it's type.
C
               IF ( FLTYPE(I) .EQ. 1 ) THEN

C
C                 The parameter is of INTEGER type; parse as INT
C                 number.
C
                  CALL NPARSI ( TXT, K, ERROR, J )

                  IF ( J .NE. 0 ) THEN
                     CALL SETMSG ( 'Value of the field number # ' //
     .                             'is the record number # was '  //
     .                             'was not an integer number, '  //
     .                             'although the field was '      //
     .                             'specified to be of integer '  //
     .                             'type. The value was ''#''. '  //
     .                             '''Combed'' value was ''#''. ' //
     .                             'Parsing error was: #.'        )
                     CALL ERRINT ( '#', FLDNO                     )
                     CALL ERRINT ( '#', IREC                      )
                     CALL ERRCH  ( '#', STRING                    )
                     CALL ERRCH  ( '#', TXT                       )
                     CALL ERRCH  ( '#', ERROR                     )
                     CALL SIGERR ( 'SPICE(BADINTVALUECYCLE2)'     )
                     CALL CHKOUT ( 'STWPF2'                       )
                     RETURN
                  END IF

                  A = K

               ELSE IF ( FLTYPE(I) .EQ. 2 ) THEN

C
C                 The parameter is of DOUBLE PRECISION type; parse as
C                 DP number.
C
                  CALL NPARSD ( TXT, A, ERROR, J )

                  IF ( J .NE. 0 ) THEN
                     CALL SETMSG ( 'Value of the field number # ' //
     .                             'is the record number # was '  //
     .                             'was not an DP number, '       //
     .                             'although the field was '      //
     .                             'specified to be of DP '       //
     .                             'type. The value was ''#''. '  //
     .                             '''Combed'' value was ''#''. ' //
     .                             'Parsing error was: #.'        )
                     CALL ERRINT ( '#', FLDNO                     )
                     CALL ERRINT ( '#', IREC                      )
                     CALL ERRCH  ( '#', STRING                    )
                     CALL ERRCH  ( '#', TXT                       )
                     CALL ERRCH  ( '#', ERROR                     )
                     CALL SIGERR ( 'SPICE(BADDPVALUECYCLE2)'      )
                     CALL CHKOUT ( 'STWPF2'                       )
                     RETURN

                   END IF

               END IF

C
C              Check to see whether the value is within the range
C              that we have determined for this field during the
C              first cycle.
C
               IF ( A .LT. MINVAL(I) .OR. A .GT. MAXVAL(I) ) THEN
                  CALL SETMSG ( 'Value # of the field number # '    //
     .                          'of the record number # specified ' //
     .                          'during the second cycle is '       //
     .                          'outside of the field range [#,#] ' //
     .                          'determined during the first '      //
     .                          'cycle.'                            )
                  CALL ERRDP  ( '#', A                              )
                  CALL ERRINT ( '#', FLDNO                          )
                  CALL ERRINT ( '#', IREC                           )
                  CALL ERRDP  ( '#', MINVAL(I)                      )
                  CALL ERRDP  ( '#', MAXVAL(I)                      )
                  CALL SIGERR ( 'SPICE(INCOSISTENTDPVALUE)'         )
                  CALL CHKOUT ( 'STWPF2'                            )
                  RETURN
               END IF

C
C              Fill corresponding VALUE element
C
               I1 = (A-MINVAL(I)) * 10**ACCUR(I) + .5D0
               VALUE(I) = I1 - MAXABS(I)

            END IF

         END IF

C
C        Memorize IREC for this VALUE element. It will be used
C        for data consistency check in STWRC2.
C
         VLIREC(I) = IREC

      ELSE

C
C        We cannot possibly get here becasue upon the entry we
C        have checked that we are in cycle 1 or 2. But just in case
C        we will signal an error.
C
         CALL SETMSG ( 'Cycle index was #. This is STWPF2 bug. '  //
     .                 'Contact NAIF.'                            )
         CALL ERRINT ( '#', CYCLE                                 )
         CALL SIGERR ( 'SPICE(STWPF2BUG1)'                        )
         CALL CHKOUT ( 'STWPF2'                                   )
         RETURN

      END IF

      CALL CHKOUT ( 'STWPF2' )

      RETURN


C$Procedure STWSW2 ( start the catalog writing )

      ENTRY STWSW2

C$ Abstract
C
C     Process the results of the first cycle, determine packing
C     structure and other field value related metainformation and
C     write it to the METAINFORMATION segment of the catalog, and
C     perform all necessary preparation for and start the second
C     cycle.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     None.
C
C$ Brief_I/O
C
C     None.
C
C$ Detailed_Input
C
C     None.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is opened for writing at the time
C        when this routine is called, then the error
C        'SPICE(CATALOGISNOTOPENED)' will be signalled.
C
C     2) If this entry was called before STWIN2 or after the second
C        cycle has started, then the error 'SPICE(CALLEDOUTOFORDER)'
C        will be signalled.
C
C     3) If STWRD2 has not been called exactly NOBJ times during
C        the first cycle before calling this entry, then the error
C        'SPICE(PARTIALCYCLE1RD)' will be signalled.
C
C     4) If STWPF2 has not been called exactly NOBJ times for each
C        catalog field during the first cycle before calling this entry,
C        then the error 'SPICE(PARTIALCYCLE1VAL)' will be signalled.
C
C     5) If position of any object has not been provided in the first
C        cycle, then the error 'SPICE(INCOMPLETEDATA)' will be signalled.
C
C     6) If all values of one of the fields are NULLs, then the error
C        'SPICE(NULLSONLYFIELD)' will be signalled.
C
C     7) If value of a text field was identical for all catalog objects
C        and the field was to be indexed, then the error
C        'SPICE(TFLDCANTBEINDEXED)' will be signalled.
C
C     8) If value of a numeric field was identical for all catalog
C        objects and the field was to be indexed, then the error
C        'SPICE(NFLDCANTBEINDEXED)' will be signalled.
C
C$ Files
C
C     TBD
C
C     Need brief reference of output and scratch file used by routine.
C
C$ Particulars
C
C
C     The main goal of the routine is to generate the
C     METAINFORMATION segment of the catalog.
C
C     The routine starts with geometry organization issues.
C
C     Remind that during the first cycle ZONE numbers and SHFTRAs
C     for all objects were buffered during in ARR1 and ARR2 arrays.
C
C     We generate integer array INPOS and write it to the
C     METAINFORMATION segment. Remind that INPOS is an
C     integer array of NZONES elements where k-th element
C     is record number for the first sky object in k-th
C     elementary zone on the celestial sphere.
C
C     Next efforts are devoted to generate list of integer numbers
C     maps consequent OTC record numbers to final SPICE catalog
C     record numbers, i.e. to provide required geometrical
C     organization of the catalog data.
C     To this end we process ARR1 amd ARR2 arrays containing ZONE
C     numbers and SHFTRAs and finally obtain rank vector specifing
C     to which location in the SPICE catalog every record from the
C     original catalog should be stored.
C
C     Further, augment the fields list with 4 additional fields:
C       - declination band number
C       - elementary zone number within the declination band
C       - RA
C       - DEC
C     and fill associated arrays descripting the fields features.
C
C     Then make a solution how to divide fields to MAIN and AUX
C     parts according to the following approach.
C
C     Numerical field is considered as AUX if:
C        -  it is not INTENSITY
C        -  MISS / NOBJ * 100% > C1
C
C     Text field is considered as AUX if:
C        -  it is not ID
C        -  MISS / NOBJ * 100% > min ( C1, C2 / SIZE ),
C
C     where
C
C     - MISS is number of missing data for the field,
C     - SIZE is maximal size of the field ( for text fields only),
C     - C1 and C2 are pre-defined constants. Evidently, C1 is
C       critical percentage of missing data whereas C2 allow us to
C       move the field to AUX part even if missing data volume is not
C       so large but the field size is pretty large.
C
C     Next step is rearrangement of all the fields according to
C     accepted order: the first field numbers are
C
C     1 - object ID
C     2 - declination band number
C     3 - elementary zone number within the declination band
C     4 - RA
C     5 - DEC
C
C     and then the following fields (if exist):
C
C     PMRA
C     PMDEC
C     PRLX
C     RAD_VEL
C     INTENSITY
C
C     Then, all AUX fields are to be located at the very end of
C     the fields list.
C
C     After completion of the ORDER vector generation we reorder
C     all associated arrays and write down all the information
C     obtained to the METAINFORMATION segment.
C
C     Next step is to determine packing attributes of the MAIN
C     and AUX part of the record:
C
C     - the number of numerical and text MAIN fields,
C     - the number of numerical and text AUX fields,
C     - arrays of numerical and text MAIN fields numbers,
C     - arrays of numerical and text AUX fields numbers,
C     - maximal absolute values for numerical fields integer
C       presentation,
C     - size of the MAIN part of the record and numerical and
C       character portions of it;
C     - MAIN part field packing density;
C
C     Also, if dynamic range of a numerical field is too wide, we
C     modify ACCUR and MINVAL arrays to make sure it can fit into
C     the catalog packing schema.
C
C     After we are through with it (and endless boring/necessary
C     checks :) we write all collected data into the METAINFORMATION
C     segment.
C
C     To finish METAINFORMATION segment we store field descriptions
C     and close scratch DAS file containing them.
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be opened for writing using STWOP2
C     entry of this routine prior to calling this entry.
C
C     Positional and other field data must be provided for all objetcs
C     from the source catalog during first cycle prior to calling
C     this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     start type_2 sky_catalog writing
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWSW2' )
      END IF

C
C     Check whether the catalog is opened for writing.
C
      IF ( .NOT. OPENED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was opened for '    //
     .                 'writing prior to calling this routine.'   )
         CALL SIGERR ( 'SPICE(CATALOGISNOTOPENED)'                )
         CALL CHKOUT ( 'STWSW2'                                   )
         RETURN
      END IF

C
C     Check whether we are in the first cycle.
C
      IF ( CYCLE .NE. 1 ) THEN
         CALL SETMSG ( 'This entry should only be called after '  //
     .                 'the end of the first data processing '    //
     .                 'cycle initiated by a call to STWIN2. '    //
     .                 'It was called during cycle number #. '    )
         CALL ERRINT ( '#', CYCLE                                 )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER1)'                 )
         CALL CHKOUT ( 'STWSW2'                                   )
         RETURN
      END IF

C
C     Before anything, sanity check to verify that STWRD2 was called
C     exactly NOBJ times before calling this entry.
C
      IF ( C1PCNT .NE. NOBJ ) THEN
         CALL SETMSG ( 'Entry STWRD2 must have been called '      //
     .                 'exactly # times (the number of objects '  //
     .                 'in the catalog) before calling this '     //
     .                 'entry. It was called only # times.'       )
         CALL ERRINT ( '#', NOBJ                                  )
         CALL ERRINT ( '#', C1PCNT                                )
         CALL SIGERR ( 'SPICE(PARTIALCYCLE1RD)'                   )
         CALL CHKOUT ( 'STWSW2'                                   )
         RETURN
      END IF

C
C     Another sanity check to verify that STWPF2 was called
C     exactly NOBJ times for each field before calling this entry.
C
      DO I = 1, NFLDS
         IF ( C1VCNT(I) .NE. NOBJ ) THEN
            CALL SETMSG ( 'Entry STWPF2 must have been called '      //
     .                    'exactly # times (the number of objects '  //
     .                    'in the catalog) for the field number # '  //
     .                    'before calling this '                     //
     .                    'entry. It was called only # times.'       )
            CALL ERRINT ( '#', NOBJ                                  )
            CALL ERRINT ( '#', I                                     )
            CALL ERRINT ( '#', C1VCNT(I)                             )
            CALL SIGERR ( 'SPICE(PARTIALCYCLE1VAL)'                  )
            CALL CHKOUT ( 'STWSW2'                                   )
            RETURN
         END IF
      END DO

C
C     And yet one more sanity check to verify that we don't have any
C     fields containing only NULLS.
C
      DO I = 1, NFLDS
         IF ( MISS(I) .GE. NOBJ ) THEN
            CALL SETMSG ( 'It appers that all values of the field ' //
     .                    'number # are NULLs. Fields with only '   //
     .                    'NULL values don''t make sense.'           )
            CALL ERRINT ( '#', I                                     )
            CALL SIGERR ( 'SPICE(NULLSONLYFIELD)'                    )
            CALL CHKOUT ( 'STWSW2'                                   )
            RETURN
         END IF
      END DO

C
C     And another one ... to verify that we don't have any fields that
C     have to be indexed but contain the same value for all objects.
C
      DO I = 1, NFLDS
         IF ( FLTYPE(I) .EQ. 0 ) THEN
            IF ( FLDBPS(I) .GT. SIZE(I) .AND.
     .           FLDIND(I) .EQ. 1              ) THEN
               CALL SETMSG ( 'Value of the field number # was '      //
     .                       'identical and equal to ''#'' to all '  //
     .                       'catalog objects. Such fields cannot '  //
     .                       'be indexed.'                           )
               CALL ERRINT ( '#', I                                  )
               CALL ERRCH  ( '#', FLDPRF(I)                          )
               CALL SIGERR ( 'SPICE(TFLDCANTBEINDEXED)'              )
               CALL CHKOUT ( 'STWSW2'                                )
               RETURN
            END IF
         ELSE
            IF ( MAXVAL(I) .EQ. MINVAL(I) .AND.
     .           FLDIND(I) .EQ. 1              ) THEN
               CALL SETMSG ( 'Value of the field number # was '      //
     .                       'identical and equal to # to for all '  //
     .                       'catalog objects. Such fields cannot '  //
     .                       'be indexed.'                           )
               CALL ERRINT ( '#', I                                  )
               CALL ERRDP  ( '#', MAXVAL(I)                          )
               CALL SIGERR ( 'SPICE(NFLDCANTBEINDEXED)'              )
               CALL CHKOUT ( 'STWSW2'                                )
               RETURN
            END IF
         END IF
      END DO

C
C     Check ZONE numbers accumulated in the buffers.
C
      DO I = 1, NOBJ

C
C        I is record #, ARR1(I) is zone #, ARR2(I) is SHFTRA. If RA/DEC
C        was not provided via STWRD2 for any of the source records,
C        then IZONE will be zero (remember that we filled ARR1
C        with zeros in STWIN2.) So, if IZONE is zero, we complain
C        saying that position for source catalog record I was not
C        provided. If it's greater that NZONES or less than zero ... we
C        complain that it's a bug because this should never have
C        happened ...
C
         IF ( ARR1(I) .EQ. 0 ) THEN
            CALL SETMSG ( 'Position of the object with source '      //
     .                    'catalog record number # has not been '    //
     .                    'provided in the first pass over the '     //
     .                    'catalog data.'                            )
            CALL ERRINT ( '#', I                                     )
            CALL SIGERR ( 'SPICE(INCOMPLETEDATA)'                    )
            CALL CHKOUT ( 'STWSW2'                                   )
            RETURN
         END IF

         IF ( ARR1(I) .LT. 0 .OR. ARR1(I) .GT. NZONES ) THEN
            CALL SETMSG ( 'Zone index, #, for the object with '      //
     .                    'source catalog record number # is less '  //
     .                    'than zero or greater than the number of ' //
     .                    'of zones #. This indicates serious '      //
     .                    'problem in catalog writer library. '      //
     .                    'Please, contact NAIF.'                    )
            CALL ERRINT ( '#', ARR1(I)                               )
            CALL ERRINT ( '#', I                                     )
            CALL ERRINT ( '#', NZONES                                )
            CALL SIGERR ( 'SPICE(STWSW2BUG1)'                        )
            CALL CHKOUT ( 'STWSW2'                                   )
            RETURN
         END IF

      END DO

C
C     Step 1: compute record order for our geometric organization
C             using information collected during the first cycle;
C
C     Generate integer array INPOS containing index of the first
C     object in each elementary zone and write it to the
C     METAINFORMATION segment.
C
      INPOS(1) = 1
      DO I = 2, NZONES
         INPOS(I) = INPOS(I-1) + OBJINZ(I-1)
      END DO
      CALL STAIT2 ( HANDLE, MDIPOS, NZONES, INPOS )

C
C     We have already checked buffered geometry information and can
C     generate geometric index. First thing that we need to do is to
C     find order of records sorted by zone number. Zones numbers are
C     buffered in ARR1 and we will use ARR3 to store the order
C     vector.
C
      CALL ORDERI ( ARR1, NOBJ, ARR3 )

C
C     Now ARR3 contain order of records by as if they would be sorted
C     by zone number. We use it to re-order records in the ARR2 buffer
C     that holds SHFTRAs.
C
      CALL REORDI ( ARR3, NOBJ, ARR2 )

C
C     We have done the first part of our sorting -- both record numbers
C     (ARR3) and SHFTRAs (ARR2) are "sorted" by zone number. We don't
C     need zone numbers stored in ARR1 anymore. So, we will use ARR1 to
C     hold the order vector while re-ordering portions of the ARR3 by
C     SHFTRA.
C
      DO IZONE = 1, NZONES

C
C        Check number of objects in current zone, and, if it's not zero,
C        go ahead and re-order this zone portion of ARR3 by SHFTRA.
C
         IF ( OBJINZ(IZONE) .NE. 0 ) THEN

C
C           Get order of current zone portion by increasing SHFTRA.
C
            CALL ORDERI ( ARR2(INPOS(IZONE)), OBJINZ(IZONE), ARR1 )

C
C           Re-order SHFTRAs (ARR2) and original record numbers (ARR3)
C           within this zone portion.
C
            CALL REORDI ( ARR1, OBJINZ(IZONE), ARR2(INPOS(IZONE)) )
            CALL REORDI ( ARR1, OBJINZ(IZONE), ARR3(INPOS(IZONE)) )

         END IF

      END DO

C
C     Now let us generate "rank" vector, ARR1, for original catalog
C     records from the "order" vector stored in the ARR3.
C
      DO I = 1, NOBJ
         ARR1(ARR3(I)) = I
      END DO

C
C     So, now ARR1 buffer contains rank vector specifing to which
C     location in the SPICE catalog every record from the original
C     catalog should be stored, while ARR2 contains SHFTRAs in the
C     order in which they will be in the output catalog (we will use
C     ARR2 elements to verify consistency in position data between
C     first and second cycles.)
C

C
C     Step 2: augment the fields list with 4 additional positional
C             information fields:
C
C       - declination band number
C       - elementary zone number within the declination band
C       - RA
C       - DEC
C
C     and fill associated arrays containing field name, class and type.
C
      J = NFLDS + 1
      FLDNAM(J  ) = FNBAND
      FLDNAM(J+1) = FNZONE
      FLDNAM(J+2) = FNRA
      FLDNAM(J+3) = FNDEC
      FLDCLS(J  ) = FCDECB 
      FLDCLS(J+1) = FCRAZ
      FLDCLS(J+2) = FCRAS
      FLDCLS(J+3) = FCDECS
      FLTYPE(J  ) = 1
      FLTYPE(J+1) = 1
      FLTYPE(J+2) = 2
      FLTYPE(J+3) = 2
      NFLDS = NFLDS + 4

C
C     Step 3: determine field distribution between MAIN and AUX parts
C             of the record.
C
C     To decide whether a field should be in MAIN or AUX part, we use
C     the following approach:
C
C     Numerical field is goes to AUX if:
C        -  it is not INTENSITY
C        -  MISS/NOBJ*100% > C1
C
C     Text field is goes to AUX if:
C        -  it is not ID
C        -  MISS/NOBJ*100% > min ( C1, C2/SIZE )
C
C     Any field goes to AUX only if ... there is still a slot for
C     it available in AUX :) Remeber that AUX field has a MASK that
C     allows only 31 AUX fields.
C
C     So, pre-defined parameter C1 is critical percentage of missing
C     data whereas pre-defined parameter C2 for text data allow us to
C     move the field to AUX part even if missing data volume is not
C     so large but the field size is pretty large.
C
      NMAIN = NFLDS
      C1 = AORMPR
      C2 = AORMSZ

      DO I = 1, NFLDS

         A = MISS(I) * 100.D0 / NOBJ

         IF ( ( ( FLTYPE(I) .EQ. 0              .AND.
     .            FLDCLS(I) .NE. FCID           .AND.
     .            A .GT. DMIN1 ( C1, C2/SIZE(I) )    ) .OR.
     .          ( FLTYPE(I) .GT. 0              .AND.
     .            FLDCLS(I) .NE. FCINTE         .AND.
     .            A .GT. C1                          )    ) .AND.
     .        ( ( NFLDS - NMAIN ) .LT. NFAMAX             )      ) THEN
            Z(I) = 1
            NMAIN = NMAIN - 1
         ELSE
            Z(I) = 0
         END IF

      END DO

C
C     After this cycle we have filled Z array. If Z(i)=0,
C     field "i" is included to MAIN part, otherwise - to AUX part
C

C
C     Step 4: determine the order of field in the SPICE catalog
C             records and generate order and rank vectors
C             correspondence between original catalog and SPICE
C             field numbers.
C
C     Remind, that we the following fields have explicitly assigned
C     numbers (locations) in the SPICE catalog records:
C
C        1 - object ID
C        2 - declination band number
C        3 - elementary zone number within the declination band
C        4 - RA
C        5 - DEC
C
C     and then fields of these types (if exist) in the following order:
C
C        PMRA
C        PMDEC
C        PRLX
C        RAD_VEL
C        INTENSITY
C
C     First, we clear the ORDER array.
C
      CALL CLEARI ( NFLMAX, ORDER )

C
C     Start with the first field in SPICE catalog records is
C     ID field.
C
      I = ESRCHC ( FCID, NFLDS, FLDCLS )
      ORDER(1) = I

C
C     Then - four "obligatory" position fields mentioned above.
C
      ORDER(2) = NFLDS - 3
      ORDER(3) = NFLDS - 2
      ORDER(4) = NFLDS - 1
      ORDER(5) = NFLDS
      J = 6



C
C     Then - RA and DEC proper motion fields (if exist.)
C
      I = ESRCHC ( FCPMRA, NFLDS, FLDCLS )
      K = ESRCHC ( FCPMDC, NFLDS, FLDCLS )

      IF ( I .NE. 0 .AND. K .NE. 0 ) THEN

         ORDER(6) = I
         ORDER(7) = K
         J = 8

      ELSE IF ( I + K .NE. 0 ) THEN

         CALL SETMSG ( 'Presence/absence of PMRA and PMDEC type ' //
     .                 'fields must have been checked out before '//
     .                 'getting to this point in catalog '        //
     .                 'generation process. The PMRA-type field ' //
     .                 'index was # while PMDEC-type field index '//
     .                 'was #. There is a problem in catalog '    //
     .                 'writer code. Please, contact NAIF.'       )
         CALL ERRINT ( '#', I                                     )
         CALL ERRINT ( '#', J                                     )
         CALL SIGERR ( 'SPICE(STWSW2BUG2)'                        )
         CALL CHKOUT ( 'STWSW2'                                   )
         RETURN

      END IF

C
C     Then - parallax field (if exists.)
C
      I = ESRCHC ( FCPRLX, NFLDS, FLDCLS )
      IF ( I .NE. 0 ) THEN
         ORDER(J) = I
         J = J + 1
      END IF

C
C     Then - radial velocity field (if exists.)
C
      I = ESRCHC ( FCRVEL, NFLDS, FLDCLS )
      IF ( I .NE. 0 ) THEN
         ORDER(J) = I
         J = J + 1
      END IF

      NINPOS = J - 2

C
C     Then - INTENSITY fields (if exist.)
C
      NINTEN = 0
      DO I = 1, NFLDS
         IF ( FLDCLS(I) .EQ. FCINTE ) THEN
            ORDER(J) = I
            J = J + 1
            NINTEN = NINTEN + 1
         END IF
      END DO

C
C     Complete ORDER vector generation by appending the rest of the
C     fields after the fields that we have already copied to it.
C
      M = J - 1

      DO I = 1, NFLDS - 4

         I1 = ISRCHI ( I, M, ORDER )

         IF ( I1 .EQ. 0 ) THEN
            ORDER(J) = I
            J = J + 1
         END IF

      END DO

C
C     Now, when we have first iteration ORDER which doesn't reflect
C     which fields are in the MAIN part and which in AUX, we
C     re-arrange it such that all AUX fields end up at the very end
C     of the record. Note that this re-ordering cannot affect neither
C     'ID' and 'INTENSITY' fields not four positional fields that we
C     have added -- these fields all have Z(I) .EQ. 0.
C
      M = NFLDS

      DO I = 1, NFLDS

         IF ( Z(I) .EQ. 1 ) THEN

C
C          Search for K - ORDER element number containing I, ORDER(K)=I
C
           K = ISRCHI ( I, M, ORDER )

C
C          Swap two ORDER elements: "K-th" and "last non-processed".
C
           J = ORDER(M)
           ORDER(M) = ORDER(K)
           ORDER(K) = J
           M = M - 1

         END IF

      END DO

C
C     Now we have found the order in which original (and added) record
C     fields must appear in the record. Using it we can reorder all
C     field attribute and assotiated arrays.
C
      CALL REORDC ( ORDER, NFLDS, FLDNAM )
      CALL REORDI ( ORDER, NFLDS, FLTYPE )
      CALL REORDI ( ORDER, NFLDS, FLDIND )
      CALL REORDD ( ORDER, NFLDS, MINVAL )
      CALL REORDD ( ORDER, NFLDS, MAXVAL )
      CALL REORDI ( ORDER, NFLDS, ACCUR  )
      CALL REORDI ( ORDER, NFLDS, SIZE   )
      CALL REORDI ( ORDER, NFLDS, MISS   )
      CALL REORDC ( ORDER, NFLDS, FLDCLS )
      CALL REORDC ( ORDER, NFLDS, FLDPRF )
      CALL REORDI ( ORDER, NFLDS, FLDBPS )

C
C     We also generate RANK vector from the ORDER vector such that
C     using the RANK and ORDER vectors we can easily make a
C     correspondence between "Final field #" and "Initial field #":
C
C        Final field #   =  RANK  ( Initial field # )
C        Initial field # =  ORDER ( Final field #   )
C
      DO I = 1, NFLDS
         RANK(ORDER(I)) = I
      END DO

C
C     Step 5: determine packing attributes of the MAIN and AUX part
C             of the record:
C
C        -- number of num and text MAIN fields (NNUMM and NTXTM);
C        -- number of num and text AUX fields (NNUMM and NTXTM);
C        -- arrays of num and text MAIN fields numbers (NMFLDS and TMFLDS);
C        -- arrays of num and text AUX fields numbers (NAFLDS and TAFLDS);
C        -- field's MAXABS;
C        -- size of the MAIN part of the records and numeric and
C           character portions of it;
C        -- MAIN part field packing density;
C
C     Also, if dynamic range of a numeric field is too wide, we
C     modify ACCUR and MINVAL to make sure it can fit into the
C     catalog packing schema.
C
      ISTART = 1

      DO I = 1, NFLDS

C
C        We do it for all fields but four position fields that we
C        added; all attributes for these four will be set after this
C        loop.
C
         IF ( I .LT. 2 .OR. I .GT. 5 ) THEN

            IF ( FLTYPE(I) .NE. 0 ) THEN

C
C              The parameter is of NUMERICAL type. At first compute
C              counters and numbers for MAIN and AUX fields.
C
               IF ( I .LE. NMAIN ) THEN
                  NNUMM = NNUMM + 1
                  NMFLDS(NNUMM) = I
               ELSE
                  NNUMA = NNUMA + 1
                  NAFLDS(NNUMA) = I
               END IF

C
C              And now check ACCUR array in such a way to have an
C              appropriate dynamic range for each field. The dynamic
C              range (considered here as maximal value of conditional
C              "units") is to be less than 2^31 - 3. If the requirement
C              is not met, we shall increase value of the conditional
C              "unit".
C
               A = 1.0D0
               IF ( ACCUR(I) .GT. 0 ) THEN
                  A = A / (10**ACCUR(I))
               END IF

               RATIO = ( MAXVAL(I) - MINVAL(I) ) / A

C
C              Once we computed first cut at RATIO, we need to make
C              sure that we it's not too big (which is VERY unlikely
C              :-) and not-negative because of the DP to INT
C              assignment overflow. Such overflow can happen if
C              dynamic range of a field of interest is too wide
C              (more than 2^31-3.) We also need to truncate MINVAL
C              to make sure that we won't bother future users
C              with digits beyond ACCUR when values will be put back
C              together.
C
               DO WHILE ( RATIO .GE. RATMAX .OR. RATIO .LE. 0 )
                  A = A * 10
                  ACCUR(I) = ACCUR(I) - 1
                  RATIO = ( MAXVAL(I) - MINVAL(I) ) / A
                  C1 = DABS ( MINVAL(I) )
                  C2 = C1 - INT ( C1 )
                  MINVAL(I) = DSIGN ( INT(C1) + INT( C2 *
     .               10D0**ACCUR(I)+.5D0 )/10D0**ACCUR(I), MINVAL(I) )
               END DO

C
C              Very important instance! We define MAXABS value bearing
C              in mind that we are to provide "margin" for NULL values.
C              Consider real amount of increments
C
C                 J=(MAXVAL-MINVAL)/Units.
C
C              If J is odd it is an ideal case: we just generate
C
C                 MAXABS = (J+1)/2
C
C              and reserve the value Y = + MAXABS for NULL. Otherwise,
C              for even J we have to reserve one spare value:
C
C                 MAXABS = J/2 + 1
C
C              and again reserve the value Y = + MAXABS for NULL.
C
               J = ( MAXVAL(I) - MINVAL(I) ) / A + .5D0
               IF ( MOD ( J, 2 ) .EQ. 1 ) THEN
                  MAXABS(I) = ( J + 1 ) / 2
               ELSE
                  MAXABS(I) = J / 2 + 1
               END IF

            ELSE

C
C              The parameter is of CHAR type.  At first compute
C              counters and numbers for MAIN and AUX fields.
C
               IF ( I .LE. NMAIN ) THEN

                  NTXTM = NTXTM + 1
                  TMFLDS(NTXTM) = I
                  TXTSIZ = TXTSIZ + SIZE(I)

               ELSE

                  NTXTA = NTXTA + 1
                  TAFLDS(NTXTA) = I

               END IF

               TXTBEG(I) = ISTART
               ISTART = ISTART + SIZE(I)
               MAXABS(I) = -SIZE(I)

            END IF

         ELSE
C
C           We are here if 2 <= field # <= 5, i.e. the field is one of
C           the positional field that we added. In this case the
C           field definitely belongs to MAIN part of the record.
C
            NNUMM = NNUMM + 1
            NMFLDS(NNUMM) = I

         END IF

      END DO

C
C     For four positional fields that we added (fields #2..#5),
C     we define MINVAL, MAXABS, and ACCUR values in accordance with
C     positional information packing schema defined by the catalog
C     design.
C
      MINVAL(2) = 1.0D0
      MINVAL(3) = 1.0D0
      MINVAL(4) = RDMINV
      MINVAL(5) = RDMINV
      MAXABS(2) = NBANDS / 2
      MAXABS(3) = NMAXBN / 2
      MAXABS(4) = RDMAXA
      MAXABS(5) = RDMAXA
      ACCUR(2)  = 0
      ACCUR(3)  = 0
      ACCUR(4)  = 0
      ACCUR(5)  = 0

C
C     Determine number integer packets needed to hold concatenated
C     text fields of MAIN part of the record.
C
      NPKTXT = TXTSIZ / NCHARI
      IF ( MOD( TXTSIZ, NCHARI ) .NE. 0 ) THEN
         NPKTXT = NPKTXT+1
      END IF

C
C     So, we have got NNUMM of fields for numerical parameters
C     of the MAIN block. It is necessary to pack them in optimal way.
C     To this end let us use the STPCK2 routine.
C
      DO I = 1, NNUMM
         Z(I) = MAXABS ( NMFLDS(I) )
      END DO

C
C     Note that this call to STPCK2 re-orders NMFLDS array such that
C     maximum packing is achieved.
C
      CALL STPCK2 ( NMFLDS, Z, NNUMM, NPKNUM, DENS )

      MRECL = NPKNUM + NPKTXT + 1

C
C     We have done all the processing we wanted and can now write
C     all collected metainformation into the METAINFORMATION
C     segment.
C
C     Start with the number fo fields and number of fields in the
C     main part of the record
C
      CALL STAIT2 ( HANDLE, MDNOFF, 1, NFLDS )
      CALL STAIT2 ( HANDLE, MDNMAI, 1, NMAIN )

C
C     Store field names. Since they are strings, we must to
C     convert them into integers.
C
      DO I = 1, NFLDS
         CALL STT2I2 ( FLDNAM(I), FLDNLN,
     .                 ARR3((I-1)*(FLDNLN/NCHARI)+1), J )
      END DO
      CALL STAIT2 ( HANDLE, MDFNAM, (FLDNLN/NCHARI)*NFLDS, ARR3 )

C
C     Store field type and indexed flags.
C
      CALL STAIT2 ( HANDLE, MDFTYP, NFLDS, FLTYPE )
      CALL STAIT2 ( HANDLE, MDFIDX, NFLDS, FLDIND )

C
C     Store field class names.
C
      DO I = 1, NFLDS
         CALL STT2I2 ( FLDCLS(I), FLDCLN,
     .                 ARR3((I-1)*(FLDCLN/NCHARI)+1), J )
      END DO
      CALL STAIT2 ( HANDLE, MDFCLA, (FLDCLN/NCHARI)*NFLDS, ARR3 )

C
C     Encode by hex, convert to INTs and store MINVALs.
C
      K = DPHXSZ / NCHARI
      DO I = 1, NFLDS
         LINE = ' '
         CALL DP2HX  ( MINVAL(I), LINE, J )
         CALL STT2I2 ( LINE, DPHXSZ, ARR3(1+K*(I-1)), J )
      END DO
      CALL STAIT2 ( HANDLE, MDMINV, NFLDS * K, ARR3 )

C
C     Store other meta intens that are already INTs, and, therefore,
C     don't require pre-processing.
C
      CALL STAIT2 ( HANDLE, MDACCU, NFLDS,  ACCUR  )
      CALL STAIT2 ( HANDLE, MDMISS, NFLDS,  MISS   )
      CALL STAIT2 ( HANDLE, MDMAXA, NFLDS,  MAXABS )
      CALL STAIT2 ( HANDLE, MDNPKT, 1,      NPKTXT )
      CALL STAIT2 ( HANDLE, MDMRCL, 1,      MRECL  )
      CALL STAIT2 ( HANDLE, MDNMFL, NNUMM,  NMFLDS )
      CALL STAIT2 ( HANDLE, MDNPKN, 1,      NPKNUM )
      CALL STAIT2 ( HANDLE, MDDENS, NPKNUM, DENS   )
      CALL STAIT2 ( HANDLE, MDNNAU, 1,      NNUMA  )
      CALL STAIT2 ( HANDLE, MDNAUF, NNUMA,  NAFLDS )
      CALL STAIT2 ( HANDLE, MDNTAU, 1,      NTXTA  )
      CALL STAIT2 ( HANDLE, MDTAUF, NTXTA,  TAFLDS )
      CALL STAIT2 ( HANDLE, MDNINP, 1,      NINPOS )
      CALL STAIT2 ( HANDLE, MDNINI, 1,      NINTEN )

C
C     Write first non-common character indexes to METAINFORMATION.
C
      CALL STAIT2 ( HANDLE, MDCPOS, NFLDS,  FLDBPS )

C
C     Accumulate all common prefixes in one string and write it
C     to METAINFORMATION.
C
      PRFSIZ = 0
      PRFVAL = ' '
      DO I = 1, NFLDS
         J = FLDBPS(I) - 1
         IF ( FLTYPE(I) .EQ. 0 .AND. J .GT. 0 ) THEN
            PRFVAL( PRFSIZ+1 : PRFSIZ+J ) = FLDPRF(I)(1:J)
            PRFSIZ = PRFSIZ + J
         END IF
      END DO

      IF ( PRFSIZ .GT. 0 ) THEN
         CALL STT2I2 ( PRFVAL, PRFSIZ, ARR3, J )
         CALL STAIT2 ( HANDLE, MDCPRF, J, ARR3 )
      END IF

C
C     Write index table attributes to METAINFORMATION.
C
      DO I = 1, NFLDS
         IF ( FLDIND(I) .EQ. 1 ) THEN
            NINDX = NINDX + 1
            LSTTAB(NINDX) = I
         END IF
      END DO

      CALL STAIT2 ( HANDLE, MDNITB, 1,     NINDX  )
      CALL STAIT2 ( HANDLE, MDLSTT, NINDX, LSTTAB )

C
C     Write placeholders for BEGMAI, BEGAUX, BEGIND addresses and
C     NNODES array.
C
      I = 0
      CALL STAIT2 ( HANDLE, MDBMAI, 1, I )
      CALL STAIT2 ( HANDLE, MDBAUX, 1, I )
      CALL STAIT2 ( HANDLE, MDBIDX, 1, I )

      CALL CLEARI ( NINDX, Z )
      CALL STAIT2 ( HANDLE, MDNNOD, NINDX, Z )

C
C     To finish METAINFORMATION segment we need to store field
C     descriptions. Remind that array NFDESC contains numbers of
C     lines for non-ordered fields and that descrptions themselves
C     were "dumped" into scratch DAS file with handle DSCDAS in
C     STWFI2.
C
C     On our way, we will do the following:
C
C        -- use array Z to store sum of NFLDDS elements (i-th element
C           of Z stores sum of NFLDDS elements from 1 to i-1);
C
C        -- use ORDER vector to fill in array DAT with numbers from
C           NFLDDS + four more elements for added RA/DEC fields;
C
C        -- add pre-cooked descriptions for four additional RA/DEC
C           fields;
C
C        -- convert pre-cooked description lines and ones stored in
C           DSCDAS to INTs and accumulate them in ARR3; keep count
C           of elements in ARR3 using L;
C
C     First, we fill in Z.
C
      Z(1) = 0
      DO I = 2, NFLDS - 4
         Z(I) = Z(I-1) + NFDESC(I-1)
      END DO

C
C     Now start packing/converting description text. Do the first field
C     in ORDER (ID); description of this field is stored in DSCDAS.
C
      K = ORDER(1)
      DAT(1) = NFDESC(K)

      L = 1
      DO I = 1, DAT(1)
         CALL DASRDC ( DSCDAS,
     .                 (Z(K)+I-1)*DSCLSZ+1, (Z(K)+I)*DSCLSZ,
     .                                   1,          DSCLSZ, LINE )
         CALL STT2I2 ( LINE, DSCLSZ, ARR3(L), J )
         L = L + DSCLSZ/NCHARI
      END DO

C
C     Pack pre-coocked descriptions for the 2nd..5th fields in ORDER -
C     DEC band number, zone number, RA offset, DEC offset. Try to be
C     as brief as possible; those who needs to know more should read
C     Sky Catalog REQ :-)
C
      DAT(2) = 1
      LINE = PFNBAN
      CALL STT2I2 ( LINE, DSCLSZ, ARR3(L), J )
      L = L + DSCLSZ/NCHARI

      DAT(3) = 1
      LINE = PFNZON
      CALL STT2I2 ( LINE, DSCLSZ, ARR3(L), J )
      L = L + DSCLSZ/NCHARI

      DAT(4) = 1
      LINE = PFNRA
      CALL STT2I2 ( LINE, DSCLSZ, ARR3(L), J )
      L = L + DSCLSZ/NCHARI

      DAT(5) = 1
      LINE = PFNDEC
      CALL STT2I2 ( LINE, DSCLSZ, ARR3(L), J )
      L = L + DSCLSZ/NCHARI

C
C     For the rest of the fields in ORDER (6th...NFLDSth) we do the
C     same thing as for the first field -- read description from DAS.
C
      DO I = 6, NFLDS

         K = ORDER(I)
         DAT(I) = NFDESC(K)

         DO I1 = 1, DAT(I)
            CALL DASRDC ( DSCDAS,
     .                    (Z(K)+I1-1)*DSCLSZ+1, (Z(K)+I1)*DSCLSZ,
     .                                       1,           DSCLSZ, LINE )
            CALL STT2I2 ( LINE, DSCLSZ, ARR3(L), J )
            L = L + DSCLSZ/NCHARI
         END DO

      END DO

C
C     We are done with description packing. All test was converted and
C     stored in ARR3, all number-of-lines per field description were
C     stored in the right order in DAT. Let's add bth of them to
C     METAINFORMATION.
C
      CALL STAIT2 ( HANDLE, MDFDSC, L - 1, ARR3 )
      CALL STAIT2 ( HANDLE, MDFDSN, NFLDS, DAT  )

C
C     We don't need scratch DAS file containing field descriptions
C     any more. Close it.
C
      CALL DASCLS ( DSCDAS )

C
C     Now we are really through with METAINFORMATION. It's hightime
C     to obtain address of the last record in the DAS file (i.e.
C     the last record in the METAINFORMATION segment).
C
      CALL DASLLA ( HANDLE, I, J, K )

C
C     Compute BEGMAI and BEGAUX and update the METAINFORMATION data.
C
      BEGMAI = K + 1
      BEGAUX = BEGMAI + MRECL * NOBJ

      CALL STGIT2 ( HANDLE, MDBMAI, I, J )
      CALL DASUDI ( HANDLE, I, J, BEGMAI )
      CALL STGIT2 ( HANDLE, MDBAUX, I, J )
      CALL DASUDI ( HANDLE, I, J, BEGAUX )

C
C     Write placeholders for MAIN DATA segment.
C
      DO I = 1, MRECL
         CALL DASADI ( HANDLE, NOBJ, ARR3 )
      END DO

C
C     Set relative (to BEGAUX) address at which the next AUX
C     portion will be written.
C
      ISTAUX = 1

C
C     ... and move on to the next cycle!
C
      CYCLE = 2

C
C     All done. Checking out.
C
      CALL CHKOUT( 'STWSW2' )

      RETURN


C$Procedure  STWRC2 ( write a record to the catalog )

      ENTRY STWRC2 ( IREC )

C$ Abstract
C
C     Generate and write to the catalog file SPICE catalog record
C     for specified sky object.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     INTEGER               IREC
C
C$ Brief_I/O
C
C     VARIABLE  I/O  DESCRIPTION
C     --------  ---  --------------------------------------------------
C     IREC       I   Source catalog record number for the object
C
C$ Detailed_Input
C
C     IREC           is the source catalog record number of the object.
C
C$ Detailed_Output
C
C     None
C
C$ Parameters
C
C     See umbrella and include file headers.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is opened for writing at the time
C        when this routine is called, then the error
C        'SPICE(CATALOGISNOTOPENED)' will be signalled.
C
C     2) If this entry was called before STWSW2 or after StWFW2 (i.e.
C        outside of cycle 2), then the error 'SPICE(CALLEDOUTOFORDER)'
C        will be signalled.
C
C     3) If values to records other that the one speficied have been
C        processed/buffered by previous call to STWRD2 and STWPF2,
C        then the error 'SPICE(INCONSISTENTDATA)' will be signalled.
C
C$ Files
C
C     TBD.
C
C     Need brief reference of output and scratch file used by routine.
C
C$ Particulars
C
C     At the moment of calling the routine we have array
C     VALUE filled by numerical fields values and string TEXT
C     filled by text fields. So, all fields are filled - both
C     for MAIN and for AUX parts.
C     At first we pack the MAIN set of data. Then we check whether
C     the record contains AUX block. To this end look through all
C     the rest (AUX) fields.
C     If we meet non-empty text AUX field, we modify the MASK and
C     write to TXT string the text AUX field followed by
C     non-printable byte '007' ASCII.
C     If we meet non-empty numerical AUX field, we again modify
C     the MASK and make preparations for future packing.
C
C     Then determine the address in Catalog to write the MAIN DATA
C     package, finalize and write down MAIN package. If AUX exists,
C     finalize the AUX package and write it down to the AUX DATA
C     segment.
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be opened for writing using STWOP2
C     entry of this routine prior to calling this entry.
C
C     Second cycle must be started by calling STWSW2 entry prior to
C     calling this entry.
C
C     Position and value of all fields in specified record must
C     provided using STWRD2 and STWPF2 prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     write type_2 sky_catalog object record
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWRC2' )
      END IF

C
C     Check whether the catalog is opened for writing.
C
      IF ( .NOT. OPENED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was opened for '    //
     .                 'writing prior to calling this routine.'   )
         CALL SIGERR ( 'SPICE(CATALOGISNOTOPENED)'                )
         CALL CHKOUT ( 'STWRC2'                                   )
         RETURN
      END IF

C
C     This routine is called "outside" first and second cycles.
C     If yes, signal an error.
C
      IF ( CYCLE .NE. 2 ) THEN
         CALL SETMSG ( 'This entry must not be called before '    //
     .                 'the second pass over catalog data '       //
     .                 '(second cycle) initiated by STWSW2. '     )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER)'                  )
         CALL CHKOUT ( 'STWRC2'                                   )
         RETURN
      END IF

C
C     Check whether RA/DEC and all field value were provided and that
C     they were provided for the same IREC (remember that VLIREC
C     elements were assigned IREC in STWRD2 and STWPF2.)
C
      DO J = 1, NFLDS
         IF ( IREC .NE. VLIREC(J) ) THEN
            CALL SETMSG ( 'Attempted to write buffered value of '    //
     .                    'the field ''#'' for source catalog '      //
     .                    'No. # with the write-record request '     //
     .                    'for source catalog record No. #.'         )
            CALL ERRCH  ( '#', FLDNAM(j)                             )
            CALL ERRINT ( '#', VLIREC(j)                             )
            CALL ERRINT ( '#', IREC                                  )
            CALL SIGERR ( 'SPICE(INCONSISTENTDATA)'                  )
            CALL CHKOUT ( 'STWRC2'                                   )
            RETURN
         END IF
      END DO

C
C     Start packing the record. Remember that:
C
C        -- IREC is record number for source catalog;
C        -- array VALUE filled and string TEXT filled field values;
C
C     First, pack numeric field of the MAIN part of the record. We know
C     that we have at least four positional numeric fiels, so there is no
C     check for NNUMM value.
C
      DO J = 1, NNUMM
         Z(J) = VALUE(NMFLDS(J))
      END DO

      K = 1
      DO J = 1, NPKNUM
         PACKED(J) = STF2I2 ( DENS(J), Z(K) )
         K = K + DENS(J)
      END DO

C
C     Then, pack text field of the MAIN part of the record. These are
C     stored is concatenated fashion in the TEXT string. Note that we
C     cannot quarantee that we have at least one character field in
C     the main part. Thus, we should chekc for that.
C
      IF ( NPKTXT .GT. 0 ) THEN
         CALL STT2I2 ( TEXT, TXTSIZ, PACKED(NPKNUM+1), NPKTXT )
      END IF

C
C     MAIN block has been packed (although it doesn't contain POINTER
C     to AUX part yet.) Check whether the record contains AUX block.
C     First, initialize necessary parameters.
C
      MASK = 0
      NNUM = 0
      NTXT = 0
      TXT = ' '
      I1 = 1

C
C     Look through AUX fields to see if any of them has a non-NULL
C     value.
C
      DO J = NMAIN+1, NFLDS

C
C        Is this field a character field?
C
         IF ( FLTYPE(J) .EQ. 0 ) THEN

C
C           Yes. See if its value is not blank.
C
            K = TXTBEG(J)
            M = K - 1 - MAXABS(J)

            IF ( TEXT(K:M) .NE. ' ' ) THEN

C
C              Non-blank text AUX field has been found. Modify the MASK
C              and write the text AUX field value followed by
C              non-printable byte '007' ASCII to TXT string.
C
               IAUX = J - NMAIN
               MASK = MASK + 2**(IAUX-1)
               NTXT = NTXT + 1
               I = RTRIM(TEXT(K:M))
               I2 = I1 + I
               TXT(I1:I2) = TEXT(K:K+I-1) // CHAR(7)
               I1 = I2 + 1

            END IF

         ELSE

C
C           This is numerical field. Does it have NULL value?
C
            IF ( VALUE(J) .LT. MAXABS(J) ) THEN

C
C              Non-NULL numerical AUX field has been found. Modify the
C              MASK and make preparations for future packing. We store
C              numbers of non-empty AUX numerical fields in FIELDS
C              array whereas corresponding MAXABS values in Z array.
C
               IAUX = J - NMAIN
               MASK = MASK + 2**(IAUX-1)
               NNUM = NNUM + 1
               FIELDS(NNUM) = J
               Z(NNUM) = MAXABS(J)

            END IF

         END IF

      END DO

C
C     Determine the address in output SPICE catalog at which the
C     MAIN portion of the record should be written. Remember that
C     the record number in the output catalog is stored at the
C     original record index in the ARR1.
C
      K = ARR1(IREC)
      J1 = BEGMAI + MRECL * (K-1)
      J2 = J1 + MRECL - 1

C
C     Do have AUX fields to store?
C
      IF ( MASK .EQ. 0 ) THEN

C
C        No. Put zero instead of the address of AUX part and write MAIN
C        part of the record to the file.
C
         PACKED(MRECL) = 0
         CALL DASUDI ( HANDLE, J1, J2, PACKED )

      ELSE

C
C        Yes, we have AUX part for this record. Store current relative
C        AUX address in the last element of the MAIN part of the record
C        and write MAIN part of the record to the file.
C
         PACKED ( MRECL ) = ISTAUX
         CALL DASUDI ( HANDLE, J1, J2, PACKED )

C
C        Now we need to package non-NULL AUX fields to the AUX part
C        of the record. The first element of the AUX part is the
C        number of INTs in it. We will assign it later when we will
C        compute it. The second element of AUX part is MASK.
C
         PACKED(2) = MASK

C
C        Then, package numerical AUX fields, if we have any.
C
         IF ( NNUM .GT. 0 ) THEN

C
C           Note that this call to STPCK2 re-orders FIELDS to achieve
C           maximum packing.
C
            CALL STPCK2 ( FIELDS, Z, NNUM, NPCKED, DENAUX )
            DO J = 1, NNUM
               Z(J) = VALUE ( FIELDS(J) )
            END DO

            K = 1
            DO J = 1, NPCKED
               PACKED(J+2) = STF2I2 ( DENAUX(J), Z(K) )
               K = K + DENAUX(J)
            END DO

         ELSE

            NPCKED = 0

         END IF

C
C        Now we are done with the numerical part of AUX and can pack
C        the text part of AUX. At first determine ITXT - the number of
C        symbols in the text. (Note that we leave the last
C        non-printable byte at the very end of TXT.)
C
         ITXT = I1 - 1

         IF ( ITXT .GT. 0 ) THEN
            CALL STT2I2 ( TXT, ITXT, PACKED(3+NPCKED), JTXT )
         ELSE
            JTXT = 0
         END IF

C
C        Compute the length of current AUX package and store it
C        in the first element of the AUX package.
C
         JAUX = 2 + NPCKED + JTXT
         PACKED(1) = JAUX

C
C        Compute relative (to AUX area start) address of the next AUX
C        package.
C
         ISTAUX = ISTAUX + JAUX

C
C        Write AUX part of the record to the file. Note that we wrote
C        MAIN at a particular address while AUX part was simply
C        appended to the end of the file.
C
         CALL DASADI ( HANDLE, JAUX, PACKED )

      END IF

C
C     Clear up TEXT buffer to prepare it for the next record.
C
      TEXT = ' '

      CALL CHKOUT ( 'STWRC2' )

      RETURN


C$Procedure STWFW2 ( finish the catalog writing )

      ENTRY STWFW2

C$ Abstract
C
C     Generate INDEX TABLES and complete generation the catalog.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     None
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is opened for writing at the time
C        when this routine is called, then the error
C        'SPICE(CATALOGISNOTOPENED)' will be signalled.
C
C     2) If this entry was called before STWSW2 or after the second
C        cycle was completed, then the error 'SPICE(CALLEDOUTOFORDER)'
C        will be signalled.
C
C     3) If STWRD2 has not been called exactly NOBJ times during second
C        cycle before calling this entry, then the error
C        'SPICE(PARTIALCYCLE2RD)' will be signalled.
C
C     4) If STWPF2 has not been called exactly NOBJ times for each
C        catalog field during the second cycle before calling this
C        entry, then the error 'SPICE(PARTIALCYCLE2VAL)' will be
C        signalled.
C
C$ Files
C
C     TBD.
C
C     Need brief reference of output and scratch file used by routine.
C
C$ Particulars
C
C     TBD.
C
C     To generate INDEX TABLES it is necessary to look through
C     all the records in our fresh-made DATA segment and to sort
C     them by pre-defined key fields. If the field to be indexed
C     is of character type, the processing is as follows. We
C     shall perform not exact indexing but some truncated version
C     of it: form integer numbers from first four bytes of text
C     strings and sort them as usual numerical parameter.
C
C     We process all "fields of interest" one-by-one. On buffering
C     values for current field we generate an ORDER vector that is
C     INDEX TABLE for the field.
C
C     Let us design our strategy of generation NODES sequence for
C     each certain INDEX TABLE.
C
C     We shall split the non-NULL range of the key parameter to
C     predefined number of bins NNMAX and distribute the objects in
C     more or less uniform way (to have about N = NOBJ/(NNMAX+1) for
C     fields without NULLs and N = NOBJ/NNMAX for fields with NULL
C     objects in each bin). So, the condition of current bin
C     "completion" is, at first, that the number of objects in the
C     bin is greater than N, and at second, that the key parameter
C     for the next record in the index table is not equal to the
C     parameter for the current record.
C
C     The NULL portions of the index table automatically fall into
C     the first bin for text fields and into the last bin for
C     numeric fields.
C
C     According to the Catalog Design we are to generate ININDX
C     array for each indexed field (somelike an AUX with respect to
C     complete INDEX TABLE).
C
C     Let {Ai} - elements of the complete INDEX TABLE (SPICE
C                catalog record numbers sorting by key parameter
C                increasing)
C         {Zi} - corresponding values of key parameter,
C         {Bj} - node sequence,
C         {Cj} - target ININDX array.
C
C     Then the {Cj} sequence is to meet the following requirement:
C
C              C  = A , where  Z   <= B ,    Z > B
C               k    r          r-1    k      r   k
C
C     In other words, Ck is the first (minimal) element of the
C     subset of {Ai} that meets requirement:
C
C                          B  < Z  <= B
C                           k    i     k+1
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be opened for writing using STWOP2
C     entry of this routine prior to calling this entry.
C
C     Positional and other field data must be provided for all objetcs
C     from the source catalog during second cycle prior to calling
C     this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     finish type_2 sky_catalog writing
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWFW2' )
      END IF

C
C     Check whether the catalog is opened for writing.
C
      IF ( .NOT. OPENED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was opened for '    //
     .                 'writing prior to calling this routine.'   )
         CALL SIGERR ( 'SPICE(CATALOGISNOTOPENED)'                )
         CALL CHKOUT ( 'STWFW2'                                   )
         RETURN
      END IF

C
C     Check whether we are in the second cycle.
C
      IF ( CYCLE .NE. 2 ) THEN
         CALL SETMSG ( 'This entry should only be called after '  //
     .                 'the end of the second data processing '   //
     .                 'cycle initiated by a call to STWSW2. '    //
     .                 'It was called during cycle number #. '    )
         CALL ERRINT ( '#', CYCLE                                 )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER1)'                 )
         CALL CHKOUT ( 'STWFW2'                                   )
         RETURN
      END IF

C
C     Before anything, sanity check to verify that STWRD2 was called
C     exactly NOBJ times before calling this entry.
C
      IF ( C2PCNT .NE. NOBJ ) THEN
         CALL SETMSG ( 'Entry STWRD2 must have been called '      //
     .                 'exactly # times (the number of objects '  //
     .                 'in the catalog) before calling this '     //
     .                 'entry. It was called only # times.'       )
         CALL ERRINT ( '#', NOBJ                                  )
         CALL ERRINT ( '#', C2PCNT                                )
         CALL SIGERR ( 'SPICE(PARTIALCYCLE2RD)'                   )
         CALL CHKOUT ( 'STWFW2'                                   )
         RETURN
      END IF

C
C     Another sanity check to verify that STWPF2 was called
C     exactly NOBJ times for each field before calling this entry.
C
      DO I = 1, NFLDS - 4
         IF ( C2VCNT(I) .NE. NOBJ ) THEN
            CALL SETMSG ( 'Entry STWPF2 must have been called '      //
     .                    'exactly # times (the number of objects '  //
     .                    'in the catalog) for the field number # '  //
     .                    'before calling this '                     //
     .                    'entry. It was called only # times.'       )
            CALL ERRINT ( '#', NOBJ                                  )
            CALL ERRINT ( '#', I                                     )
            CALL ERRINT ( '#', C2VCNT ( I )                          )
            CALL SIGERR ( 'SPICE(PARTIALCYCLE2VAL)'                  )
            CALL CHKOUT ( 'STWFW2'                                   )
            RETURN
         END IF
      END DO

C
C     First, we need to find out what is the DAS address of the last
C     number (the last element of the last AUX portion appended) in
C     the file. Start of the INDEX area of the file will be the next
C     one after it. We get it and store in the metainformation segment.
C
      CALL DASLLA ( HANDLE, I, J, K )
      BEGIND = K + 1

      CALL STGIT2 ( HANDLE, MDBIDX, I, J )
      CALL DASUDI ( HANDLE, I, J, BEGIND )

C
C     Now we are through with DATA writing and our next step is to
C     generate INDEX TABLES. To this end, we need again consequently
C     read the data from our semi-completed master catalog. We are
C     going to use existing "SPICE catalog readers" software for the
C     purpose. To perform it we shall at first close DAS file with the
C     catalog and then open it for reading/writing again.
C
      CALL DASCLS ( HANDLE )
      CALL DASOPW ( FNAM, HANDLE )

C
C     Now load the catalog in the "SPICE catalog reader" software.
C
      CALL STLD2  ( HANDLE )

C
C     Now switch to indexing (sorting). We need to look through
C     all the records in our fresh-made DATA segment and to sort
C     them by pre-defined key fields. If the field to be indexed
C     is of character type, the processing is as follows. We
C     shall perform not exact indexing but some truncated version
C     of it: form integer numbers from first four bytes of text
C     strings and sort them as usual numerical parameter.
C

C
C     Process fields to be indexed one-by-one.
C
      DO IINDX = 1, NINDX

C
C        Get field number.
C
         IFLD = LSTTAB(IINDX)

C
C        Fetch and buffer all values for current field to be indexed.
C
         DO IOBJ = 1, NOBJ

C
C           Is this field a character field?
C
            IF ( FLTYPE(IFLD) .EQ. 0 ) THEN

C
C              We are here if the field is of character type. Read
C              the text field from the catalog file.
C
               CALL STGFC2 ( IOBJ, FLDNAM(IFLD), TEXT, FOUND )

               IF ( FOUND ) THEN

C
C                 Convert its first four or less non-common characters
C                 to an integer number.
C
                  STRLEN = MAX0 (
     .                 MIN0 ( 1-MAXABS(IFLD)-FLDBPS(IFLD), NCHARI ), 1)
                  CALL STT2I2 ( TEXT(FLDBPS(IFLD):), STRLEN, M, I1 )

               ELSE

                  M = 0

               END IF

            ELSE

C
C              We deal with numerical field. Read the parameter value
C              and convert it to an integer number.
C
               IF      ( FLTYPE(IFLD) .EQ. 1 ) THEN

                  CALL STGFI2 ( IOBJ, FLDNAM(IFLD), I1, FOUND )
                  A = I1

               ELSE IF ( FLTYPE(IFLD) .EQ. 2 ) THEN

                  CALL STGFD2 ( IOBJ, FLDNAM(IFLD), A, FOUND )

               END IF

               IF ( FOUND ) THEN
                  M = ( A - MINVAL(IFLD) ) * 10**ACCUR(IFLD) + .5D0
                  M = M - MAXABS(IFLD)
               ELSE
                  M = MAXABS(IFLD)
               END IF

            END IF

C
C           Buffer field value.
C
            ARR2(IOBJ) = M

         END DO

C
C        We have buffered values for current field. ARR2 contains NOBJ
C        elements which are key parameter values. Remind that the
C        vectors present numerical fields and text fields as well. Now
C        we can generate INDEX TABLE for current key parameter in ARR1
C        array (by calling ORDERI routine).
C
         CALL ORDERI ( ARR2, NOBJ, ARR1 )

C
C        Let us design our strategy of generation NODES sequence for
C        each certain INDEX TABLE.
C
C        We shall split the non-NULL range of the key parameter to
C        predefined number of bins NNMAX and distribute the objects in
C        more or less uniform way (to have about N = NOBJ/(NNMAX+1) for
C        fields without NULLs and N = NOBJ/NNMAX for fields with NULL
C        objects in each bin). So, the condition of current bin
C        "completion" is, at first, that the number of objects in the
C        bin is greater than N, and at second, that the key parameter
C        for the next record in the index table is not equal to the
C        parameter for the current record.
C
C        The NULL portions of the index table automatically fall into
C        the first bin for text fields and into the last bin for
C        numeric fields.
C
C        First, determine which part of the table is non-NULL part and,
C        thus, is to be split into bins :-)
C
         IDXDNE = .FALSE.

         IF ( MISS(IFLD) .GT. 0 ) THEN

            IF ( FLTYPE(IFLD) .EQ. 0 ) THEN

C
C              This field is a text field. The first bin will contain
C              all objects with NULL value. So, we need to split into
C              NNMAX bins all table but first MISS(IFLD) elements.
C
               ININDX(1) = MISS(IFLD) + 1
               NODES (1) = ARR2(ARR1(1))
               L = 2
               I = MISS(IFLD) + 2
               J = NOBJ
               NBINS = NNMAX

C
C              Check whether we have enough elements left. If we don't,
C              we set the flag indicating that we are done with node
C              table generation.
C
               IF ( I .GE. J ) THEN
                  L = 1
                  IDXDNE = .TRUE.
               END IF

            ELSE

C
C              This field is a numeric field. The last bin will
C              contain all objects with NULL values. So, we need to
C              split into NNMAX bins all table but last MISS(IFLD)
C              elements.
C
               L = 1
               I = 2
               J = NOBJ - MISS(IFLD)
               NBINS = NNMAX

C
C              Check whether we have enough elements left. If we don't,
C              we set the flag indicating that we are done with node
C              table generation.
C
               IF ( I .GE. J ) THEN
                  L = 1
                  ININDX(1) = NOBJ - MISS(IFLD) + 1
                  NODES (1) = ARR2(ARR1(NOBJ - MISS(IFLD)))
                  IDXDNE = .TRUE.
               END IF

            END IF

         ELSE

C
C           This field doesn't have NULLs. So, we need to split into
C           NNMAX+1 bins all table.
C
            L = 1
            I = 2
            J = NOBJ
            NBINS = NNMAX + 1

C
C           Check whether we have enough elements left. If we
C           don't, we set the flag indicating that we are done with
C           node table generation.
C
            IF ( I .GE. J ) THEN
               L = 1
               ININDX(1) = 2
               NODES (1) = ARR2(ARR1(1))
               IDXDNE = .TRUE.
            END IF

         END IF

C
C        Are we done with node generation? If not, proceed to the next
C        step.
C
         IF ( .NOT. IDXDNE ) THEN

C
C           Next step is computing N -- reasonable minimum number of
C           table elements in each bin. Note that in some cases N will
C           be ridiculosly small, maybe even zero meaning that EACH
C           element in the table portion that we deal with may become a
C           node :-) But, we will not worry about it now because
C           algorithm below will handle zero, small and big Ns equally
C           well.
C
            N = ( J - I + 2 ) / NBINS

C
C           Loop to find all other nodes.
C
            J1 = 1

            DO K = I, J

C
C              Remind that the number of objects in the bin is to be
C              greater than N, and at that the key parameter for the
C              next record in the index table is to be greater than
C              the parameter for the current record.
C
               IF ( J1 .GT. N                          .AND.
     .              ARR2(ARR1(K)) .NE. ARR2(ARR1(K-1))       ) THEN

                  ININDX(L) = K
                  NODES(L)  = ARR2(ARR1(K-1))
                  L  = L + 1
                  J1 = 0

               END IF

               J1 = J1 + 1

            END DO

            L = L - 1

C
C           We are not done yet. We need to do two things: first, check
C           whether we found any nodes at all, and second, if needed,
C           adjust the last node value for numeric fields with NULLs.
C
            IF ( L .EQ. 0 ) THEN

C
C              We didn't find any nodes, what a pity! Note that this
C              could have happened only for a field without NULLs or
C              for numeric field with NULLs (character field has got
C              its first node before entering the loop.) Chance of this
C              happening is TREMENDOSLY low ... but it exist. It can
C              happen in cases when a field has more than N * (NBINS-1)
C              identical values and they all are at the end of table
C              portion which we are trying to split. Well, for numeric
C              field with NULLs we simply assign the node, for no-NULLs
C              fields we have to do the loop again ...
C
               IF ( FLTYPE(IFLD) .NE. 0 .AND. MISS(IFLD) .GT. 0 ) THEN

C
C                 For numeric fields with MISS the node is the first
C                 NULL.
C
                  L = 1
                  ININDX(1) = NOBJ - MISS(IFLD) + 1
                  NODES (1) = ARR2(ARR1(NOBJ - MISS(IFLD)))

               ELSE

C
C                 For fields without NULLs, the node is the first
C                 value that is different from the previous one.
C
                  DO K = I, J

                     IF ( L .EQ. 0                          .AND.
     .                    ARR2(ARR1(K)) .NE. ARR2(ARR1(K-1))     ) THEN

                        L  = L + 1
                        ININDX(L) = K
                        NODES(L)  = ARR2(ARR1(K-1))

                     END IF

                  END DO

C
C                 If we still haven't found the node, it's either bug,
C                 because we checked in STWSW2 that indexed field contains
C                 different values, or user gave us garbage during
C                 the second cycle (i.e. all values passed in the second
C                 cycle were the same.)
C
                  IF ( L .EQ. 0 ) THEN
                     CALL SETMSG ( 'Number of nodes for index table ' //
     .                             'for the output catalog field #  ' //
     .                             'is zero. There is a '             //
     .                             'problem in catalog writer code. ' //
     .                             'Please, contact NAIF.'            )
                     CALL ERRINT ( '#', IFLD                          )
                     CALL SIGERR ( 'SPICE(STWFW2BUG2)'                )
                     CALL CHKOUT ( 'STWFW2'                           )
                     RETURN
                  END IF

               END IF

            ELSE IF ( FLTYPE(IFLD) .NE. 0 .AND.
     .                MISS(IFLD)   .GT. 0       ) THEN

C
C              The number of nodes wasn't zero, but we had numeric
C              field with NULLs. Check if the last node did
C              magically end up in the right place, at the beginning of
C              NULL portion of the table
C
               IF ( ININDX(L) .NE. ( NOBJ - MISS(IFLD) + 1 ) ) THEN

C
C                 Unfortunately, the last node is not where we want it
C                 to be. Check whether we still have vacant spot in the
C                 ININDX/NODES arrays.
C
                  IF ( L .LT. NNMAX ) THEN

C
C                    We do. Put the first NULL element in the index table
C                    in this spot.
C
                     L = L + 1
                     ININDX(L) = NOBJ - MISS(IFLD) + 1
                     NODES (L) = ARR2(ARR1(NOBJ - MISS(IFLD)))

                  ELSE

C
C                    We don't have a vacant spot. We need to change the last
C                    element in the nodes table to be the first NULL element
C                    of the index table.
C
                     ININDX(L) = NOBJ - MISS(IFLD) + 1
                     NODES (L) = ARR2(ARR1(NOBJ - MISS(IFLD)))

                  END IF

               END IF

            END IF

         END IF

C
C        Set number of nodes.
C
         NNODES(IINDX) = L

C
C        Final sanity check to see if the number of node is less than
C        NNMAX. We couldn't have generated nodes than NNMAX. It's a bug.
C
         IF ( L .GT. NNMAX ) THEN

            CALL SETMSG ( 'Number of nodes for index table ' //
     .                    'for the output catalog field #  ' //
     .                    'is greater than maximum allowed ' //
     .                    'number of nodes #. There is a '   //
     .                    'problem in catalog writer code. ' //
     .                    'Please, contact NAIF.'            )
            CALL ERRINT ( '#', IFLD                          )
            CALL ERRINT ( '#', NNMAX                         )
            CALL SIGERR ( 'SPICE(STWFW2BUG1)'                )
            CALL CHKOUT ( 'STWFW2'                           )
            RETURN

         END IF

C
C        Now write down to the catalog DAS file our Index Table,
C        "Initial Indexes" array and Nodes array for the key
C        parameter.
C
         CALL DASADI ( HANDLE, NOBJ, ARR1            )
         CALL DASADI ( HANDLE, NNODES(IINDX), ININDX )
         CALL DASADI ( HANDLE, NNODES(IINDX), NODES  )

      END DO

C
C     It is hightime to provide META with indexing results,
C     namely to write down array NNODES ... if we had any
C     indexed fields, of course :-)
C
      IF ( NINDX .GT. 0 ) THEN

         CALL STGIT2 ( HANDLE, MDNNOD, I, J )
         CALL DASUDI ( HANDLE, I, J, NNODES )

      END IF

C
C     Re-set CYCLE to indicate that we are done with this catalog.
C
      CYCLE = 3

      CALL CHKOUT ( 'STWFW2' )

      RETURN


C$Procedure  STWCL2 ( close sky catalog file opened for writing )

      ENTRY STWCL2

C$ Abstract
C
C     Close SPICE catalog opened for writing.
C
C$ Copyright
C
C     Copyright (2000), California Institute of Technology.
C     U.S. Government sponsorship acknowledged.
C
C$ Required_Reading
C
C     SPICE Sky Catalog Subsystem
C
C$ Keywords
C
C     TBD
C
C$ Declarations
C
C     None
C
C$ Parameters
C
C     None.
C
C$ Exceptions
C
C     1) If no type Type 2 catalog is opened for writing at the time
C        when this routine is called, then the error
C        'SPICE(CATALOGISNOTOPENED)' will be signalled.
C
C     2) If writing of the catalog has not been finished by a call
C        to STWFW2, then the error 'SPICE(CALLEDOUTORDER)' will be
C        signalled.
C
C$ Files
C
C     TBD
C
C     Need brief reference of output file used by routine.
C
C$ Particulars
C
C     On successful completion of some checks unload the file from
C     reader, close the file using DASCLS and reset all flags for
C     the next catalog writing :)
C
C$ Examples
C
C     See the example for entire set of the umbrella routines
C
C$ Restrictions
C
C     Type 2 SPICE Sky catalog must be opened for writing using STWOP2
C     entry of this routine prior to calling this entry.
C
C     Writing of the catalog must be completed by a call to STWFW2 entry
C     prior to calling this entry.
C
C$ Literature_References
C
C     None.
C
C$ Author_and_Institution
C
C     V.N. Kheifets  (JPL)
C
C$ Version
C
C-    SPICELIB Version 1.0.0, 01-DEC-1999 (VNK)
C
C-&

C$ Index_Entries
C
C     close type_2 sky_catalog opened for writing
C
C-&

C
C     Standard SPICE error handling.
C
      IF ( RETURN () ) THEN
         RETURN
      ELSE
         CALL CHKIN ( 'STWCL2' )
      END IF

C
C     Check whether the catalog is opened for writing.
C
      IF ( .NOT. OPENED ) THEN
         CALL SETMSG ( 'No Type 2 Sky catalog was opened for '    //
     .                 'writing prior to calling this routine.'   )
         CALL SIGERR ( 'SPICE(CATALOGISNOTOPENED)'                )
         CALL CHKOUT ( 'STWCL2'                                   )
         RETURN
      END IF

C
C     Check whether we are in the third cycle.
C
      IF ( CYCLE .NE. 3 ) THEN
         CALL SETMSG ( 'This entry should only be called after '  //
     .                 'wiritng of the catalog has been finished '//
     .                 'by a call to STWFW2. '                    //
     .                 'It was called during cycle number #. '    )
         CALL ERRINT ( '#', CYCLE                                 )
         CALL SIGERR ( 'SPICE(CALLEDOUTOFORDER)'                  )
         CALL CHKOUT ( 'STWCL2'                                   )
         RETURN
      END IF

C
C     Unload the file from reader.
C
      CALL STULD2 ( HANDLE )

C
C     Close the file using DASCLS.
C
      CALL DASCLS ( HANDLE )

C
C     Reset all flags for the next catalog :).
C
      OPENED = .FALSE.
      CYCLE  = 0
      C1PCNT = 0
      C2PCNT = 0
      CALL FILLI  ( 0, NFLMAX, C1VCNT )
      CALL FILLI  ( 0, NFLMAX, C2VCNT )
      WCI2FL = .FALSE.
      WFI2FL = .FALSE.
      WZS2FL = .FALSE.
      WPM2FL = .FALSE.

      CALL CHKOUT ( 'STWCL2' )

      RETURN

      END
